package com.vendor.xzjh.settings;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.ConnectivityManager;
import android.net.Network;
import android.net.NetworkInfo;
import android.os.Build;
import android.os.Bundle;
import android.view.KeyEvent;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Toast;
import androidx.core.os.EnvironmentCompat;
import com.vendor.xzjh.settings.util.SharePreUtil;

public class BrowserActivity extends Activity {
    private static final boolean IS_DEBUG = true;
    private static final String TAG = "BrowserActivity";
    String mBootBrowserUrl;
    WebView mWvBootBrowser;
    NetWorkStateReceiver netWorkStateReceiver;

    /* access modifiers changed from: protected */
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.browser_activity);
        initView();
    }

    private void initView() {
        this.mBootBrowserUrl = (String) SharePreUtil.getInstance().getValue("modify_boot_browser_url", EnvironmentCompat.MEDIA_UNKNOWN);
        WebView webView = (WebView) findViewById(R.id.wv_boot_browser);
        this.mWvBootBrowser = webView;
        webView.setWebViewClient(new WebViewClient() {
            /* class com.vendor.xzjh.settings.BrowserActivity.AnonymousClass1 */

            @Override // android.webkit.WebViewClient
            public boolean shouldOverrideUrlLoading(WebView view, String url) {
                return false;
            }
        });
        WebSettings webSettings = this.mWvBootBrowser.getSettings();
        webSettings.setJavaScriptEnabled(IS_DEBUG);
        webSettings.setJavaScriptCanOpenWindowsAutomatically(IS_DEBUG);
        webSettings.setAppCacheEnabled(IS_DEBUG);
        webSettings.setCacheMode(1);
        webSettings.setSupportZoom(IS_DEBUG);
        webSettings.setUseWideViewPort(IS_DEBUG);
        webSettings.setLayoutAlgorithm(WebSettings.LayoutAlgorithm.SINGLE_COLUMN);
        webSettings.setDisplayZoomControls(IS_DEBUG);
        webSettings.setDefaultFontSize(12);
        this.mWvBootBrowser.loadUrl(this.mBootBrowserUrl);
    }

    public boolean onKeyUp(int keyCode, KeyEvent event) {
        if (keyCode != 4 || !this.mWvBootBrowser.canGoBack()) {
            return super.onKeyUp(keyCode, event);
        }
        this.mWvBootBrowser.goBack();
        return IS_DEBUG;
    }

    /* access modifiers changed from: protected */
    public void onResume() {
        if (this.netWorkStateReceiver == null) {
            this.netWorkStateReceiver = new NetWorkStateReceiver();
        }
        IntentFilter filter = new IntentFilter();
        filter.addAction("android.net.conn.CONNECTIVITY_CHANGE");
        registerReceiver(this.netWorkStateReceiver, filter);
        System.out.println("注册");
        super.onResume();
    }

    /* access modifiers changed from: protected */
    public void onPause() {
        unregisterReceiver(this.netWorkStateReceiver);
        System.out.println("注销");
        super.onPause();
    }

    class NetWorkStateReceiver extends BroadcastReceiver {
        NetWorkStateReceiver() {
        }

        public void onReceive(Context context, Intent intent) {
            System.out.println("网络状态发生变化");
            if (Build.VERSION.SDK_INT < 21) {
                ConnectivityManager connMgr = (ConnectivityManager) context.getSystemService("connectivity");
                NetworkInfo wifiNetworkInfo = connMgr.getNetworkInfo(1);
                NetworkInfo dataNetworkInfo = connMgr.getNetworkInfo(0);
                if (wifiNetworkInfo.isConnected() && dataNetworkInfo.isConnected()) {
                    Toast.makeText(context, "WIFI已连接,移动数据已连接", 0).show();
                    BrowserActivity.this.mWvBootBrowser.loadUrl(BrowserActivity.this.mBootBrowserUrl);
                } else if (wifiNetworkInfo.isConnected() && !dataNetworkInfo.isConnected()) {
                    Toast.makeText(context, "WIFI已连接,移动数据已断开", 0).show();
                } else if (wifiNetworkInfo.isConnected() || !dataNetworkInfo.isConnected()) {
                    Toast.makeText(context, "WIFI已断开,移动数据已断开", 0).show();
                } else {
                    Toast.makeText(context, "WIFI已断开,移动数据已连接", 0).show();
                }
            } else {
                System.out.println("API level 大于23");
                ConnectivityManager connMgr2 = (ConnectivityManager) context.getSystemService("connectivity");
                Network[] networks = connMgr2.getAllNetworks();
                StringBuilder sb = new StringBuilder();
                for (Network network : networks) {
                    NetworkInfo networkInfo = connMgr2.getNetworkInfo(network);
                    sb.append(networkInfo.getTypeName() + " connect is " + networkInfo.isConnected());
                }
                Toast.makeText(context, sb.toString(), 0).show();
            }
        }
    }
}
