package com.vendor.xzjh.settings.dbutils;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import com.vendor.xzjh.settings.bean.TimerEntries;
import com.vendor.xzjh.settings.constant.Constant;
import java.util.ArrayList;
import java.util.Collections;

public class PowerToolsDatabaseHelper extends SQLiteOpenHelper {
    private SQLiteDatabase db;
    Context mContext;

    public PowerToolsDatabaseHelper(Context context) {
        super(context, Constant.POWER_DATABASE_NAME, (SQLiteDatabase.CursorFactory) null, 1);
        this.mContext = context;
    }

    public void onCreate(SQLiteDatabase db2) {
        this.db = db2;
        for (int index = 0; index < Constant.mTableName.length; index++) {
            db2.execSQL(" create table if not exists " + Constant.mTableName[index] + " (_id integer primary key autoincrement, week text, powerontime text, powerofftime text, enable integer)");
        }
    }

    public void updateByPowerOnTime(int tableIndex, boolean checked, TimerEntries timer) {
        if (this.db == null) {
            this.db = getWritableDatabase();
        }
        ContentValues values = new ContentValues();
        values.put("week", Integer.valueOf(timer.getWeek()));
        values.put("powerontime", timer.getStringPowerOnTime());
        values.put("powerofftime", timer.getStringPowerOffTime());
        values.put("enable", Integer.valueOf(checked ? 1 : 0));
        this.db.update(Constant.mTableName[tableIndex], values, "powerontime=?", new String[]{timer.getStringPowerOnTime()});
    }

    public void insert(ContentValues values, String tableName) {
        if (this.db == null) {
            this.db = getWritableDatabase();
        }
        this.db.insert(tableName, null, values);
    }

    public Cursor query(String tableName) {
        if (this.db == null) {
            this.db = getWritableDatabase();
        }
        return this.db.query(tableName, null, null, null, null, null, null);
    }

    public ArrayList<TimerEntries> getDataBaseAllData() {
        ArrayList<TimerEntries> listTimer = new ArrayList<>();
        Cursor cursor = null;
        for (int index = 0; index < Constant.mTableName.length; index++) {
            cursor = query(Constant.mTableName[index]);
            if (cursor != null) {
                ArrayList<TimerEntries> tmpTimer = new ArrayList<>();
                while (cursor.moveToNext()) {
                    TimerEntries timer = new TimerEntries();
                    timer.setStringPowerOnTime(cursor.getString(cursor.getColumnIndex("powerontime")));
                    timer.setStringPowerOffTime(cursor.getString(cursor.getColumnIndex("powerofftime")));
                    tmpTimer.add(timer);
                }
                if (tmpTimer.size() > 0) {
                    Collections.sort(tmpTimer, $$Lambda$PowerToolsDatabaseHelper$hiqLWpUitS8Rawh2l8O02dF99w.INSTANCE);
                    listTimer.addAll(tmpTimer);
                }
            }
        }
        if (cursor != null) {
            cursor.close();
        }
        return listTimer;
    }

    static /* synthetic */ int lambda$getDataBaseAllData$0(Object lhs, Object rhs) {
        return ((TimerEntries) lhs).getStringPowerOffTime().compareTo(((TimerEntries) rhs).getStringPowerOffTime());
    }

    public int deleteTimer(int tableIndex, TimerEntries timer) {
        if (this.db == null) {
            this.db = getWritableDatabase();
        }
        return this.db.delete(Constant.mTableName[tableIndex], "powerontime=?", new String[]{timer.getStringPowerOnTime()});
    }

    public void onUpgrade(SQLiteDatabase sqLiteDatabase, int i, int i1) {
    }

    @Override // java.lang.AutoCloseable
    public void close() {
        SQLiteDatabase sQLiteDatabase = this.db;
        if (sQLiteDatabase != null) {
            sQLiteDatabase.close();
            this.db = null;
        }
    }
}
