package com.vendor.xzjh.settings.fragment;

import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import androidx.preference.Preference;
import androidx.preference.PreferenceFragmentCompat;
import androidx.preference.SwitchPreference;
import com.vendor.xzjh.settings.R;
import com.vendor.xzjh.settings.constant.SharePreferenceKey;
import com.vendor.xzjh.settings.constant.ViewKey;
import com.vendor.xzjh.settings.util.LogUtil;
import com.vendor.xzjh.settings.util.SharePreUtil;
import com.vendor.xzjh.settings.util.ToastUtil;
import com.vendor.xzjh.settings.view.EditTextDialog;

public class G4RouteSettingsFragment extends PreferenceFragmentCompat implements Preference.OnPreferenceChangeListener, Preference.OnPreferenceClickListener {
    private static final int DIALOG_ID_BEGIN_IP = 2;
    private static final int DIALOG_ID_DNS1 = 6;
    private static final int DIALOG_ID_DNS2 = 7;
    private static final int DIALOG_ID_END_IP = 3;
    private static final int DIALOG_ID_GW = 5;
    private static final int DIALOG_ID_IP = 1;
    private static final int DIALOG_ID_MASK = 4;
    private static final boolean IS_DEBUG = true;
    private static final String TAG = "G4RouteSettingsFragment";
    EditTextDialog mEditTextDialog;
    Preference mPF4gBeginIp;
    Preference mPF4gDns1;
    Preference mPF4gDns2;
    Preference mPF4gEndIp;
    Preference mPF4gGw;
    Preference mPF4gIp;
    Preference mPF4gMask;
    SwitchPreference mSP4gRoute;

    @Override // androidx.preference.PreferenceFragmentCompat
    public void onCreatePreferences(Bundle savedInstanceState, String rootKey) {
        setPreferencesFromResource(R.xml.g4route_settings_preferences, rootKey);
    }

    @Override // androidx.fragment.app.Fragment
    public void onResume() {
        super.onResume();
        initView();
    }

    private void initView() {
        if (this.mSP4gRoute == null) {
            SwitchPreference switchPreference = (SwitchPreference) findPreference(ViewKey.NETWORK_4G_ROUTE_FUNCTION_KEY);
            this.mSP4gRoute = switchPreference;
            switchPreference.setOnPreferenceChangeListener(this);
        }
        initPreference();
    }

    private void initPreference() {
        if (this.mPF4gIp == null) {
            Preference findPreference = findPreference(ViewKey.NETWORK_4G_ROUTE_IP_KEY);
            this.mPF4gIp = findPreference;
            findPreference.setOnPreferenceClickListener(this);
        }
        if (this.mPF4gBeginIp == null) {
            Preference findPreference2 = findPreference(ViewKey.NETWORK_4G_ROUTE_BEGIN_IP_KEY);
            this.mPF4gBeginIp = findPreference2;
            findPreference2.setOnPreferenceClickListener(this);
        }
        if (this.mPF4gEndIp == null) {
            Preference findPreference3 = findPreference(ViewKey.NETWORK_4G_ROUTE_END_IP_KEY);
            this.mPF4gEndIp = findPreference3;
            findPreference3.setOnPreferenceClickListener(this);
        }
        if (this.mPF4gMask == null) {
            Preference findPreference4 = findPreference(ViewKey.NETWORK_4G_ROUTE_MASK_KEY);
            this.mPF4gMask = findPreference4;
            findPreference4.setOnPreferenceClickListener(this);
        }
        if (this.mPF4gGw == null) {
            Preference findPreference5 = findPreference(ViewKey.NETWORK_4G_ROUTE_GW_KEY);
            this.mPF4gGw = findPreference5;
            findPreference5.setOnPreferenceClickListener(this);
        }
        if (this.mPF4gDns1 == null) {
            Preference findPreference6 = findPreference(ViewKey.NETWORK_4G_ROUTE_DNS1_KEY);
            this.mPF4gDns1 = findPreference6;
            findPreference6.setOnPreferenceClickListener(this);
        }
        if (this.mPF4gDns2 == null) {
            Preference findPreference7 = findPreference(ViewKey.NETWORK_4G_ROUTE_DNS2_KEY);
            this.mPF4gDns2 = findPreference7;
            findPreference7.setOnPreferenceClickListener(this);
        }
    }

    @Override // androidx.fragment.app.Fragment
    public void onPause() {
        super.onPause();
    }

    @Override // androidx.fragment.app.Fragment
    public void onDestroy() {
        super.onDestroy();
    }

    @Override // androidx.preference.Preference.OnPreferenceChangeListener
    public boolean onPreferenceChange(Preference preference, Object newValue) {
        String key = preference.getKey();
        LogUtil.LogI(TAG, IS_DEBUG, "key: " + key);
        if (!key.equals(ViewKey.NETWORK_4G_ROUTE_FUNCTION_KEY)) {
            return false;
        }
        SharePreUtil.getInstance().setValue(SharePreferenceKey.SP_G4_ROUTE_KEY, Boolean.valueOf(((Boolean) newValue).booleanValue()));
        return IS_DEBUG;
    }

    @Override // androidx.preference.Preference.OnPreferenceClickListener
    public boolean onPreferenceClick(Preference preference) {
        String key = preference.getKey();
        if (key.equals(ViewKey.NETWORK_4G_ROUTE_IP_KEY)) {
            showEdit4gRouteDialog(1, getActivity().getResources().getString(R.string.input_4g_route_ip), String.format(getActivity().getResources().getString(R.string.input_msg_is_null), getActivity().getResources().getString(R.string.network_4g_route_ip)), String.format(getActivity().getResources().getString(R.string.input_msg_is_illeagal), getActivity().getResources().getString(R.string.network_4g_route_ip)));
        } else if (key.equals(ViewKey.NETWORK_4G_ROUTE_BEGIN_IP_KEY)) {
            showEdit4gRouteDialog(1, getActivity().getResources().getString(R.string.input_4g_route_begin_ip), String.format(getActivity().getResources().getString(R.string.input_msg_is_null), getActivity().getResources().getString(R.string.network_4g_route_begin_ip)), String.format(getActivity().getResources().getString(R.string.input_msg_is_illeagal), getActivity().getResources().getString(R.string.network_4g_route_begin_ip)));
        } else if (key.equals(ViewKey.NETWORK_4G_ROUTE_END_IP_KEY)) {
            showEdit4gRouteDialog(1, getActivity().getResources().getString(R.string.input_4g_route_end_ip), String.format(getActivity().getResources().getString(R.string.input_msg_is_null), getActivity().getResources().getString(R.string.network_4g_route_end_ip)), String.format(getActivity().getResources().getString(R.string.input_msg_is_illeagal), getActivity().getResources().getString(R.string.network_4g_route_end_ip)));
        } else if (key.equals(ViewKey.NETWORK_4G_ROUTE_MASK_KEY)) {
            showEdit4gRouteDialog(1, getActivity().getResources().getString(R.string.input_4g_route_mask), String.format(getActivity().getResources().getString(R.string.input_msg_is_null), getActivity().getResources().getString(R.string.network_4g_route_mask)), String.format(getActivity().getResources().getString(R.string.input_msg_is_illeagal), getActivity().getResources().getString(R.string.network_4g_route_mask)));
        } else if (key.equals(ViewKey.NETWORK_4G_ROUTE_GW_KEY)) {
            showEdit4gRouteDialog(1, getActivity().getResources().getString(R.string.input_4g_route_gw), String.format(getActivity().getResources().getString(R.string.input_msg_is_null), getActivity().getResources().getString(R.string.network_4g_route_gw)), String.format(getActivity().getResources().getString(R.string.input_msg_is_illeagal), getActivity().getResources().getString(R.string.network_4g_route_gw)));
        } else if (key.equals(ViewKey.NETWORK_4G_ROUTE_DNS1_KEY)) {
            showEdit4gRouteDialog(1, getActivity().getResources().getString(R.string.input_4g_route_dns1), String.format(getActivity().getResources().getString(R.string.input_msg_is_null), getActivity().getResources().getString(R.string.network_4g_route_dn1)), String.format(getActivity().getResources().getString(R.string.input_msg_is_illeagal), getActivity().getResources().getString(R.string.network_4g_route_dn1)));
        } else if (key.equals(ViewKey.NETWORK_4G_ROUTE_DNS2_KEY)) {
            showEdit4gRouteDialog(1, getActivity().getResources().getString(R.string.input_4g_route_dns2), String.format(getActivity().getResources().getString(R.string.input_msg_is_null), getActivity().getResources().getString(R.string.network_4g_route_dn2)), String.format(getActivity().getResources().getString(R.string.input_msg_is_illeagal), getActivity().getResources().getString(R.string.network_4g_route_dn2)));
        }
        return false;
    }

    private void showEdit4gRouteDialog(int dialogId, String dialogTitle, String nullMsg, String illegalMsg) {
        if (this.mEditTextDialog == null) {
            this.mEditTextDialog = new EditTextDialog(getActivity());
        }
        this.mEditTextDialog.setTv(dialogTitle);
        this.mEditTextDialog.setOnExitListener(new View.OnClickListener(dialogId, nullMsg) {
            /* class com.vendor.xzjh.settings.fragment.$$Lambda$G4RouteSettingsFragment$ufXFwX1hnDDHFwayPWD5I5x2KuM */
            public final /* synthetic */ int f$1;
            public final /* synthetic */ String f$2;

            {
                this.f$1 = r2;
                this.f$2 = r3;
            }

            public final void onClick(View view) {
                G4RouteSettingsFragment.this.lambda$showEdit4gRouteDialog$0$G4RouteSettingsFragment(this.f$1, this.f$2, view);
            }
        });
        this.mEditTextDialog.setOnCancelListener(new View.OnClickListener() {
            /* class com.vendor.xzjh.settings.fragment.$$Lambda$G4RouteSettingsFragment$TxQPzHRsOZQgv9087BJ0pCiv6eE */

            public final void onClick(View view) {
                G4RouteSettingsFragment.this.lambda$showEdit4gRouteDialog$1$G4RouteSettingsFragment(view);
            }
        });
        this.mEditTextDialog.show();
    }

    public /* synthetic */ void lambda$showEdit4gRouteDialog$0$G4RouteSettingsFragment(int dialogId, String nullMsg, View view) {
        this.mEditTextDialog.dismiss();
        String inputMsg = this.mEditTextDialog.getEditTextMsg();
        if (TextUtils.isEmpty(inputMsg)) {
            ToastUtil.toastUtil(getActivity(), nullMsg);
        } else if (dialogId != 1) {
            if (dialogId == 2) {
                LogUtil.LogI(TAG, IS_DEBUG, "device serial number : " + inputMsg);
            } else if (dialogId == 3) {
                LogUtil.LogI(TAG, IS_DEBUG, "device model name : " + inputMsg);
            } else if (dialogId == 4) {
                LogUtil.LogI(TAG, IS_DEBUG, "device model name : " + inputMsg);
            } else if (dialogId == 5) {
                LogUtil.LogI(TAG, IS_DEBUG, "device model name : " + inputMsg);
            } else if (dialogId == 6) {
                LogUtil.LogI(TAG, IS_DEBUG, "device model name : " + inputMsg);
            } else if (dialogId == 7) {
                LogUtil.LogI(TAG, IS_DEBUG, "device model name : " + inputMsg);
            }
        }
    }

    public /* synthetic */ void lambda$showEdit4gRouteDialog$1$G4RouteSettingsFragment(View view) {
        this.mEditTextDialog.dismiss();
    }
}
