package com.vendor.xzjh.settings.fragment;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import androidx.preference.ListPreference;
import androidx.preference.Preference;
import androidx.preference.PreferenceFragmentCompat;
import com.vendor.xzjh.settings.R;
import com.vendor.xzjh.settings.constant.Constant;
import com.vendor.xzjh.settings.constant.PreferenceView;
import com.vendor.xzjh.settings.constant.ViewKey;
import com.vendor.xzjh.settings.util.LogUtil;
import com.vendor.xzjh.settings.view.LoadingDialog;
import java.util.Arrays;

public class PowerSettingsFragment extends PreferenceFragmentCompat implements Preference.OnPreferenceClickListener, Preference.OnPreferenceChangeListener {
    private static final boolean IS_DEBUG = true;
    private static final String TAG = "PowerSettingsFragment";
    int mAlarmPowerOnOffMode = 0;
    Context mCxt;
    Handler mHandler = new Handler() {
        /* class com.vendor.xzjh.settings.fragment.PowerSettingsFragment.AnonymousClass1 */

        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            if (msg.what == 1) {
                PreferenceView.mLPPowerMode.setSummary(PreferenceView.mLPPowerMode.getEntries()[PowerSettingsFragment.this.mAlarmPowerOnOffMode]);
                PreferenceView.mLPPowerMode.setValueIndex(PowerSettingsFragment.this.mAlarmPowerOnOffMode);
                PowerSettingsFragment powerSettingsFragment = PowerSettingsFragment.this;
                powerSettingsFragment.init_all_power_mode_enable_status(powerSettingsFragment.mAlarmPowerOnOffMode);
                if (PowerSettingsFragment.this.mLoadingDialog != null) {
                    PowerSettingsFragment.this.mLoadingDialog.dismiss();
                    PowerSettingsFragment.this.mLoadingDialog = null;
                }
            }
        }
    };
    LoadingDialog mLoadingDialog;

    @Override // androidx.preference.PreferenceFragmentCompat
    public void onCreatePreferences(Bundle savedInstanceState, String rootKey) {
        setPreferencesFromResource(R.xml.power_settings_fragment, rootKey);
        this.mCxt = getActivity();
    }

    @Override // androidx.fragment.app.Fragment
    public void onResume() {
        super.onResume();
        showLoadingDialog();
        initview();
        new GetDataThread().start();
        getDeviceData();
    }

    private void showLoadingDialog() {
        LoadingDialog loadingDialog = new LoadingDialog(getActivity());
        this.mLoadingDialog = loadingDialog;
        loadingDialog.setCanceledOnTouchOutside(false);
        this.mLoadingDialog.setTip(getString(R.string.getting_info));
        this.mLoadingDialog.show();
    }

    private void initview() {
        PreferenceView.mPFPowerModeSingle = findPreference(ViewKey.POWER_MODE_SINGLE_KEY);
        PreferenceView.mPFPowerModeEveryDay = findPreference(ViewKey.POWER_MODE_EVERY_DAY_KEY);
        PreferenceView.mPFPowerModeCycle = findPreference(ViewKey.POWER_MODE_CYCLE_KEY);
        PreferenceView.mLPPowerMode = (ListPreference) findPreference(ViewKey.POWER_MODE_KEY);
        PreferenceView.mLPPowerMode.setOnPreferenceChangeListener(this);
        PreferenceView.mLPPowerMode.setSummary(PreferenceView.mLPPowerMode.getEntry());
        int index = Arrays.asList(PreferenceView.mLPPowerMode.getEntries()).indexOf(PreferenceView.mLPPowerMode.getEntry());
        LogUtil.LogE(TAG, IS_DEBUG, "======== index " + index + " ========");
        init_all_power_mode_enable_status(index);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void init_all_power_mode_enable_status(int index) {
        if (index == 0) {
            PreferenceView.mPFPowerModeSingle.setEnabled(false);
            PreferenceView.mPFPowerModeEveryDay.setEnabled(false);
            PreferenceView.mPFPowerModeCycle.setEnabled(false);
        } else if (index == 1) {
            PreferenceView.mPFPowerModeSingle.setEnabled(IS_DEBUG);
            PreferenceView.mPFPowerModeEveryDay.setEnabled(false);
            PreferenceView.mPFPowerModeCycle.setEnabled(false);
        } else if (index == 2) {
            PreferenceView.mPFPowerModeSingle.setEnabled(false);
            PreferenceView.mPFPowerModeEveryDay.setEnabled(IS_DEBUG);
            PreferenceView.mPFPowerModeCycle.setEnabled(false);
        } else if (index == 3) {
            PreferenceView.mPFPowerModeSingle.setEnabled(false);
            PreferenceView.mPFPowerModeEveryDay.setEnabled(false);
            PreferenceView.mPFPowerModeCycle.setEnabled(IS_DEBUG);
        }
    }

    @Override // androidx.preference.Preference.OnPreferenceClickListener
    public boolean onPreferenceClick(Preference preference) {
        return false;
    }

    @Override // androidx.preference.Preference.OnPreferenceChangeListener
    public boolean onPreferenceChange(Preference preference, Object newValue) {
        if (!preference.getKey().equals(ViewKey.POWER_MODE_KEY)) {
            return false;
        }
        CharSequence[] entries = PreferenceView.mLPPowerMode.getEntries();
        this.mAlarmPowerOnOffMode = Integer.parseInt((String) newValue);
        PreferenceView.mLPPowerMode.setSummary(entries[this.mAlarmPowerOnOffMode]);
        PreferenceView.mLPPowerMode.setValueIndex(this.mAlarmPowerOnOffMode);
        init_all_power_mode_enable_status(this.mAlarmPowerOnOffMode);
        Constant.mManager.xzjhSetAlarmPowerOnOffMode(this.mAlarmPowerOnOffMode);
        return false;
    }

    private void getDeviceData() {
    }

    class GetDataThread extends Thread {
        GetDataThread() {
        }

        public void run() {
            super.run();
            PowerSettingsFragment.this.mAlarmPowerOnOffMode = Constant.mManager.xzjhGetAlarmPowerOnOffMode();
            PowerSettingsFragment.this.mHandler.sendEmptyMessage(1);
        }
    }
}
