package com.vendor.xzjh.settings.fragment;

import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.View;
import androidx.preference.ListPreference;
import androidx.preference.Preference;
import androidx.preference.PreferenceFragmentCompat;
import androidx.preference.SwitchPreference;
import com.vendor.xzjh.settings.R;
import com.vendor.xzjh.settings.constant.Constant;
import com.vendor.xzjh.settings.constant.PreferenceView;
import com.vendor.xzjh.settings.constant.SharePreferenceKey;
import com.vendor.xzjh.settings.constant.ViewKey;
import com.vendor.xzjh.settings.service.SysLogService;
import com.vendor.xzjh.settings.util.ClearAppDataUtil;
import com.vendor.xzjh.settings.util.FileUtil;
import com.vendor.xzjh.settings.util.LogUtil;
import com.vendor.xzjh.settings.util.ScreenUtil;
import com.vendor.xzjh.settings.util.SharePreUtil;
import com.vendor.xzjh.settings.util.ToastUtil;
import com.vendor.xzjh.settings.view.CustomDialog;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class SettingsFragment extends PreferenceFragmentCompat implements Preference.OnPreferenceChangeListener, Preference.OnPreferenceClickListener {
    private static final String FILENAME_PROC_VERSION = "/proc/version";
    public static final int HANDLE_START_LOGCATTHREAD = 0;
    private static final boolean IS_DEBUG = true;
    private static final String TAG = "SettingsFragment";
    static boolean mNetworkAdb = false;
    static int mRotation = 0;
    static int mScreenDensityCurrentIndex = 2;
    static int mScreenDensitySetIndex = 0;
    CustomDialog mCustomDialog;
    Context mCxt;
    CharSequence[] mDensityEntries;
    Handler mHandler = new Handler() {
        /* class com.vendor.xzjh.settings.fragment.SettingsFragment.AnonymousClass1 */

        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            if (msg.what == 0) {
                boolean isChecked = ((Boolean) msg.obj).booleanValue();
                LogUtil.LogI(SettingsFragment.TAG, SettingsFragment.IS_DEBUG, "isChecked: " + isChecked);
                if (!isChecked) {
                    SettingsFragment.this.mCxt.stopService(new Intent(SettingsFragment.this.mCxt, SysLogService.class));
                } else if (Build.VERSION.SDK_INT >= 26) {
                    SettingsFragment.this.mCxt.startForegroundService(new Intent(SettingsFragment.this.mCxt, SysLogService.class));
                } else {
                    SettingsFragment.this.mCxt.startService(new Intent(SettingsFragment.this.mCxt, SysLogService.class));
                }
            }
        }
    };
    CharSequence[] mRotationEntries;

    @Override // androidx.preference.PreferenceFragmentCompat
    public void onCreatePreferences(Bundle savedInstanceState, String rootKey) {
        setPreferencesFromResource(R.xml.root_preferences, rootKey);
        this.mCxt = getActivity();
    }

    private void initView() {
        initPreference();
        this.mCustomDialog = new CustomDialog(getContext());
        initData();
    }

    private void initData() {
        PreferenceView.mPFScreenResolution.setSummary(ScreenUtil.getCurrentScreenResolution(getActivity()));
        boolean updateAutoFile_enable = false;
        if (!Constant.mManager.xzjhChangeDensity()) {
            PreferenceView.mLPScreenDensity.setEnabled(false);
        } else {
            CharSequence[] entries = PreferenceView.mLPScreenDensity.getEntries();
            this.mDensityEntries = entries;
            List list = Arrays.asList(entries);
            mScreenDensityCurrentIndex = list.indexOf(Constant.mManager.xzjhGetScreenDensity() + " " + PreferenceView.mLPScreenDensity.getEntry().toString().split(" ")[1]);
            PreferenceView.mLPScreenDensity.setSummary(this.mDensityEntries[mScreenDensityCurrentIndex]);
            PreferenceView.mLPScreenDensity.setValueIndex(mScreenDensityCurrentIndex);
        }
        this.mRotationEntries = PreferenceView.mLPScreenOrientation.getEntries();
        mRotation = Constant.mManager.xzjhGetScreenRotation();
        PreferenceView.mLPScreenOrientation.setSummary(this.mRotationEntries[mRotation]);
        PreferenceView.mLPScreenOrientation.setValueIndex(mRotation);
        PreferenceView.mSPBackLightMirror.setChecked(Constant.mManager.xzjhGetBacklightMirrorStatus() == 0 ? false : IS_DEBUG);
        mNetworkAdb = Constant.mManager.xzjhGetNetworkAdbEnable();
        PreferenceView.mSPNetwork.setChecked(mNetworkAdb);
        PreferenceView.mSPOtgToUsb.setChecked(Constant.mManager.xzjhGetOtgToUsbStatus() == 0 ? false : IS_DEBUG);
        Date time = new Date(Build.TIME);
        SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd HH:mm");
        Preference preference = PreferenceView.mPFDeviceVendorId;
        preference.setSummary("SDS " + getFirmwareVersion() + " #" + formatter.format(time));
        boolean logInfoOpen_enable = Constant.mManager.xzjhGetLogInfoOpenStatus() == 0 ? false : IS_DEBUG;
        LogUtil.LogE(TAG, IS_DEBUG, "==== logInfoOpen_enable = " + logInfoOpen_enable + " ====");
        PreferenceView.mSPLogOpen.setChecked(logInfoOpen_enable);
        boolean logInfoAutoOpen_enable = Constant.mManager.xzjhGetLogInfoAutoOpenStatus() == 0 ? false : IS_DEBUG;
        LogUtil.LogE(TAG, IS_DEBUG, "==== logInfoAutoOpen_enable = " + logInfoAutoOpen_enable + " ====");
        PreferenceView.mSPLogAutoOpen.setChecked(logInfoAutoOpen_enable);
        PreferenceView.mSPUpdateAutoOta.setChecked(Constant.mManager.xzjhGetAutoUpdateOtaStatus() == 0 ? false : IS_DEBUG);
        if (Constant.mManager.xzjhGetAutoUpdateFileStatus() != 0) {
            updateAutoFile_enable = IS_DEBUG;
        }
        PreferenceView.mSPUpdateAutoFile.setChecked(updateAutoFile_enable);
    }

    private void initPreference() {
        PreferenceView.mPFScreenResolution = findPreference(ViewKey.SCREEN_RESOLUTION);
        PreferenceView.mLPScreenDensity = (ListPreference) findPreference(ViewKey.SCREEN_DENSITY_KEY);
        PreferenceView.mLPScreenDensity.setOnPreferenceChangeListener(this);
        PreferenceView.mLPScreenOrientation = (ListPreference) findPreference(ViewKey.SCREEN_ORIENTATION_KEY);
        PreferenceView.mLPScreenOrientation.setOnPreferenceChangeListener(this);
        PreferenceView.mSPBackLightMirror = (SwitchPreference) findPreference(ViewKey.SCREEN_BACKLIGHT_MIRROR_KEY);
        PreferenceView.mSPBackLightMirror.setOnPreferenceChangeListener(this);
        PreferenceView.mSPNetwork = (SwitchPreference) findPreference(ViewKey.NETWORK_ADB_KEY);
        PreferenceView.mSPNetwork.setOnPreferenceChangeListener(this);
        PreferenceView.mSPOtgToUsb = (SwitchPreference) findPreference(ViewKey.OTG_TO_USB_KEY);
        PreferenceView.mSPOtgToUsb.setOnPreferenceChangeListener(this);
        PreferenceView.mPFShutDown = findPreference(ViewKey.SHUTDOWN_KEY);
        PreferenceView.mPFShutDown.setOnPreferenceClickListener(this);
        PreferenceView.mPFRebootDev = findPreference(ViewKey.REBOOT_DEV_KEY);
        PreferenceView.mPFRebootDev.setOnPreferenceClickListener(this);
        PreferenceView.mPFResetSys = findPreference(ViewKey.RESET_SYS_KEY);
        PreferenceView.mPFResetSys.setOnPreferenceClickListener(this);
        PreferenceView.mPFDeviceVendorId = findPreference(ViewKey.DEVICE_VENDOR_ID_KEY);
        PreferenceView.mSPLogOpen = (SwitchPreference) findPreference(ViewKey.LOG_OPEN_KEY);
        PreferenceView.mSPLogOpen.setOnPreferenceChangeListener(this);
        PreferenceView.mSPLogAutoOpen = (SwitchPreference) findPreference(ViewKey.LOG_AUTO_OPEN_KEY);
        PreferenceView.mSPLogAutoOpen.setOnPreferenceChangeListener(this);
        PreferenceView.mSPUpdateAutoOta = (SwitchPreference) findPreference(ViewKey.UPDATE_AUTO_OTA_KEY);
        PreferenceView.mSPUpdateAutoOta.setOnPreferenceChangeListener(this);
        PreferenceView.mSPUpdateAutoFile = (SwitchPreference) findPreference(ViewKey.UPDATE_AUTO_FILE_KEY);
        PreferenceView.mSPUpdateAutoFile.setOnPreferenceChangeListener(this);
    }

    @Override // androidx.preference.Preference.OnPreferenceChangeListener
    public boolean onPreferenceChange(Preference preference, Object newValue) {
        String key = preference.getKey();
        if (key.equals(ViewKey.SCREEN_DENSITY_KEY)) {
            int index = Integer.parseInt((String) newValue);
            if (mScreenDensityCurrentIndex != index) {
                mScreenDensitySetIndex = index;
                showCustomDialog(getString(R.string.change_density_reboot_msg), 4);
            }
            return IS_DEBUG;
        } else if (key.equals(ViewKey.SCREEN_ORIENTATION_KEY)) {
            int index2 = Integer.parseInt((String) newValue);
            PreferenceView.mLPScreenOrientation.setSummary(this.mRotationEntries[index2]);
            PreferenceView.mLPScreenOrientation.setValueIndex(index2);
            Constant.mManager.xzjhSetScreenRotation(index2);
            return IS_DEBUG;
        } else if (key.equals(ViewKey.SCREEN_BACKLIGHT_MIRROR_KEY)) {
            Constant.mManager.xzjhSetBacklightMirrorStatus(((Boolean) newValue).booleanValue() ? 1 : 0);
            return IS_DEBUG;
        } else if (key.equals(ViewKey.NETWORK_ADB_KEY)) {
            Constant.mManager.xzjhSetNetworkAdbEnable(((Boolean) newValue).booleanValue());
            return IS_DEBUG;
        } else if (key.equals(ViewKey.OTG_TO_USB_KEY)) {
            Constant.mManager.xzjhSetOtgToUsbStatus(((Boolean) newValue).booleanValue() ? 1 : 0);
            return IS_DEBUG;
        } else if (key.equals(ViewKey.POWER_INFO_BOOT_SHOW_KEY)) {
            SharePreUtil.getInstance().setValue(SharePreferenceKey.SP_SHOW_POWER_ON_OFF_INFO_KEY, Boolean.valueOf(((Boolean) newValue).booleanValue()));
            return IS_DEBUG;
        } else if (key.equals(ViewKey.LOG_OPEN_KEY)) {
            boolean isChecked = ((Boolean) newValue).booleanValue();
            Constant.mManager.xzjhSetLogInfoOpenStatus(isChecked ? 1 : 0);
            Message msg = this.mHandler.obtainMessage();
            msg.what = 0;
            msg.obj = Boolean.valueOf(isChecked);
            this.mHandler.sendMessage(msg);
            return IS_DEBUG;
        } else if (key.equals(ViewKey.LOG_AUTO_OPEN_KEY)) {
            Constant.mManager.xzjhSetLogInfoAutoOpenStatus(((Boolean) newValue).booleanValue() ? 1 : 0);
            return IS_DEBUG;
        } else if (key.equals(ViewKey.UPDATE_AUTO_OTA_KEY)) {
            Constant.mManager.xzjhSetAutoUpdateOtaStatus(((Boolean) newValue).booleanValue() ? 1 : 0);
            return IS_DEBUG;
        } else if (!key.equals(ViewKey.UPDATE_AUTO_FILE_KEY)) {
            return false;
        } else {
            Constant.mManager.xzjhSetAutoUpdateFileStatus(((Boolean) newValue).booleanValue() ? 1 : 0);
            return IS_DEBUG;
        }
    }

    @Override // androidx.preference.Preference.OnPreferenceClickListener
    public boolean onPreferenceClick(Preference preference) {
        String key = preference.getKey();
        if (key.equals(ViewKey.SHUTDOWN_KEY)) {
            showCustomDialog(getString(R.string.shutdown_info), 0);
        } else if (key.equals(ViewKey.REBOOT_DEV_KEY)) {
            showCustomDialog(getString(R.string.reboot_dev_info), 1);
        } else if (key.equals(ViewKey.RESET_SYS_KEY)) {
            showCustomDialog(getString(R.string.reset_sys_info), 2);
        } else if (key.equals(ViewKey.CLEAR_SETTINS_DATA_KEY)) {
            showCustomDialog(getString(R.string.clear_app_data), 3);
            ClearAppDataUtil.clearAppData();
        }
        return false;
    }

    private void showCustomDialog(String dialogMsg, int type) {
        dismissCustomDialog();
        if (this.mCustomDialog == null) {
            this.mCustomDialog = new CustomDialog(getContext());
        }
        this.mCustomDialog.setTv(dialogMsg);
        this.mCustomDialog.setOnExitListener(new View.OnClickListener(type) {
            /* class com.vendor.xzjh.settings.fragment.$$Lambda$SettingsFragment$nrRead3yxYo07bJ7SwIzpRfaww */
            public final /* synthetic */ int f$1;

            {
                this.f$1 = r2;
            }

            public final void onClick(View view) {
                SettingsFragment.this.lambda$showCustomDialog$0$SettingsFragment(this.f$1, view);
            }
        });
        this.mCustomDialog.setOnCancelListener(new View.OnClickListener() {
            /* class com.vendor.xzjh.settings.fragment.$$Lambda$SettingsFragment$2Zq8_1sBAIfsTyY16nhaPEwI3Uc */

            public final void onClick(View view) {
                SettingsFragment.this.lambda$showCustomDialog$1$SettingsFragment(view);
            }
        });
        this.mCustomDialog.show();
    }

    public /* synthetic */ void lambda$showCustomDialog$0$SettingsFragment(int type, View view) {
        if (type == 0) {
            Constant.mManager.xzjhShutdownSys(false);
        } else if (type == 1) {
            Constant.mManager.xzjhRebootSys(false);
        } else if (type == 2) {
            ToastUtil.toastUtil(getContext(), "you click reset");
            Constant.mManager.xzjhResetSys();
        } else if (type == 4) {
            int mScreenDensity = Integer.parseInt(this.mDensityEntries[mScreenDensitySetIndex].toString().split(" ")[0]);
            mScreenDensityCurrentIndex = mScreenDensitySetIndex;
            Constant.mManager.xzjhSetScreenDensity(mScreenDensity);
            Constant.mManager.xzjhRebootSys(false);
        }
        this.mCustomDialog.dismiss();
    }

    public /* synthetic */ void lambda$showCustomDialog$1$SettingsFragment(View view) {
        this.mCustomDialog.dismiss();
    }

    private void dismissCustomDialog() {
        CustomDialog customDialog = this.mCustomDialog;
        if (customDialog != null && customDialog.isShowing()) {
            this.mCustomDialog.dismiss();
        }
    }

    @Override // androidx.fragment.app.Fragment
    public void onResume() {
        super.onResume();
        initView();
    }

    @Override // androidx.fragment.app.Fragment
    public void onPause() {
        super.onPause();
    }

    private String getFirmwareVersion() {
        try {
            return formatKernelVersion(FileUtil.readLine(FILENAME_PROC_VERSION));
        } catch (IOException ex) {
            LogUtil.LogE(TAG, IS_DEBUG, " ----- Exception ----- " + ex.toString());
            return Constant.DEFAULT_PACKAGE_NAME;
        }
    }

    private String formatKernelVersion(String rawKernelVersion) {
        Matcher m = Pattern.compile("Linux version (\\S+) \\((\\S+?)\\) (?:\\(gcc.+? \\)) (#\\d+) (?:.*?)?((Sun|Mon|Tue|Wed|Thu|Fri|Sat).+)").matcher(rawKernelVersion);
        if (!m.matches()) {
            LogUtil.LogE(TAG, IS_DEBUG, "Regex did not match on /proc/version: " + rawKernelVersion);
            return "Unavailable";
        } else if (m.groupCount() >= 4) {
            return m.group(3);
        } else {
            LogUtil.LogE(TAG, IS_DEBUG, "Regex match on /proc/version only returned " + m.groupCount() + " groups");
            return "Unavailable";
        }
    }
}
