package com.vendor.xzjh.settings.helpler;

import android.content.Context;
import android.os.Handler;
import android.os.Process;
import com.vendor.xzjh.settings.util.FileUtil;
import com.vendor.xzjh.settings.util.LogUtil;
import com.vendor.xzjh.settings.util.ShellUtils;
import com.vendor.xzjh.settings.util.TimeUtil;
import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;

public class LogcatHelper {
    private static final int MAX_FILE_SIZE = 5;
    private static final String TAG = "LogcatHelper";
    static int mCountTime = 0;
    private static Context mCxt;
    private static Handler mHandler;
    private static LogcatHelper mInstance = null;
    private static String mLogcatPath = null;
    private boolean IS_DEBUG;
    private LogcatDumper mLogcatDumper;
    private int mPid;

    public LogcatHelper() {
        this.IS_DEBUG = true;
        this.mLogcatDumper = null;
        this.mPid = -1;
        this.mPid = Process.myPid();
    }

    public static LogcatHelper getInstance(Context context, Handler handler, String path) {
        mCxt = context;
        mHandler = handler;
        mLogcatPath = path;
        if (mInstance == null) {
            mInstance = new LogcatHelper();
        }
        return mInstance;
    }

    public void start() {
        if (this.mLogcatDumper == null) {
            this.mLogcatDumper = new LogcatDumper(String.valueOf(this.mPid), mLogcatPath);
        }
        this.mLogcatDumper.start();
    }

    public void stop() {
        LogcatDumper logcatDumper = this.mLogcatDumper;
        if (logcatDumper != null) {
            logcatDumper.stopLogs();
            this.mLogcatDumper = null;
        }
    }

    /* access modifiers changed from: private */
    public class LogcatDumper extends Thread {
        String mCmds;
        private File mFileLog = null;
        private FileOutputStream mFos = null;
        private String mLogDir;
        private Process mLogcatProc;
        private String mPid;
        private BufferedReader mReader = null;
        private boolean mRunning = true;

        public LogcatDumper(String pid, String logcatDir) {
            this.mPid = pid;
            this.mLogDir = logcatDir;
            try {
                String fileName = "logcat-" + TimeUtil.getCurrentTimeOrDataByFormat("yyyyMMdd_HHmmss") + ".log";
                FileUtil.createFile(logcatDir, fileName);
                this.mFileLog = new File(logcatDir, fileName);
                this.mFos = new FileOutputStream(this.mFileLog);
                LogUtil.LogI(LogcatHelper.TAG, LogcatHelper.this.IS_DEBUG, "LogcatHelper:great file logcat file success, mFileLog = " + this.mFileLog);
            } catch (FileNotFoundException e) {
                e.printStackTrace();
                LogUtil.LogE(LogcatHelper.TAG, LogcatHelper.this.IS_DEBUG, "FileNotFoundException: " + e.toString());
            }
            this.mCmds = "logcat -v time";
            FileUtil.fileLogList(this.mLogDir);
        }

        public void stopLogs() {
            this.mRunning = false;
        }

        public void run() {
            StringBuilder sb;
            boolean z;
            IOException e;
            super.run();
            try {
                this.mLogcatProc = Runtime.getRuntime().exec(ShellUtils.COMMAND_SU);
                DataOutputStream dos = new DataOutputStream(this.mLogcatProc.getOutputStream());
                dos.writeBytes("adb root\n");
                dos.writeBytes("adb remount\n");
                dos.writeBytes("adb shell\n");
                if (LogcatHelper.mCountTime > 0) {
                    dos.writeBytes("logcat -c\n");
                }
                dos.writeBytes(this.mCmds + ShellUtils.COMMAND_LINE_END);
                dos.writeBytes(ShellUtils.COMMAND_EXIT);
                dos.flush();
                this.mReader = new BufferedReader(new InputStreamReader(this.mLogcatProc.getInputStream()), 1024);
                while (true) {
                    boolean z2 = this.mRunning;
                    if (z2) {
                        if (!z2) {
                            break;
                        }
                        String line = this.mReader.readLine();
                        if (line != null) {
                            if (line.length() == 0) {
                                break;
                            }
                            FileOutputStream fileOutputStream = this.mFos;
                            if (fileOutputStream != null) {
                                fileOutputStream.write((line + ShellUtils.COMMAND_LINE_END).getBytes());
                                if (this.mFileLog.length() >= 5242880) {
                                    FileUtil.fileLogList(this.mLogDir);
                                    if (this.mRunning) {
                                        LogcatHelper.mCountTime++;
                                        LogcatHelper.mHandler.sendEmptyMessage(2);
                                    }
                                    this.mRunning = false;
                                }
                            }
                        }
                    }
                }
                try {
                    Process process = this.mLogcatProc;
                    if (process != null) {
                        process.destroy();
                        this.mLogcatProc = null;
                    }
                    BufferedReader bufferedReader = this.mReader;
                    if (bufferedReader != null) {
                        bufferedReader.close();
                        this.mReader = null;
                    }
                    FileOutputStream fileOutputStream2 = this.mFos;
                    if (fileOutputStream2 != null) {
                        fileOutputStream2.close();
                        this.mFos = null;
                    }
                } catch (IOException e2) {
                    e = e2;
                    e.printStackTrace();
                    z = LogcatHelper.this.IS_DEBUG;
                    sb = new StringBuilder();
                    sb.append("11 --- IOException: ");
                    sb.append(e.toString());
                    LogUtil.LogE(LogcatHelper.TAG, z, sb.toString());
                }
            } catch (IOException e3) {
                e3.printStackTrace();
                LogUtil.LogE(LogcatHelper.TAG, LogcatHelper.this.IS_DEBUG, "00 --- IOException: " + e3.toString());
                try {
                    Process process2 = this.mLogcatProc;
                    if (process2 != null) {
                        process2.destroy();
                        this.mLogcatProc = null;
                    }
                    BufferedReader bufferedReader2 = this.mReader;
                    if (bufferedReader2 != null) {
                        bufferedReader2.close();
                        this.mReader = null;
                    }
                    FileOutputStream fileOutputStream3 = this.mFos;
                    if (fileOutputStream3 != null) {
                        fileOutputStream3.close();
                        this.mFos = null;
                    }
                } catch (IOException e4) {
                    e = e4;
                    e.printStackTrace();
                    z = LogcatHelper.this.IS_DEBUG;
                    sb = new StringBuilder();
                    sb.append("11 --- IOException: ");
                    sb.append(e.toString());
                    LogUtil.LogE(LogcatHelper.TAG, z, sb.toString());
                }
            } catch (Throwable e5) {
                try {
                    Process process3 = this.mLogcatProc;
                    if (process3 != null) {
                        process3.destroy();
                        this.mLogcatProc = null;
                    }
                    BufferedReader bufferedReader3 = this.mReader;
                    if (bufferedReader3 != null) {
                        bufferedReader3.close();
                        this.mReader = null;
                    }
                    FileOutputStream fileOutputStream4 = this.mFos;
                    if (fileOutputStream4 != null) {
                        fileOutputStream4.close();
                        this.mFos = null;
                    }
                } catch (IOException e6) {
                    e6.printStackTrace();
                    LogUtil.LogE(LogcatHelper.TAG, LogcatHelper.this.IS_DEBUG, "11 --- IOException: " + e6.toString());
                }
                throw e5;
            }
        }
    }
}
