package com.vendor.xzjh.settings.receiver;

import android.app.ActivityManager;
import android.content.BroadcastReceiver;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.os.Build;
import android.view.View;
import com.vendor.xzjh.settings.BuildConfig;
import com.vendor.xzjh.settings.R;
import com.vendor.xzjh.settings.SettingsActivity;
import com.vendor.xzjh.settings.constant.Constant;
import com.vendor.xzjh.settings.constant.SharePreferenceKey;
import com.vendor.xzjh.settings.service.OtaUpdateService;
import com.vendor.xzjh.settings.service.ShowCountDownDialog;
import com.vendor.xzjh.settings.service.SysLogService;
import com.vendor.xzjh.settings.service.UpdateFileToSysService;
import com.vendor.xzjh.settings.util.LogUtil;
import com.vendor.xzjh.settings.util.SharePreUtil;
import com.vendor.xzjh.settings.util.StrUtil;
import com.vendor.xzjh.settings.util.ToastUtil;
import com.vendor.xzjh.settings.view.CustomDialog;
import java.io.File;
import java.util.ArrayList;
import java.util.List;

public class XzjhBroadcastReceiver extends BroadcastReceiver {
    private static final String BOOT_COMPLETED_ACTION = "android.intent.action.BOOT_COMPLETED";
    private static final boolean IS_DEBUG = true;
    private static final String MEDIA_MOUNT_ACTION = "android.intent.action.MEDIA_MOUNTED";
    private static final String MEDIA_REMOVED_ACTION = "android.intent.action.MEDIA_REMOVED";
    private static final String MEDIA_UNMOUNT_ACIONT = "android.intent.action.MEDIA_UNMOUNTED";
    private static final String PACKAGE_ADDED_ACTION = "android.intent.action.PACKAGE_ADDED";
    private static final String PACKAGE_REMOVED_ACTION = "android.intent.action.PACKAGE_REMOVED";
    private static final String RX_OTA_UPDATE_ACTION = "com.rx.ota.update.action";
    public static final String SHOW_POWER_OFF_COUNTDOWN_DIALOG_ACTION = "com.xzjh.countdown.dialog.action";
    private static final String SHUT_DOWN_ACTION = "android.intent.action.ACTION_SHUTDOWN";
    private static final String TAG = "XzjhBroadcastReceiver";
    String mAction = null;
    CustomDialog mCustomDialog;
    Context mCxt;

    public void onReceive(Context context, Intent intent) {
        this.mAction = intent.getAction();
        this.mCxt = context;
        LogUtil.LogI(TAG, IS_DEBUG, "mAction: " + this.mAction);
        if (this.mAction.equals(BOOT_COMPLETED_ACTION)) {
            startBootBrowser();
            startBootApp();
            if (Constant.mManager.xzjhGetLogInfoOpenStatus() != 1 || Constant.mManager.xzjhGetLogInfoAutoOpenStatus() != 1) {
                return;
            }
            if (Build.VERSION.SDK_INT >= 26) {
                this.mCxt.startForegroundService(new Intent(this.mCxt, SysLogService.class));
            } else {
                this.mCxt.startService(new Intent(this.mCxt, SysLogService.class));
            }
        } else if (!this.mAction.equals(SHUT_DOWN_ACTION)) {
            if (this.mAction.equals(MEDIA_MOUNT_ACTION)) {
                String uRootPath = intent.getData().getPath();
                LogUtil.LogI(TAG, IS_DEBUG, "uRootPath: " + uRootPath);
                if (!"emulated".equals(uRootPath.split("/")[2])) {
                    ToastUtil.toastUtil(context, "检测到U盘接入了");
                }
                if (Constant.mManager.xzjhGetAutoUpdateOtaStatus() == 1) {
                    Intent intentService = new Intent(this.mCxt, OtaUpdateService.class);
                    intentService.putExtra("path", uRootPath);
                    this.mCxt.startService(intentService);
                }
                if (Constant.mManager.xzjhGetAutoUpdateFileStatus() == 1) {
                    ToastUtil.toastUtil(context, "开始检测更新系统文件");
                    startSearchUpdateFile(uRootPath);
                }
            } else if (this.mAction.equals(MEDIA_UNMOUNT_ACIONT)) {
                ToastUtil.toastUtil(context, "检测到U盘移除了");
            } else if (!this.mAction.equals(MEDIA_REMOVED_ACTION)) {
                if (this.mAction.equals(PACKAGE_ADDED_ACTION)) {
                    String packageName = intent.getDataString();
                    ToastUtil.toastUtil(this.mCxt, String.format(this.mCxt.getResources().getString(R.string.install_app_done), packageName));
                    this.mCxt.sendBroadcast(new Intent("com.rx.operation.app.action"));
                } else if (this.mAction.equals(PACKAGE_REMOVED_ACTION)) {
                    String packageName2 = intent.getDataString();
                    ToastUtil.toastUtil(this.mCxt, String.format(this.mCxt.getResources().getString(R.string.uninstall_app_done), packageName2));
                    this.mCxt.sendBroadcast(new Intent("com.rx.operation.app.action"));
                } else if (!this.mAction.equals(RX_OTA_UPDATE_ACTION) && this.mAction.equals(SHOW_POWER_OFF_COUNTDOWN_DIALOG_ACTION)) {
                    context.startService(new Intent(this.mCxt, ShowCountDownDialog.class));
                }
            }
        }
    }

    private void checkHardwareDogStatus() {
    }

    private void startBootBrowser() {
        if (((Boolean) SharePreUtil.getInstance().getValue(SharePreferenceKey.SP_BOOT_BROWSER_SWITCH_KEY, false)).booleanValue()) {
            Intent intent = new Intent();
            intent.setComponent(new ComponentName(BuildConfig.APPLICATION_ID, "com.vendor.xzjh.settings.BrowserActivity"));
            this.mCxt.startActivity(intent);
        }
    }

    private void startBootApp() {
        String bootAppPackageName = (String) SharePreUtil.getInstance().getValue(SharePreferenceKey.SP_BOOT_APP_KEY, Constant.DEFAULT_PACKAGE_NAME);
        if (!StrUtil.isStrEmpty(bootAppPackageName) && !bootAppPackageName.equals(Constant.DEFAULT_PACKAGE_NAME) && installedApp(bootAppPackageName)) {
            bootApp(bootAppPackageName);
        }
    }

    private void showPromptDialog(String uRootPath) {
        LogUtil.LogI(TAG, IS_DEBUG, "showPromptDialog() === uRootPath == " + uRootPath);
        dismissCustomDialog();
        if (this.mCustomDialog == null) {
            this.mCustomDialog = new CustomDialog(SettingsActivity.mCxt);
        }
        if (Build.VERSION.SDK_INT >= 26) {
            this.mCustomDialog.getWindow().setType(2038);
        } else {
            this.mCustomDialog.getWindow().setType(2003);
        }
        this.mCustomDialog.setTv(this.mCxt.getResources().getString(R.string.update_file_prompt));
        this.mCustomDialog.setOnExitListener(new View.OnClickListener(uRootPath) {
            /* class com.vendor.xzjh.settings.receiver.$$Lambda$XzjhBroadcastReceiver$42ufqxeHWwW6hDXxpLpEBqbxKR0 */
            public final /* synthetic */ String f$1;

            {
                this.f$1 = r2;
            }

            public final void onClick(View view) {
                XzjhBroadcastReceiver.this.lambda$showPromptDialog$0$XzjhBroadcastReceiver(this.f$1, view);
            }
        });
        this.mCustomDialog.setOnCancelListener(new View.OnClickListener() {
            /* class com.vendor.xzjh.settings.receiver.$$Lambda$XzjhBroadcastReceiver$Jyr7lBaVjkrGUk483pI97a2t_S8 */

            public final void onClick(View view) {
                XzjhBroadcastReceiver.this.lambda$showPromptDialog$1$XzjhBroadcastReceiver(view);
            }
        });
        this.mCustomDialog.show();
    }

    public /* synthetic */ void lambda$showPromptDialog$0$XzjhBroadcastReceiver(String uRootPath, View view) {
        this.mCustomDialog.dismiss();
        startSearchUpdateFile(uRootPath);
    }

    public /* synthetic */ void lambda$showPromptDialog$1$XzjhBroadcastReceiver(View view) {
        this.mCustomDialog.dismiss();
    }

    private void startSearchUpdateFile(String uRootPath) {
        File uFile = new File(uRootPath);
        if (!uFile.exists() || !uFile.isDirectory()) {
            LogUtil.LogI(TAG, IS_DEBUG, uRootPath + " is not exist !!!");
            return;
        }
        LogUtil.LogI(TAG, IS_DEBUG, uRootPath + " is exist !!!");
        Intent intentService = new Intent(this.mCxt, UpdateFileToSysService.class);
        intentService.putExtra("path", uRootPath);
        this.mCxt.startService(intentService);
    }

    private void dismissCustomDialog() {
        CustomDialog customDialog = this.mCustomDialog;
        if (customDialog != null && customDialog.isShowing()) {
            this.mCustomDialog.dismiss();
        }
    }

    private boolean installedApp(String packageName) {
        List<PackageInfo> pinfo = this.mCxt.getPackageManager().getInstalledPackages(0);
        List<String> pName = new ArrayList<>();
        if (pinfo != null) {
            for (int i = 0; i < pinfo.size(); i++) {
                pName.add(pinfo.get(i).packageName);
            }
        }
        return pName.contains(packageName);
    }

    private void bootApp(String packageName) {
        this.mCxt.startActivity(this.mCxt.getPackageManager().getLaunchIntentForPackage(packageName));
    }

    public static boolean isApplicationShowing(String packageName, Context context) {
        int status;
        boolean result = false;
        List<ActivityManager.RunningAppProcessInfo> appProcesses = ((ActivityManager) context.getSystemService("activity")).getRunningAppProcesses();
        if (appProcesses != null) {
            for (ActivityManager.RunningAppProcessInfo runningAppProcessInfo : appProcesses) {
                if (runningAppProcessInfo.processName.equals(packageName) && ((status = runningAppProcessInfo.importance) == 200 || status == 100)) {
                    result = IS_DEBUG;
                }
            }
        }
        return result;
    }
}
