package com.vendor.xzjh.settings.util;

import android.content.Context;
import android.content.Intent;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Build;
import com.vendor.xzjh.settings.bean.BootAppBean;
import com.vendor.xzjh.settings.constant.Constant;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class AppUtil {
    private static final List<String> mSysPackage = new ArrayList(Arrays.asList("com.android.browser", "com.android.camera2", "com.android.rk", "com.android.music", "android.rk.RockVideoPlayer"));

    public static List<BootAppBean> getAllAppInfo(Context context, boolean isPlaySysApp) {
        PackageInfo packageInfo;
        List<ApplicationInfo> listAppInfo = queryFilterAppInfo(context, isPlaySysApp);
        List<BootAppBean> mListBootAppInfo = new ArrayList<>();
        for (int i = 0; i < listAppInfo.size(); i++) {
            ApplicationInfo info = listAppInfo.get(i);
            PackageManager packageManager = context.getPackageManager();
            String name = info.loadLabel(packageManager).toString();
            Bitmap bitmap = drawableToBitmap(getIconFromPackageName(info.packageName, context));
            try {
                packageInfo = packageManager.getPackageInfo(info.packageName, 0);
            } catch (Exception e) {
                e.printStackTrace();
                packageInfo = null;
            }
            mListBootAppInfo.add(new BootAppBean(bitmap, name, info.packageName, packageInfo == null ? Constant.DEFAULT_PACKAGE_NAME : packageInfo.versionName, packageInfo != null && packageInfo.applicationInfo != null && (packageInfo.applicationInfo.flags & 1) != 0));
        }
        return mListBootAppInfo;
    }

    public static Bitmap drawableToBitmap(Drawable drawable) {
        int w = drawable.getIntrinsicWidth();
        int h = drawable.getIntrinsicHeight();
        Bitmap bitmap = Bitmap.createBitmap(w, h, drawable.getOpacity() != -1 ? Bitmap.Config.ARGB_8888 : Bitmap.Config.RGB_565);
        Canvas canvas = new Canvas(bitmap);
        drawable.setBounds(0, 0, w, h);
        drawable.draw(canvas);
        return bitmap;
    }

    public static synchronized Drawable getIconFromPackageName(String packageName, Context context) {
        synchronized (AppUtil.class) {
            PackageManager pm = context.getPackageManager();
            if (Build.VERSION.SDK_INT >= 15) {
                try {
                    PackageInfo pi = pm.getPackageInfo(packageName, 0);
                    Context otherAppCtx = context.createPackageContext(packageName, 2);
                    for (int displayMetric : new int[]{640, 480, 320, 240, 213}) {
                        try {
                            Drawable d = otherAppCtx.getResources().getDrawableForDensity(pi.applicationInfo.icon, displayMetric);
                            if (d != null) {
                                return d;
                            }
                        } catch (Resources.NotFoundException e) {
                        }
                    }
                } catch (Exception e2) {
                }
            }
            try {
                return pm.getApplicationInfo(packageName, 0).loadIcon(pm);
            } catch (PackageManager.NameNotFoundException e3) {
                return null;
            }
        }
    }

    private static List<ApplicationInfo> queryFilterAppInfo(Context context, boolean isPlaySysApp) {
        List<ApplicationInfo> appInfos = context.getPackageManager().getInstalledApplications(8192);
        List<ApplicationInfo> applicationInfos = new ArrayList<>();
        Intent resolveIntent = new Intent("android.intent.action.MAIN", (Uri) null);
        resolveIntent.addCategory("android.intent.category.LAUNCHER");
        List<ResolveInfo> resolveinfoList = context.getPackageManager().queryIntentActivities(resolveIntent, 0);
        Set<String> allowPackages = new HashSet<>();
        for (ResolveInfo resolveInfo : resolveinfoList) {
            allowPackages.add(resolveInfo.activityInfo.packageName);
        }
        for (ApplicationInfo app : appInfos) {
            if (!isPlaySysApp) {
                if ((app.flags & 1) <= 0) {
                    applicationInfos.add(app);
                }
            } else if (allowPackages.contains(app.packageName) || mSysPackage.contains(app.packageName)) {
                applicationInfos.add(app);
            }
        }
        return applicationInfos;
    }

    public static String getVersionName(Context context) {
        return getPackageInfo(context).versionName;
    }

    public static int getVersionCode(Context context) {
        return getPackageInfo(context).versionCode;
    }

    private static PackageInfo getPackageInfo(Context context) {
        try {
            return context.getPackageManager().getPackageInfo(context.getPackageName(), 16384);
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }
}
