package com.vendor.xzjh.settings.util;

import android.content.Context;
import android.os.Looper;
import android.widget.Toast;
import com.vendor.xzjh.settings.constant.Constant;
import java.io.File;
import java.io.StringWriter;
import java.io.Writer;
import java.lang.Thread;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

public class CrashHandler implements Thread.UncaughtExceptionHandler {
    private static final boolean IS_DEBUG = true;
    private static final String TAG = "CrashHandler";
    private static CrashHandler sInstance = null;
    private Map<String, String> infos = new HashMap();
    private Context mContext;
    private Thread.UncaughtExceptionHandler mDefaultHandler;

    public static CrashHandler getInstance() {
        if (sInstance == null) {
            synchronized (CrashHandler.class) {
                if (sInstance == null) {
                    synchronized (CrashHandler.class) {
                        sInstance = new CrashHandler();
                    }
                }
            }
        }
        return sInstance;
    }

    private CrashHandler() {
    }

    public void init(Context context) {
        this.mContext = context;
        this.mDefaultHandler = Thread.getDefaultUncaughtExceptionHandler();
        Thread.setDefaultUncaughtExceptionHandler(this);
    }

    public void uncaughtException(Thread t, Throwable e) {
        if (!handleException(e)) {
            Thread.UncaughtExceptionHandler uncaughtExceptionHandler = this.mDefaultHandler;
            if (uncaughtExceptionHandler != null) {
                uncaughtExceptionHandler.uncaughtException(t, e);
                return;
            }
            return;
        }
        try {
            Thread.sleep(3000);
        } catch (InterruptedException e1) {
            e1.printStackTrace();
        }
        System.exit(1);
    }

    private boolean handleException(Throwable e) {
        if (e == null) {
            return false;
        }
        new Thread() {
            /* class com.vendor.xzjh.settings.util.CrashHandler.AnonymousClass1 */

            public void run() {
                Looper.prepare();
                Toast.makeText(CrashHandler.this.mContext, "捕获到异常", 0).show();
                Looper.loop();
            }
        }.start();
        this.infos = DevUtil.collectDeviceInfo(this.mContext);
        saveErrorMessages(e);
        return false;
    }

    private void saveErrorMessages(Throwable e) {
        StringBuffer sb = StrUtil.mapToString(this.infos);
        Writer writer = new StringWriter();
        sb.append(StrUtil.exceptionToString(e, writer));
        LogUtil.LogI(TAG, IS_DEBUG, "----saveErrorMessages: " + e.toString());
        String fileName = "crash-" + new SimpleDateFormat("yyyyMMdd_HHmmss", Locale.CHINA).format(new Date()) + ".log";
        File dir = new File(Constant.APP_EXCEPTION_LOG_PATH);
        if (!dir.exists()) {
            dir.mkdirs();
        }
        FileUtil.fileLogList(Constant.APP_EXCEPTION_LOG_PATH);
        FileUtil.saveMsgToFile(writer, sb.toString(), Constant.APP_EXCEPTION_LOG_PATH + File.separator + fileName);
    }
}
