package com.vendor.xzjh.settings.util;

import android.content.Context;
import android.content.SharedPreferences;

public class SharePreUtil {
    private static SharePreUtil instance;
    private Context mContext;
    private String name;

    public static SharePreUtil getInstance() {
        if (instance == null) {
            synchronized (SharePreUtil.class) {
                if (instance == null) {
                    instance = new SharePreUtil();
                }
            }
        }
        return instance;
    }

    private SharePreUtil() {
    }

    public void init(Context context, String name2) {
        this.mContext = context.getApplicationContext();
        this.name = name2;
    }

    public <V> void setValue(String key, V value) {
        SharedPreferences.Editor editor = this.mContext.getSharedPreferences(this.name, 0).edit();
        if (value instanceof String) {
            editor.putString(key, value);
        } else if (value instanceof Integer) {
            editor.putInt(key, value.intValue());
        } else if (value instanceof Long) {
            editor.putLong(key, value.longValue());
        } else if (value instanceof Boolean) {
            editor.putBoolean(key, value.booleanValue());
        } else if (value instanceof Float) {
            editor.putFloat(key, value.floatValue());
        }
        editor.commit();
    }

    public <V> V getValue(String key, V defaultValue) {
        SharedPreferences sp = this.mContext.getSharedPreferences(this.name, 0);
        return defaultValue instanceof String ? (V) sp.getString(key, defaultValue) : defaultValue instanceof Integer ? (V) Integer.valueOf(sp.getInt(key, defaultValue.intValue())) : defaultValue instanceof Long ? (V) Long.valueOf(sp.getLong(key, defaultValue.longValue())) : defaultValue instanceof Boolean ? (V) Boolean.valueOf(sp.getBoolean(key, defaultValue.booleanValue())) : defaultValue instanceof Float ? (V) Float.valueOf(sp.getFloat(key, defaultValue.floatValue())) : defaultValue;
    }

    public void clearData() {
        SharedPreferences.Editor editor = this.mContext.getSharedPreferences(this.name, 0).edit();
        editor.clear();
        editor.commit();
    }
}
