package com.vendor.xzjh.settings.view;

import android.content.Context;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.widget.SeekBar;
import android.widget.TextView;
import androidx.preference.Preference;
import androidx.preference.PreferenceViewHolder;
import com.vendor.xzjh.settings.R;

public class SeekBarPreference extends Preference implements SeekBar.OnSeekBarChangeListener {
    private OnSeekBarPrefsChangeListener mListener;
    private int mMax;
    private int mProgress;
    private String mSeekbarTitle;
    private TextView mTitle;
    private boolean mTrackingTouch;
    private TextView value;

    public interface OnSeekBarPrefsChangeListener {
        void onProgressChanged(String str, SeekBar seekBar, int i, boolean z);

        void onStartTrackingTouch(String str, SeekBar seekBar);

        void onStopTrackingTouch(String str, SeekBar seekBar);
    }

    public SeekBarPreference(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs, defStyle);
        this.mProgress = 50;
        this.mMax = 100;
        this.mListener = null;
        setMax(100);
        setLayoutResource(R.layout.seekbar_layout);
    }

    public SeekBarPreference(Context context, AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public SeekBarPreference(Context context) {
        this(context, null);
    }

    public void setTitle(String title) {
        this.mSeekbarTitle = title;
    }

    @Override // androidx.preference.Preference
    public void onBindViewHolder(PreferenceViewHolder holder) {
        super.onBindViewHolder(holder);
        SeekBar seekBar = (SeekBar) holder.findViewById(R.id.seekBar1);
        seekBar.setMax(this.mMax);
        seekBar.setProgress(this.mProgress);
        seekBar.setEnabled(isEnabled());
        seekBar.setOnSeekBarChangeListener(this);
        TextView textView = (TextView) holder.findViewById(R.id.value);
        this.value = textView;
        textView.setText(String.valueOf(this.mProgress));
        TextView textView2 = (TextView) holder.findViewById(R.id.tv_seekbar_title);
        this.mTitle = textView2;
        textView2.setText(this.mSeekbarTitle);
    }

    public void setDefaultProgressValue(int defaultValue) {
        if (getPersistedInt(-1) == -1) {
            setProgress(defaultValue);
        }
    }

    /* access modifiers changed from: protected */
    @Override // androidx.preference.Preference
    public void onSetInitialValue(boolean restoreValue, Object defaultValue) {
        setProgress(restoreValue ? getPersistedInt(this.mProgress) : ((Integer) defaultValue).intValue());
    }

    public void setMax(int max) {
        if (max != this.mMax) {
            this.mMax = max;
            notifyChanged();
        }
    }

    public void setProgress(int progress) {
        setProgress(progress, true);
    }

    private void setProgress(int progress, boolean notifyChanged) {
        if (progress > this.mMax) {
            progress = this.mMax;
        }
        if (progress < 0) {
            progress = 0;
        }
        if (progress != this.mProgress) {
            this.mProgress = progress;
            persistInt(progress);
            if (notifyChanged) {
                notifyChanged();
            }
        }
    }

    public int getProgress() {
        return this.mProgress;
    }

    public void setOnSeekBarPrefsChangeListener(OnSeekBarPrefsChangeListener listener) {
        this.mListener = listener;
    }

    /* access modifiers changed from: package-private */
    public void syncProgress(SeekBar seekBar) {
        int progress = seekBar.getProgress();
        if (progress == this.mProgress) {
            return;
        }
        if (callChangeListener(Integer.valueOf(progress))) {
            setProgress(progress, false);
        } else {
            seekBar.setProgress(this.mProgress);
        }
    }

    public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
        OnSeekBarPrefsChangeListener onSeekBarPrefsChangeListener = this.mListener;
        if (onSeekBarPrefsChangeListener != null) {
            onSeekBarPrefsChangeListener.onProgressChanged(getKey(), seekBar, progress, fromUser);
        }
        if (seekBar.getProgress() != this.mProgress) {
            syncProgress(seekBar);
        }
        if (fromUser && !this.mTrackingTouch) {
            syncProgress(seekBar);
        }
    }

    public void onStartTrackingTouch(SeekBar seekBar) {
        OnSeekBarPrefsChangeListener onSeekBarPrefsChangeListener = this.mListener;
        if (onSeekBarPrefsChangeListener != null) {
            onSeekBarPrefsChangeListener.onStartTrackingTouch(getKey(), seekBar);
        }
        this.mTrackingTouch = true;
    }

    public void onStopTrackingTouch(SeekBar seekBar) {
        OnSeekBarPrefsChangeListener onSeekBarPrefsChangeListener = this.mListener;
        if (onSeekBarPrefsChangeListener != null) {
            onSeekBarPrefsChangeListener.onStopTrackingTouch(getKey(), seekBar);
        }
        this.mTrackingTouch = false;
        if (seekBar.getProgress() != this.mProgress) {
            syncProgress(seekBar);
        }
        notifyHierarchyChanged();
    }

    /* access modifiers changed from: protected */
    @Override // androidx.preference.Preference
    public Parcelable onSaveInstanceState() {
        Parcelable superState = super.onSaveInstanceState();
        if (isPersistent()) {
            return superState;
        }
        SavedState myState = new SavedState(superState);
        myState.progress = this.mProgress;
        myState.max = this.mMax;
        return myState;
    }

    /* access modifiers changed from: protected */
    @Override // androidx.preference.Preference
    public void onRestoreInstanceState(Parcelable state) {
        if (!state.getClass().equals(SavedState.class)) {
            super.onRestoreInstanceState(state);
            return;
        }
        SavedState myState = (SavedState) state;
        super.onRestoreInstanceState(myState.getSuperState());
        this.mProgress = myState.progress;
        this.mMax = myState.max;
        notifyChanged();
    }

    private static class SavedState extends Preference.BaseSavedState {
        int max;
        int progress;

        public SavedState(Parcel source) {
            super(source);
            this.progress = source.readInt();
            this.max = source.readInt();
        }

        public void writeToParcel(Parcel dest, int flags) {
            super.writeToParcel(dest, flags);
            dest.writeInt(this.progress);
            dest.writeInt(this.max);
        }

        public SavedState(Parcelable superState) {
            super(superState);
        }
    }
}
