package org.apache.commons.validator;

import java.util.ArrayList;
import java.util.Collection;
import org.apache.commons.validator.util.Flags;

@Deprecated
public class CreditCardValidator {
    public static final int AMEX = 1;
    public static final int DISCOVER = 8;
    public static final int MASTERCARD = 4;
    public static final int NONE = 0;
    public static final int VISA = 2;
    private final Collection<CreditCardType> cardTypes;

    public interface CreditCardType {
        boolean matches(String str);
    }

    public CreditCardValidator() {
        this(15);
    }

    public CreditCardValidator(int options) {
        ArrayList arrayList = new ArrayList();
        this.cardTypes = arrayList;
        Flags f = new Flags((long) options);
        if (f.isOn(2)) {
            arrayList.add(new Visa());
        }
        if (f.isOn(1)) {
            arrayList.add(new Amex());
        }
        if (f.isOn(4)) {
            arrayList.add(new Mastercard());
        }
        if (f.isOn(8)) {
            arrayList.add(new Discover());
        }
    }

    public boolean isValid(String card) {
        if (card == null || card.length() < 13 || card.length() > 19 || !luhnCheck(card)) {
            return false;
        }
        for (CreditCardType type : this.cardTypes) {
            if (type.matches(card)) {
                return true;
            }
        }
        return false;
    }

    public void addAllowedCardType(CreditCardType type) {
        this.cardTypes.add(type);
    }

    /* access modifiers changed from: protected */
    public boolean luhnCheck(String cardNumber) {
        int digits = cardNumber.length();
        int oddOrEven = digits & 1;
        long sum = 0;
        for (int count = 0; count < digits; count++) {
            try {
                int digit = Integer.parseInt(cardNumber.charAt(count) + "");
                if (((count & 1) ^ oddOrEven) == 0 && (digit = digit * 2) > 9) {
                    digit -= 9;
                }
                sum += (long) digit;
            } catch (NumberFormatException e) {
                return false;
            }
        }
        if (sum != 0 && sum % 10 == 0) {
            return true;
        }
        return false;
    }

    private static class Visa implements CreditCardType {
        private static final String PREFIX = "4";

        private Visa() {
        }

        @Override // org.apache.commons.validator.CreditCardValidator.CreditCardType
        public boolean matches(String card) {
            if (card.substring(0, 1).equals(PREFIX)) {
                return card.length() == 13 || card.length() == 16;
            }
            return false;
        }
    }

    private static class Amex implements CreditCardType {
        private static final String PREFIX = "34,37,";

        private Amex() {
        }

        @Override // org.apache.commons.validator.CreditCardValidator.CreditCardType
        public boolean matches(String card) {
            if (!PREFIX.contains(card.substring(0, 2) + ",") || card.length() != 15) {
                return false;
            }
            return true;
        }
    }

    private static class Discover implements CreditCardType {
        private static final String PREFIX = "6011";

        private Discover() {
        }

        @Override // org.apache.commons.validator.CreditCardValidator.CreditCardType
        public boolean matches(String card) {
            return card.substring(0, 4).equals(PREFIX) && card.length() == 16;
        }
    }

    private static class Mastercard implements CreditCardType {
        private static final String PREFIX = "51,52,53,54,55,";

        private Mastercard() {
        }

        @Override // org.apache.commons.validator.CreditCardValidator.CreditCardType
        public boolean matches(String card) {
            if (!PREFIX.contains(card.substring(0, 2) + ",") || card.length() != 16) {
                return false;
            }
            return true;
        }
    }
}
