package org.apache.commons.validator;

import java.io.IOException;
import java.util.Locale;
import org.xml.sax.SAXException;

public class DateTest extends AbstractCommonTest {
    protected String ACTION = "date";
    protected String FORM_KEY = "dateForm";

    public DateTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws IOException, SAXException {
        loadResources("DateTest-config.xml");
    }

    public void testValidDate() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("12/01/2005");
        valueTest(info, true);
    }

    public void testInvalidDate() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("12/01as/2005");
        valueTest(info, false);
    }

    /* access modifiers changed from: protected */
    public void valueTest(Object info, boolean passed) throws ValidatorException {
        Validator validator = new Validator(this.resources, this.FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, info);
        validator.setParameter(Validator.LOCALE_PARAM, Locale.US);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult result = results.getValidatorResult("value");
        assertNotNull(this.ACTION + " value ValidatorResult should not be null.", result);
        assertTrue(this.ACTION + " value ValidatorResult should contain the '" + this.ACTION + "' action.", result.containsAction(this.ACTION));
        StringBuilder sb = new StringBuilder();
        sb.append(this.ACTION);
        sb.append(" value ValidatorResult for the '");
        sb.append(this.ACTION);
        sb.append("' action should have ");
        sb.append(passed ? "passed" : "failed");
        sb.append(".");
        String sb2 = sb.toString();
        boolean isValid = result.isValid(this.ACTION);
        if (!passed) {
            isValid = !isValid;
        }
        assertTrue(sb2, isValid);
    }
}
