package org.apache.commons.validator;

import androidx.core.app.NotificationCompat;
import java.io.IOException;
import org.apache.commons.validator.routines.EmailValidator;
import org.xml.sax.SAXException;

@Deprecated
public class EmailTest extends AbstractCommonTest {
    protected static String ACTION = NotificationCompat.CATEGORY_EMAIL;
    protected static String FORM_KEY = "emailForm";
    ResultPair[] testEmailFromPerl = {new ResultPair("abigail@example.com", true), new ResultPair("abigail@example.com ", true), new ResultPair(" abigail@example.com", true), new ResultPair("abigail @example.com ", true), new ResultPair("*@example.net", true), new ResultPair("\"\\\"\"@foo.bar", true), new ResultPair("fred&barny@example.com", true), new ResultPair("---@example.com", true), new ResultPair("foo-bar@example.net", true), new ResultPair("\"127.0.0.1\"@[127.0.0.1]", true), new ResultPair("Abigail <abigail@example.com>", true), new ResultPair("Abigail<abigail@example.com>", true), new ResultPair("Abigail<@a,@b,@c:abigail@example.com>", true), new ResultPair("\"This is a phrase\"<abigail@example.com>", true), new ResultPair("\"Abigail \"<abigail@example.com>", true), new ResultPair("\"Joe & J. Harvey\" <example @Org>", true), new ResultPair("Abigail <abigail @ example.com>", true), new ResultPair("Abigail made this <  abigail   @   example  .    com    >", true), new ResultPair("Abigail(the bitch)@example.com", true), new ResultPair("Abigail <abigail @ example . (bar) com >", true), new ResultPair("Abigail < (one)  abigail (two) @(three)example . (bar) com (quz) >", true), new ResultPair("Abigail (foo) (((baz)(nested) (comment)) ! ) < (one)  abigail (two) @(three)example . (bar) com (quz) >", true), new ResultPair("Abigail <abigail(fo\\(o)@example.com>", true), new ResultPair("Abigail <abigail(fo\\)o)@example.com> ", true), new ResultPair("(foo) abigail@example.com", true), new ResultPair("abigail@example.com (foo)", true), new ResultPair("\"Abi\\\"gail\" <abigail@example.com>", true), new ResultPair("abigail@[example.com]", true), new ResultPair("abigail@[exa\\[ple.com]", true), new ResultPair("abigail@[exa\\]ple.com]", true), new ResultPair("\":sysmail\"@  Some-Group. Some-Org", true), new ResultPair("Muhammed.(I am  the greatest) Ali @(the)Vegas.WBA", true), new ResultPair("mailbox.sub1.sub2@this-domain", true), new ResultPair("sub-net.mailbox@sub-domain.domain", true), new ResultPair("name:;", true), new ResultPair("':;", true), new ResultPair("name:   ;", true), new ResultPair("Alfred Neuman <Neuman@BBN-TENEXA>", true), new ResultPair("Neuman@BBN-TENEXA", true), new ResultPair("\"George, Ted\" <Shared@Group.Arpanet>", true), new ResultPair("Wilt . (the  Stilt) Chamberlain@NBA.US", true), new ResultPair("Cruisers:  Port@Portugal, Jones@SEA;", true), new ResultPair("$@[]", true), new ResultPair("*()@[]", true), new ResultPair("\"quoted ( brackets\" ( a comment )@example.com", true), new ResultPair("\"Joe & J. Harvey\"\\x0D\\x0A     <ddd\\@ Org>", true), new ResultPair("\"Joe &\\x0D\\x0A J. Harvey\" <ddd \\@ Org>", true), new ResultPair("Gourmets:  Pompous Person <WhoZiWhatZit\\@Cordon-Bleu>,\\x0D\\x0A        Childs\\@WGBH.Boston, \"Galloping Gourmet\"\\@\\x0D\\x0A        ANT.Down-Under (Australian National Television),\\x0D\\x0A        Cheapie\\@Discount-Liquors;", true), new ResultPair("   Just a string", false), new ResultPair(Var.JSTYPE_STRING, false), new ResultPair("(comment)", false), new ResultPair("()@example.com", false), new ResultPair("fred(&)barny@example.com", false), new ResultPair("fred\\ barny@example.com", false), new ResultPair("Abigail <abi gail @ example.com>", false), new ResultPair("Abigail <abigail(fo(o)@example.com>", false), new ResultPair("Abigail <abigail(fo)o)@example.com>", false), new ResultPair("\"Abi\"gail\" <abigail@example.com>", false), new ResultPair("abigail@[exa]ple.com]", false), new ResultPair("abigail@[exa[ple.com]", false), new ResultPair("abigail@[exaple].com]", false), new ResultPair("abigail@", false), new ResultPair("@example.com", false), new ResultPair("phrase: abigail@example.com abigail@example.com ;", false), new ResultPair("invalid�char@example.com", false)};

    public EmailTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws IOException, SAXException {
        loadResources("EmailTest-config.xml");
    }

    public void testEmail() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("jsmith@apache.org");
        valueTest(info, true);
    }

    public void testEmailWithNumericAddress() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("someone@[216.109.118.76]");
        valueTest(info, true);
        info.setValue("someone@yahoo.com");
        valueTest(info, true);
    }

    public void testEmailExtension() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("jsmith@apache.org");
        valueTest(info, true);
        info.setValue("jsmith@apache.com");
        valueTest(info, true);
        info.setValue("jsmith@apache.net");
        valueTest(info, true);
        info.setValue("jsmith@apache.info");
        valueTest(info, true);
        info.setValue("jsmith@apache.");
        valueTest(info, false);
        info.setValue("jsmith@apache.c");
        valueTest(info, false);
        info.setValue("someone@yahoo.museum");
        valueTest(info, true);
        info.setValue("someone@yahoo.mu-seum");
        valueTest(info, false);
    }

    public void testEmailWithDash() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("andy.noble@data-workshop.com");
        valueTest(info, true);
        info.setValue("andy-noble@data-workshop.-com");
        valueTest(info, false);
        info.setValue("andy-noble@data-workshop.c-om");
        valueTest(info, false);
        info.setValue("andy-noble@data-workshop.co-m");
        valueTest(info, false);
    }

    public void testEmailWithDotEnd() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("andy.noble@data-workshop.com.");
        valueTest(info, false);
    }

    public void testEmailWithBogusCharacter() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("andy.noble@data-workshop.com");
        valueTest(info, false);
        info.setValue("andy.o'reilly@data-workshop.com");
        valueTest(info, true);
        info.setValue("andy@o'reilly.data-workshop.com");
        valueTest(info, false);
        info.setValue("foo+bar@i.am.not.in.us.example.com");
        valueTest(info, true);
    }

    public void testEmailWithCommas() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("joeblow@apa,che.org");
        valueTest(info, false);
        info.setValue("joeblow@apache.o,rg");
        valueTest(info, false);
        info.setValue("joeblow@apache,org");
        valueTest(info, false);
    }

    public void testEmailWithSpaces() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("joeblow @apache.org");
        valueTest(info, false);
        info.setValue("joeblow@ apache.org");
        valueTest(info, false);
        info.setValue(" joeblow@apache.org");
        valueTest(info, false);
        info.setValue("joeblow@apache.org ");
        valueTest(info, false);
        info.setValue("joe blow@apache.org ");
        valueTest(info, false);
        info.setValue("joeblow@apa che.org ");
        valueTest(info, false);
        info.setValue("\"joe blow\"@apache.org");
        valueTest(info, true);
    }

    public void testEmailWithControlChars() {
        EmailValidator validator = new EmailValidator();
        for (char c = 0; c < ' '; c = (char) (c + 1)) {
            assertFalse("Test control char " + ((int) c), validator.isValid("foo" + c + "bar@domain.com"));
        }
        assertFalse("Test control char 127", validator.isValid("foobar@domain.com"));
    }

    public void testEmailAtTLD() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("m@de");
        valueTest(info, false);
        assertTrue("Result should have been true", EmailValidator.getInstance(true, true).isValid("m@de"));
    }

    public void testEmailLocalhost() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("joe@localhost");
        valueTest(info, false);
        info.setValue("joe@localhost.localdomain");
        valueTest(info, false);
    }

    public void _testEmailUserName() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("joe1blow@apache.org");
        valueTest(info, true);
        info.setValue("joe$blow@apache.org");
        valueTest(info, true);
        info.setValue("joe-@apache.org");
        valueTest(info, true);
        info.setValue("joe_@apache.org");
        valueTest(info, true);
        info.setValue("joe.@apache.org");
        valueTest(info, false);
        info.setValue("joe+@apache.org");
        valueTest(info, false);
        info.setValue("joe!@apache.org");
        valueTest(info, false);
        info.setValue("joe*@apache.org");
        valueTest(info, false);
        info.setValue("joe'@apache.org");
        valueTest(info, false);
        info.setValue("joe(@apache.org");
        valueTest(info, false);
        info.setValue("joe)@apache.org");
        valueTest(info, false);
        info.setValue("joe,@apache.org");
        valueTest(info, false);
        info.setValue("joe%45@apache.org");
        valueTest(info, false);
        info.setValue("joe;@apache.org");
        valueTest(info, false);
        info.setValue("joe?@apache.org");
        valueTest(info, false);
        info.setValue("joe&@apache.org");
        valueTest(info, false);
        info.setValue("joe=@apache.org");
        valueTest(info, false);
        info.setValue("\"joe.\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe+\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe!\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe*\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe'\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe(\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe)\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe,\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe%45\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe;\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe?\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe&\"@apache.org");
        valueTest(info, true);
        info.setValue("\"joe=\"@apache.org");
        valueTest(info, true);
    }

    public void _testEmailFromPerl() throws ValidatorException {
        ValueBean info = new ValueBean();
        int index = 0;
        while (true) {
            ResultPair[] resultPairArr = this.testEmailFromPerl;
            if (index < resultPairArr.length) {
                info.setValue(resultPairArr[index].item);
                valueTest(info, this.testEmailFromPerl[index].valid);
                index++;
            } else {
                return;
            }
        }
    }

    private void valueTest(ValueBean info, boolean passed) throws ValidatorException {
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, info);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult result = results.getValidatorResult("value");
        assertNotNull(ACTION + " value ValidatorResult should not be null.", result);
        assertTrue("Value " + info.getValue() + " ValidatorResult should contain the '" + ACTION + "' action.", result.containsAction(ACTION));
        StringBuilder sb = new StringBuilder();
        sb.append("Value ");
        sb.append(info.getValue());
        sb.append("ValidatorResult for the '");
        sb.append(ACTION);
        sb.append("' action should have ");
        sb.append(passed ? "passed" : "failed");
        sb.append(".");
        String sb2 = sb.toString();
        boolean isValid = result.isValid(ACTION);
        if (!passed) {
            isValid = !isValid;
        }
        assertTrue(sb2, isValid);
    }
}
