package org.apache.commons.validator;

import java.io.IOException;
import org.xml.sax.SAXException;

public class ExceptionTest extends AbstractCommonTest {
    protected static String ACTION = "raiseException";
    protected static String FORM_KEY = "exceptionForm";

    public ExceptionTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws IOException, SAXException {
        loadResources("ExceptionTest-config.xml");
    }

    public void testValidatorException() {
        ValueBean info = new ValueBean();
        info.setValue("VALIDATOR");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, info);
        try {
            validator.validate();
            fail("ValidatorException should occur here!");
        } catch (ValidatorException expected) {
            assertTrue("VALIDATOR-EXCEPTION".equals(expected.getMessage()));
        }
    }

    public void XtestRuntimeException() throws ValidatorException {
        ValueBean info = new ValueBean();
        info.setValue("RUNTIME");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, info);
        try {
            validator.validate();
        } catch (RuntimeException e) {
            fail("RuntimeExceptions should be treated as validation failures in Validator 1.x.");
        }
    }

    public void XtestCheckedException() {
        ValueBean info = new ValueBean();
        info.setValue("CHECKED");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, info);
        try {
            validator.validate();
        } catch (ValidatorException e) {
            fail("Checked exceptions are not wrapped in ValidatorException in Validator 1.x.");
        } catch (Exception e2) {
            assertTrue("CHECKED-EXCEPTION".equals(e2.getMessage()));
        }
    }
}
