package org.apache.commons.validator;

import java.io.InputStream;
import junit.framework.TestCase;

public class ExtensionTest extends TestCase {
    protected static String ACTION = "required";
    protected static String CHECK_MSG_KEY = "nameForm.lastname.displayname";
    protected static String FORM_KEY = "nameForm";
    protected static String FORM_KEY2 = "nameForm2";
    private ValidatorResources resources = null;

    public ExtensionTest(String arg0) {
        super(arg0);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws Exception {
        InputStream in = null;
        try {
            in = getClass().getResourceAsStream("ExtensionTest-config.xml");
            this.resources = new ValidatorResources(in);
        } finally {
            if (in != null) {
                in.close();
            }
        }
    }

    /* access modifiers changed from: protected */
    public void tearDown() {
    }

    public void testRequired() throws ValidatorException {
        NameBean name = new NameBean();
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have failed.", !firstNameResult.isValid(ACTION));
        assertNotNull("First Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have failed.", !lastNameResult.isValid(ACTION));
    }

    public void testRequiredFirstNameBlank() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have failed.", !firstNameResult.isValid(ACTION));
        assertNotNull("First Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have failed.", !lastNameResult.isValid(ACTION));
    }

    public void testRequiredFirstName() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("Joe");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have passed.", firstNameResult.isValid(ACTION));
        assertNotNull("First Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have failed.", !lastNameResult.isValid(ACTION));
    }

    public void testRequiredLastNameBlank() throws ValidatorException {
        NameBean name = new NameBean();
        name.setLastName("");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have failed.", !firstNameResult.isValid(ACTION));
        assertNotNull("First Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have failed.", !lastNameResult.isValid(ACTION));
    }

    public void testRequiredLastName() throws ValidatorException {
        NameBean name = new NameBean();
        name.setLastName("Smith");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have failed.", !firstNameResult.isValid(ACTION));
        assertNotNull("First Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have passed.", lastNameResult.isValid(ACTION));
    }

    public void testRequiredName() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("Joe");
        name.setLastName("Smith");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have passed.", firstNameResult.isValid(ACTION));
        assertNotNull("Last Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have passed.", lastNameResult.isValid(ACTION));
    }

    public void testOverrideRule() throws ValidatorException {
        NameBean name = new NameBean();
        name.setLastName("Smith");
        Validator validator = new Validator(this.resources, FORM_KEY2);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have '" + CHECK_MSG_KEY + " as a key.", firstNameResult.field.getArg(0).getKey().equals(CHECK_MSG_KEY));
        assertNull("Last Name ValidatorResult should be null.", lastNameResult);
    }

    public void testOrder() {
        Form form = this.resources.getForm(ValidatorResources.defaultLocale, FORM_KEY);
        Form form2 = this.resources.getForm(ValidatorResources.defaultLocale, FORM_KEY2);
        assertNotNull(FORM_KEY + " is null.", form);
        assertTrue("There should only be 2 fields in " + FORM_KEY, form.getFields().size() == 2);
        assertNotNull(FORM_KEY2 + " is null.", form2);
        assertTrue("There should only be 2 fields in " + FORM_KEY2, form2.getFields().size() == 2);
        assertTrue("firstName in " + FORM_KEY + " should be the first in the list", form.getFields().get(0).getKey().equals("firstName"));
        assertTrue("lastName in " + FORM_KEY + " should be the first in the list", form.getFields().get(1).getKey().equals("lastName"));
        Field fieldLastName = form2.getFields().get(0);
        Field fieldFirstName = form2.getFields().get(1);
        assertTrue("firstName in " + FORM_KEY2 + " should be the first in the list", fieldFirstName.getKey().equals("firstName"));
        assertTrue("lastName in " + FORM_KEY2 + " should be the first in the list", fieldLastName.getKey().equals("lastName"));
    }
}
