package org.apache.commons.validator;

import com.vendor.xzjh.settings.util.ShellUtils;
import java.io.Serializable;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.StringTokenizer;
import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.collections.FastHashMap;
import org.apache.commons.validator.util.ValidatorUtils;

public class Field implements Cloneable, Serializable {
    private static final String DEFAULT_ARG = "org.apache.commons.validator.Field.DEFAULT";
    protected static final String TOKEN_END = "}";
    public static final String TOKEN_INDEXED = "[]";
    protected static final String TOKEN_START = "${";
    protected static final String TOKEN_VAR = "var:";
    private static final long serialVersionUID = -8502647722530192185L;
    protected Map<String, Arg>[] args = new Map[0];
    protected boolean clientValidation = true;
    private final List<String> dependencyList = Collections.synchronizedList(new ArrayList());
    protected String depends = null;
    protected int fieldOrder = 0;
    @Deprecated
    protected FastHashMap hMsgs = new FastHashMap();
    @Deprecated
    protected FastHashMap hVars = new FastHashMap();
    protected String indexedListProperty = null;
    protected String indexedProperty = null;
    protected String key = null;
    protected int page = 0;
    protected String property = null;

    public int getPage() {
        return this.page;
    }

    public void setPage(int page2) {
        this.page = page2;
    }

    public int getFieldOrder() {
        return this.fieldOrder;
    }

    public void setFieldOrder(int fieldOrder2) {
        this.fieldOrder = fieldOrder2;
    }

    public String getProperty() {
        return this.property;
    }

    public void setProperty(String property2) {
        this.property = property2;
    }

    public String getIndexedProperty() {
        return this.indexedProperty;
    }

    public void setIndexedProperty(String indexedProperty2) {
        this.indexedProperty = indexedProperty2;
    }

    public String getIndexedListProperty() {
        return this.indexedListProperty;
    }

    public void setIndexedListProperty(String indexedListProperty2) {
        this.indexedListProperty = indexedListProperty2;
    }

    public String getDepends() {
        return this.depends;
    }

    public void setDepends(String depends2) {
        this.depends = depends2;
        this.dependencyList.clear();
        StringTokenizer st = new StringTokenizer(depends2, ",");
        while (st.hasMoreTokens()) {
            String depend = st.nextToken().trim();
            if (depend != null && depend.length() > 0) {
                this.dependencyList.add(depend);
            }
        }
    }

    public void addMsg(Msg msg) {
        getMsgMap().put(msg.getName(), msg);
    }

    public String getMsg(String key2) {
        Msg msg = getMessage(key2);
        if (msg == null) {
            return null;
        }
        return msg.getKey();
    }

    public Msg getMessage(String key2) {
        return getMsgMap().get(key2);
    }

    public Map<String, Msg> getMessages() {
        return Collections.unmodifiableMap(getMsgMap());
    }

    public boolean isClientValidation() {
        return this.clientValidation;
    }

    public void setClientValidation(boolean clientValidation2) {
        this.clientValidation = clientValidation2;
    }

    public void addArg(Arg arg) {
        if (arg != null && arg.getKey() != null && arg.getKey().length() != 0) {
            determineArgPosition(arg);
            ensureArgsCapacity(arg);
            Map<String, Arg> argMap = this.args[arg.getPosition()];
            if (argMap == null) {
                argMap = new HashMap<>();
                this.args[arg.getPosition()] = argMap;
            }
            if (arg.getName() == null) {
                argMap.put(DEFAULT_ARG, arg);
            } else {
                argMap.put(arg.getName(), arg);
            }
        }
    }

    private void determineArgPosition(Arg arg) {
        if (arg.getPosition() < 0) {
            Map<String, Arg>[] mapArr = this.args;
            if (mapArr == null || mapArr.length == 0) {
                arg.setPosition(0);
                return;
            }
            String keyName = arg.getName() == null ? DEFAULT_ARG : arg.getName();
            int lastPosition = -1;
            int lastDefault = -1;
            int i = 0;
            while (true) {
                Map<String, Arg>[] mapArr2 = this.args;
                if (i >= mapArr2.length) {
                    break;
                }
                if (mapArr2[i] != null && mapArr2[i].containsKey(keyName)) {
                    lastPosition = i;
                }
                Map<String, Arg>[] mapArr3 = this.args;
                if (mapArr3[i] != null && mapArr3[i].containsKey(DEFAULT_ARG)) {
                    lastDefault = i;
                }
                i++;
            }
            if (lastPosition < 0) {
                lastPosition = lastDefault;
            }
            arg.setPosition(lastPosition + 1);
        }
    }

    private void ensureArgsCapacity(Arg arg) {
        if (arg.getPosition() >= this.args.length) {
            Map<String, Arg>[] newArgs = new Map[(arg.getPosition() + 1)];
            Map<String, Arg>[] mapArr = this.args;
            System.arraycopy(mapArr, 0, newArgs, 0, mapArr.length);
            this.args = newArgs;
        }
    }

    public Arg getArg(int position) {
        return getArg(DEFAULT_ARG, position);
    }

    public Arg getArg(String key2, int position) {
        Map<String, Arg>[] mapArr = this.args;
        if (position >= mapArr.length || mapArr[position] == null) {
            return null;
        }
        Arg arg = mapArr[position].get(key2);
        if (arg != null || !key2.equals(DEFAULT_ARG)) {
            return arg == null ? getArg(position) : arg;
        }
        return null;
    }

    public Arg[] getArgs(String key2) {
        Arg[] argList = new Arg[this.args.length];
        for (int i = 0; i < this.args.length; i++) {
            argList[i] = getArg(key2, i);
        }
        return argList;
    }

    public void addVar(Var v) {
        getVarMap().put(v.getName(), v);
    }

    public void addVar(String name, String value, String jsType) {
        addVar(new Var(name, value, jsType));
    }

    public Var getVar(String mainKey) {
        return getVarMap().get(mainKey);
    }

    public String getVarValue(String mainKey) {
        Var v = getVarMap().get(mainKey);
        if (v != null) {
            return v.getValue();
        }
        return null;
    }

    public Map<String, Var> getVars() {
        return Collections.unmodifiableMap(getVarMap());
    }

    public String getKey() {
        if (this.key == null) {
            generateKey();
        }
        return this.key;
    }

    public void setKey(String key2) {
        this.key = key2;
    }

    public boolean isIndexed() {
        String str = this.indexedListProperty;
        return str != null && str.length() > 0;
    }

    public void generateKey() {
        if (isIndexed()) {
            this.key = this.indexedListProperty + TOKEN_INDEXED + "." + this.property;
            return;
        }
        this.key = this.property;
    }

    /* access modifiers changed from: package-private */
    public void process(Map<String, String> globalConstants, Map<String, String> constants) {
        this.hMsgs.setFast(false);
        this.hVars.setFast(true);
        generateKey();
        for (Map.Entry<String, String> entry : constants.entrySet()) {
            String key2 = TOKEN_START + entry.getKey() + TOKEN_END;
            String replaceValue = entry.getValue();
            this.property = ValidatorUtils.replace(this.property, key2, replaceValue);
            processVars(key2, replaceValue);
            processMessageComponents(key2, replaceValue);
        }
        for (Map.Entry<String, String> entry2 : globalConstants.entrySet()) {
            String key22 = TOKEN_START + entry2.getKey() + TOKEN_END;
            String replaceValue2 = entry2.getValue();
            this.property = ValidatorUtils.replace(this.property, key22, replaceValue2);
            processVars(key22, replaceValue2);
            processMessageComponents(key22, replaceValue2);
        }
        for (String key1 : getVarMap().keySet()) {
            processMessageComponents("${var:" + key1 + TOKEN_END, getVar(key1).getValue());
        }
        this.hMsgs.setFast(true);
    }

    private void processVars(String key2, String replaceValue) {
        for (String varKey : getVarMap().keySet()) {
            Var var = getVar(varKey);
            var.setValue(ValidatorUtils.replace(var.getValue(), key2, replaceValue));
        }
    }

    private void processMessageComponents(String key2, String replaceValue) {
        if (key2 != null && !key2.startsWith("${var:")) {
            for (Msg msg : getMsgMap().values()) {
                msg.setKey(ValidatorUtils.replace(msg.getKey(), key2, replaceValue));
            }
        }
        processArg(key2, replaceValue);
    }

    private void processArg(String key2, String replaceValue) {
        int i = 0;
        while (true) {
            Map<String, Arg>[] mapArr = this.args;
            if (i < mapArr.length) {
                Map<String, Arg> argMap = mapArr[i];
                if (argMap != null) {
                    for (Arg arg : argMap.values()) {
                        if (arg != null) {
                            arg.setKey(ValidatorUtils.replace(arg.getKey(), key2, replaceValue));
                        }
                    }
                }
                i++;
            } else {
                return;
            }
        }
    }

    public boolean isDependency(String validatorName) {
        return this.dependencyList.contains(validatorName);
    }

    public List<String> getDependencyList() {
        return Collections.unmodifiableList(this.dependencyList);
    }

    @Override // java.lang.Object
    public Object clone() {
        try {
            Field field = (Field) super.clone();
            field.args = new Map[this.args.length];
            int i = 0;
            while (true) {
                Map<String, Arg>[] mapArr = this.args;
                if (i < mapArr.length) {
                    if (mapArr[i] != null) {
                        Map<String, Arg> argMap = new HashMap<>(this.args[i]);
                        for (Map.Entry<String, Arg> entry : argMap.entrySet()) {
                            argMap.put(entry.getKey(), (Arg) entry.getValue().clone());
                        }
                        field.args[i] = argMap;
                    }
                    i++;
                } else {
                    field.hVars = ValidatorUtils.copyFastHashMap(this.hVars);
                    field.hMsgs = ValidatorUtils.copyFastHashMap(this.hMsgs);
                    return field;
                }
            }
        } catch (CloneNotSupportedException e) {
            throw new RuntimeException(e.toString());
        }
    }

    public String toString() {
        StringBuilder results = new StringBuilder();
        results.append("\t\tkey = " + this.key + ShellUtils.COMMAND_LINE_END);
        results.append("\t\tproperty = " + this.property + ShellUtils.COMMAND_LINE_END);
        results.append("\t\tindexedProperty = " + this.indexedProperty + ShellUtils.COMMAND_LINE_END);
        results.append("\t\tindexedListProperty = " + this.indexedListProperty + ShellUtils.COMMAND_LINE_END);
        results.append("\t\tdepends = " + this.depends + ShellUtils.COMMAND_LINE_END);
        results.append("\t\tpage = " + this.page + ShellUtils.COMMAND_LINE_END);
        results.append("\t\tfieldOrder = " + this.fieldOrder + ShellUtils.COMMAND_LINE_END);
        if (this.hVars != null) {
            results.append("\t\tVars:\n");
            for (Object key1 : getVarMap().keySet()) {
                results.append("\t\t\t");
                results.append(key1);
                results.append("=");
                results.append(getVarMap().get(key1));
                results.append(ShellUtils.COMMAND_LINE_END);
            }
        }
        return results.toString();
    }

    /* access modifiers changed from: package-private */
    public Object[] getIndexedProperty(Object bean) throws ValidatorException {
        try {
            Object indexProp = PropertyUtils.getProperty(bean, getIndexedListProperty());
            if (indexProp instanceof Collection) {
                return ((Collection) indexProp).toArray();
            }
            if (indexProp.getClass().isArray()) {
                return (Object[]) indexProp;
            }
            throw new ValidatorException(getKey() + " is not indexed");
        } catch (IllegalAccessException | NoSuchMethodException | InvocationTargetException e) {
            throw new ValidatorException(e.getMessage());
        }
    }

    private int getIndexedPropertySize(Object bean) throws ValidatorException {
        try {
            Object indexProp = PropertyUtils.getProperty(bean, getIndexedListProperty());
            if (indexProp == null) {
                return 0;
            }
            if (indexProp instanceof Collection) {
                return ((Collection) indexProp).size();
            }
            if (indexProp.getClass().isArray()) {
                return ((Object[]) indexProp).length;
            }
            throw new ValidatorException(getKey() + " is not indexed");
        } catch (IllegalAccessException | NoSuchMethodException | InvocationTargetException e) {
            throw new ValidatorException(e.getMessage());
        }
    }

    private boolean validateForRule(ValidatorAction va, ValidatorResults results, Map<String, ValidatorAction> actions, Map<String, Object> params, int pos) throws ValidatorException {
        ValidatorResult result = results.getValidatorResult(getKey());
        if (result != null && result.containsAction(va.getName())) {
            return result.isValid(va.getName());
        }
        if (!runDependentValidators(va, results, actions, params, pos)) {
            return false;
        }
        return va.executeValidationMethod(this, params, results, pos);
    }

    private boolean runDependentValidators(ValidatorAction va, ValidatorResults results, Map<String, ValidatorAction> actions, Map<String, Object> params, int pos) throws ValidatorException {
        List<String> dependentValidators = va.getDependencyList();
        if (dependentValidators.isEmpty()) {
            return true;
        }
        for (String depend : dependentValidators) {
            ValidatorAction action = actions.get(depend);
            if (action == null) {
                handleMissingAction(depend);
            }
            if (!validateForRule(action, results, actions, params, pos)) {
                return false;
            }
        }
        return true;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:26:0x006f, code lost:
        r0.merge(r0);
        r12 = r12 + 1;
     */
    public ValidatorResults validate(Map<String, Object> params, Map<String, ValidatorAction> actions) throws ValidatorException {
        if (getDepends() == null) {
            return new ValidatorResults();
        }
        ValidatorResults allResults = new ValidatorResults();
        int numberOfFieldsToValidate = isIndexed() ? getIndexedPropertySize(params.get(Validator.BEAN_PARAM)) : 1;
        int fieldNumber = 0;
        while (fieldNumber < numberOfFieldsToValidate) {
            ValidatorResults results = new ValidatorResults();
            synchronized (this.dependencyList) {
                for (String depend : this.dependencyList) {
                    ValidatorAction action = actions.get(depend);
                    if (action == null) {
                        handleMissingAction(depend);
                    }
                    if (!validateForRule(action, results, actions, params, fieldNumber)) {
                        allResults.merge(results);
                        return allResults;
                    }
                }
            }
        }
        return allResults;
    }

    private void handleMissingAction(String name) throws ValidatorException {
        throw new ValidatorException("No ValidatorAction named " + name + " found for field " + getProperty());
    }

    /* access modifiers changed from: protected */
    public Map<String, Msg> getMsgMap() {
        return this.hMsgs;
    }

    /* access modifiers changed from: protected */
    public Map<String, Var> getVarMap() {
        return this.hVars;
    }
}
