package org.apache.commons.validator;

import com.vendor.xzjh.settings.util.ShellUtils;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.commons.collections.FastHashMap;

public class Form implements Serializable {
    private static final long serialVersionUID = 6445211789563796371L;
    @Deprecated
    protected FastHashMap hFields = new FastHashMap();
    protected String inherit = null;
    protected List<Field> lFields = new ArrayList();
    protected String name = null;
    private boolean processed = false;

    public String getName() {
        return this.name;
    }

    public void setName(String name2) {
        this.name = name2;
    }

    public void addField(Field f) {
        this.lFields.add(f);
        getFieldMap().put(f.getKey(), f);
    }

    public List<Field> getFields() {
        return Collections.unmodifiableList(this.lFields);
    }

    public Field getField(String fieldName) {
        return getFieldMap().get(fieldName);
    }

    public boolean containsField(String fieldName) {
        return getFieldMap().containsKey(fieldName);
    }

    /* access modifiers changed from: protected */
    public void merge(Form depends) {
        List<Field> templFields = new ArrayList<>();
        Map<String, Field> temphFields = new FastHashMap<>();
        for (Field defaultField : depends.getFields()) {
            if (defaultField != null) {
                String fieldKey = defaultField.getKey();
                if (!containsField(fieldKey)) {
                    templFields.add(defaultField);
                    temphFields.put(fieldKey, defaultField);
                } else {
                    Field old = getField(fieldKey);
                    getFieldMap().remove(fieldKey);
                    this.lFields.remove(old);
                    templFields.add(old);
                    temphFields.put(fieldKey, old);
                }
            }
        }
        this.lFields.addAll(0, templFields);
        getFieldMap().putAll(temphFields);
    }

    /* access modifiers changed from: protected */
    public void process(Map<String, String> globalConstants, Map<String, String> constants, Map<String, Form> forms) {
        Form parent;
        if (!isProcessed()) {
            int n = 0;
            if (isExtending() && (parent = forms.get(this.inherit)) != null) {
                if (!parent.isProcessed()) {
                    parent.process(constants, globalConstants, forms);
                }
                for (Field f : parent.getFields()) {
                    if (getFieldMap().get(f.getKey()) == null) {
                        this.lFields.add(n, f);
                        getFieldMap().put(f.getKey(), f);
                        n++;
                    }
                }
            }
            this.hFields.setFast(true);
            Iterator<Field> i = this.lFields.listIterator(n);
            while (i.hasNext()) {
                i.next().process(globalConstants, constants);
            }
            this.processed = true;
        }
    }

    public String toString() {
        StringBuilder results = new StringBuilder();
        results.append("Form: ");
        results.append(this.name);
        results.append(ShellUtils.COMMAND_LINE_END);
        for (Field field : this.lFields) {
            results.append("\tField: \n");
            results.append(field);
            results.append(ShellUtils.COMMAND_LINE_END);
        }
        return results.toString();
    }

    /* access modifiers changed from: package-private */
    public ValidatorResults validate(Map<String, Object> params, Map<String, ValidatorAction> actions, int page) throws ValidatorException {
        return validate(params, actions, page, null);
    }

    /* access modifiers changed from: package-private */
    public ValidatorResults validate(Map<String, Object> params, Map<String, ValidatorAction> actions, int page, String fieldName) throws ValidatorException {
        ValidatorResults results = new ValidatorResults();
        params.put(Validator.VALIDATOR_RESULTS_PARAM, results);
        if (fieldName != null) {
            Field field = getFieldMap().get(fieldName);
            if (field != null) {
                params.put(Validator.FIELD_PARAM, field);
                if (field.getPage() <= page) {
                    results.merge(field.validate(params, actions));
                }
            } else {
                throw new ValidatorException("Unknown field " + fieldName + " in form " + getName());
            }
        } else {
            for (Field field2 : this.lFields) {
                params.put(Validator.FIELD_PARAM, field2);
                if (field2.getPage() <= page) {
                    results.merge(field2.validate(params, actions));
                }
            }
        }
        return results;
    }

    public boolean isProcessed() {
        return this.processed;
    }

    public String getExtends() {
        return this.inherit;
    }

    public void setExtends(String inherit2) {
        this.inherit = inherit2;
    }

    public boolean isExtending() {
        return this.inherit != null;
    }

    /* access modifiers changed from: protected */
    public Map<String, Field> getFieldMap() {
        return this.hFields;
    }
}
