package org.apache.commons.validator;

import org.apache.commons.digester.AbstractObjectCreationFactory;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.xml.sax.Attributes;

public class FormSetFactory extends AbstractObjectCreationFactory {
    private transient Log log = LogFactory.getLog(FormSetFactory.class);

    public Object createObject(Attributes attributes) throws Exception {
        return createFormSet((ValidatorResources) this.digester.peek(0), attributes.getValue("language"), attributes.getValue("country"), attributes.getValue("variant"));
    }

    private FormSet createFormSet(ValidatorResources resources, String language, String country, String variant) throws Exception {
        FormSet formSet = resources.getFormSet(language, country, variant);
        if (formSet != null) {
            if (getLog().isDebugEnabled()) {
                Log log2 = getLog();
                log2.debug("FormSet[" + formSet.displayKey() + "] found - merging.");
            }
            return formSet;
        }
        FormSet formSet2 = new FormSet();
        formSet2.setLanguage(language);
        formSet2.setCountry(country);
        formSet2.setVariant(variant);
        resources.addFormSet(formSet2);
        if (getLog().isDebugEnabled()) {
            Log log3 = getLog();
            log3.debug("FormSet[" + formSet2.displayKey() + "] created.");
        }
        return formSet2;
    }

    private Log getLog() {
        if (this.log == null) {
            this.log = LogFactory.getLog(FormSetFactory.class);
        }
        return this.log;
    }
}
