package org.apache.commons.validator;

import java.io.IOException;
import java.util.Date;
import java.util.Locale;
import java.util.Map;
import org.xml.sax.SAXException;

public class GenericTypeValidatorTest extends AbstractCommonTest {
    protected static String ACTION = "byte";
    protected static String FORM_KEY = "typeForm";

    public GenericTypeValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws IOException, SAXException {
        loadResources("GenericTypeValidatorTest-config.xml");
    }

    /* access modifiers changed from: protected */
    public void tearDown() {
    }

    public void testType() throws ValidatorException {
        TypeBean info = new TypeBean();
        info.setByte("12");
        info.setShort("129");
        info.setInteger("-144");
        info.setLong("88000");
        info.setFloat("12.1555f");
        info.setDouble("129.1551511111d");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, info);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        Map<String, ?> hResultValues = results.getResultValueMap();
        assertTrue("Expecting byte result to be an instance of Byte.", hResultValues.get("byte") instanceof Byte);
        assertTrue("Expecting short result to be an instance of Short.", hResultValues.get("short") instanceof Short);
        assertTrue("Expecting integer result to be an instance of Integer.", hResultValues.get("integer") instanceof Integer);
        assertTrue("Expecting long result to be an instance of Long.", hResultValues.get("long") instanceof Long);
        assertTrue("Expecting float result to be an instance of Float.", hResultValues.get("float") instanceof Float);
        assertTrue("Expecting double result to be an instance of Double.", hResultValues.get("double") instanceof Double);
        for (String key : hResultValues.keySet()) {
            assertNotNull("value ValidatorResults.getResultValueMap() should not be null.", hResultValues.get(key));
        }
    }

    public void testUSLocale() throws ValidatorException {
        TypeBean info = new TypeBean();
        info.setByte("12");
        info.setShort("129");
        info.setInteger("-144");
        info.setLong("88000");
        info.setFloat("12.1555");
        info.setDouble("129.1551511111");
        info.setDate("12/21/2010");
        localeTest(info, Locale.US);
    }

    public void testFRLocale() throws ValidatorException {
        TypeBean info = new TypeBean();
        info.setByte("12");
        info.setShort("-129");
        info.setInteger("1443");
        info.setLong("88000");
        info.setFloat("12,1555");
        info.setDouble("129,1551511111");
        info.setDate("21/12/2010");
        Map<String, ?> map = localeTest(info, Locale.FRENCH);
        boolean z = true;
        assertTrue("float value not correct", ((Float) map.get("float")).intValue() == 12);
        if (((Double) map.get("double")).intValue() != 129) {
            z = false;
        }
        assertTrue("double value not correct", z);
    }

    private Map<String, ?> localeTest(TypeBean info, Locale locale) throws ValidatorException {
        Validator validator = new Validator(this.resources, "typeLocaleForm");
        validator.setParameter(Validator.BEAN_PARAM, info);
        validator.setParameter(Validator.LOCALE_PARAM, locale);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        Map<String, ?> hResultValues = results.getResultValueMap();
        assertTrue("Expecting byte result to be an instance of Byte for locale: " + locale, hResultValues.get("byte") instanceof Byte);
        assertTrue("Expecting short result to be an instance of Short for locale: " + locale, hResultValues.get("short") instanceof Short);
        assertTrue("Expecting integer result to be an instance of Integer for locale: " + locale, hResultValues.get("integer") instanceof Integer);
        assertTrue("Expecting long result to be an instance of Long for locale: " + locale, hResultValues.get("long") instanceof Long);
        assertTrue("Expecting float result to be an instance of Float for locale: " + locale, hResultValues.get("float") instanceof Float);
        assertTrue("Expecting double result to be an instance of Double for locale: " + locale, hResultValues.get("double") instanceof Double);
        assertTrue("Expecting date result to be an instance of Date for locale: " + locale, hResultValues.get("date") instanceof Date);
        for (String key : hResultValues.keySet()) {
            Object value = hResultValues.get(key);
            assertNotNull("value ValidatorResults.getResultValueMap() should not be null for locale: " + locale, value);
        }
        return hResultValues;
    }
}
