package org.apache.commons.validator;

import org.apache.commons.validator.util.ValidatorUtils;

public class GenericValidatorImpl {
    public static final String FIELD_TEST_EQUAL = "EQUAL";
    public static final String FIELD_TEST_NOTNULL = "NOTNULL";
    public static final String FIELD_TEST_NULL = "NULL";

    public static boolean validateRaiseException(Object bean, Field field) throws Exception {
        String value = ValidatorUtils.getValueAsString(bean, field.getProperty());
        if ("RUNTIME".equals(value)) {
            throw new RuntimeException("RUNTIME-EXCEPTION");
        } else if ("CHECKED".equals(value)) {
            throw new Exception("CHECKED-EXCEPTION");
        } else {
            throw new ValidatorException("VALIDATOR-EXCEPTION");
        }
    }

    public static boolean validateRequired(Object bean, Field field) {
        return !GenericValidator.isBlankOrNull(ValidatorUtils.getValueAsString(bean, field.getProperty()));
    }

    public static boolean validateByte(Object bean, Field field) {
        return GenericValidator.isByte(ValidatorUtils.getValueAsString(bean, field.getProperty()));
    }

    public static boolean validateShort(Object bean, Field field) {
        return GenericValidator.isShort(ValidatorUtils.getValueAsString(bean, field.getProperty()));
    }

    public static boolean validateInt(Object bean, Field field) {
        return GenericValidator.isInt(ValidatorUtils.getValueAsString(bean, field.getProperty()));
    }

    public static boolean validatePositive(Object bean, Field field) {
        return GenericTypeValidator.formatInt(ValidatorUtils.getValueAsString(bean, field.getProperty())).intValue() > 0;
    }

    public static boolean validateLong(Object bean, Field field) {
        return GenericValidator.isLong(ValidatorUtils.getValueAsString(bean, field.getProperty()));
    }

    public static boolean validateFloat(Object bean, Field field) {
        return GenericValidator.isFloat(ValidatorUtils.getValueAsString(bean, field.getProperty()));
    }

    public static boolean validateDouble(Object bean, Field field) {
        return GenericValidator.isDouble(ValidatorUtils.getValueAsString(bean, field.getProperty()));
    }

    public static boolean validateEmail(Object bean, Field field) {
        return GenericValidator.isEmail(ValidatorUtils.getValueAsString(bean, field.getProperty()));
    }

    public static boolean validateRequiredIf(Object bean, Field field, Validator validator) {
        String value;
        boolean z;
        Object form = validator.getParameterValue(Validator.BEAN_PARAM);
        boolean required = false;
        if (isStringOrNull(bean)) {
            value = (String) bean;
        } else {
            value = ValidatorUtils.getValueAsString(bean, field.getProperty());
        }
        int i = 0;
        String fieldJoin = "AND";
        if (!GenericValidator.isBlankOrNull(field.getVarValue("fieldJoin"))) {
            fieldJoin = field.getVarValue("fieldJoin");
        }
        if (fieldJoin.equalsIgnoreCase("AND")) {
            required = true;
        }
        while (true) {
            if (GenericValidator.isBlankOrNull(field.getVarValue("field[" + i + "]"))) {
                break;
            }
            String dependProp = field.getVarValue("field[" + i + "]");
            String dependTest = field.getVarValue("fieldTest[" + i + "]");
            String dependTestValue = field.getVarValue("fieldValue[" + i + "]");
            String dependIndexed = field.getVarValue("fieldIndexed[" + i + "]");
            if (dependIndexed == null) {
                dependIndexed = "false";
            }
            boolean this_required = false;
            if (field.isIndexed() && dependIndexed.equalsIgnoreCase("true")) {
                String key = field.getKey();
                if (key.contains("[") && key.contains("]")) {
                    dependProp = key.substring(0, key.indexOf(".") + 1) + dependProp;
                }
            }
            String dependVal = ValidatorUtils.getValueAsString(form, dependProp);
            if (dependTest.equals(FIELD_TEST_NULL)) {
                if (dependVal == null || dependVal.length() <= 0) {
                    this_required = true;
                } else {
                    this_required = false;
                }
            }
            if (dependTest.equals(FIELD_TEST_NOTNULL)) {
                if (dependVal == null || dependVal.length() <= 0) {
                    this_required = false;
                } else {
                    this_required = true;
                }
            }
            if (dependTest.equals(FIELD_TEST_EQUAL)) {
                this_required = dependTestValue.equalsIgnoreCase(dependVal);
            }
            if (fieldJoin.equalsIgnoreCase("AND")) {
                z = required && this_required;
            } else {
                z = required || this_required;
            }
            required = z;
            i++;
        }
        if (!required) {
            return true;
        }
        if (value == null || value.length() <= 0) {
            return false;
        }
        return true;
    }

    private static boolean isStringOrNull(Object o) {
        if (o == null) {
            return true;
        }
        return o instanceof String;
    }
}
