package org.apache.commons.validator;

import java.io.IOException;
import java.io.InputStream;
import junit.framework.TestCase;
import org.xml.sax.SAXException;

public class MultipleConfigFilesTest extends TestCase {
    private static final String ACTION = "required";
    private static final String FORM_KEY = "nameForm";
    private ValidatorResources resources = null;

    public MultipleConfigFilesTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws IOException, SAXException {
        InputStream[] streams = {getClass().getResourceAsStream("MultipleConfigFilesTest-1-config.xml"), getClass().getResourceAsStream("MultipleConfigFilesTest-2-config.xml")};
        this.resources = new ValidatorResources(streams);
        for (InputStream inputStream : streams) {
            inputStream.close();
        }
    }

    public void testMergedConfig() {
        Form form1 = this.resources.getForm("", "", "", "testForm1");
        assertNotNull("Form 'testForm1' not found", form1);
        Form form2 = this.resources.getForm("", "", "", "testForm2");
        assertNotNull("Form 'testForm2' not found", form2);
        Field field1 = form1.getField("testProperty1");
        assertEquals("testProperty1 - const 1", "testConstValue1", field1.getVarValue("var11"));
        assertEquals("testProperty1 - const 2", "testConstValue2", field1.getVarValue("var12"));
        Field field2 = form2.getField("testProperty2");
        assertEquals("testProperty2 - const 1", "testConstValue1", field2.getVarValue("var21"));
        assertEquals("testProperty2 - const 2", "testConstValue2", field2.getVarValue("var22"));
        Form form1_fr = this.resources.getForm("fr", "", "", "testForm1_fr");
        assertNotNull("Form 'testForm1_fr' not found", form1_fr);
        Form form2_fr = this.resources.getForm("fr", "", "", "testForm2_fr");
        assertNotNull("Form 'testForm2_fr' not found", form2_fr);
        Field field1_fr = form1_fr.getField("testProperty1_fr");
        assertEquals("testProperty1_fr - const 1", "testConstValue1_fr", field1_fr.getVarValue("var11_fr"));
        assertEquals("testProperty1_fr - const 2", "testConstValue2_fr", field1_fr.getVarValue("var12_fr"));
        Field field2_fr = form2_fr.getField("testProperty2_fr");
        assertEquals("testProperty2_fr - const 1", "testConstValue1_fr", field2_fr.getVarValue("var21_fr"));
        assertEquals("testProperty2_fr - const 2", "testConstValue2_fr", field2_fr.getVarValue("var22_fr"));
    }

    public void testBothBlank() throws ValidatorException {
        NameBean name = new NameBean();
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull(firstNameResult);
        assertTrue(firstNameResult.containsAction(ACTION));
        assertTrue(!firstNameResult.isValid(ACTION));
        assertNotNull(lastNameResult);
        assertTrue(lastNameResult.containsAction(ACTION));
        assertTrue(!lastNameResult.isValid(ACTION));
        assertTrue(!lastNameResult.containsAction(Var.JSTYPE_INT));
    }

    public void testRequiredFirstNameBlankLastNameShort() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("");
        name.setLastName("Test");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull(firstNameResult);
        assertTrue(firstNameResult.containsAction(ACTION));
        assertTrue(!firstNameResult.isValid(ACTION));
        assertNotNull(lastNameResult);
        assertTrue(lastNameResult.containsAction(Var.JSTYPE_INT));
        assertTrue(!lastNameResult.isValid(Var.JSTYPE_INT));
    }

    public void testRequiredLastNameShort() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("Test");
        name.setLastName("Test");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull(firstNameResult);
        assertTrue(firstNameResult.containsAction(ACTION));
        assertTrue(firstNameResult.isValid(ACTION));
        assertNotNull(lastNameResult);
        assertTrue(lastNameResult.containsAction(Var.JSTYPE_INT));
        assertTrue(!lastNameResult.isValid(Var.JSTYPE_INT));
    }

    public void testRequiredLastNameLong() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("Joe");
        name.setLastName("12345678");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull(firstNameResult);
        assertTrue(firstNameResult.containsAction(ACTION));
        assertTrue(firstNameResult.isValid(ACTION));
        assertNotNull(lastNameResult);
        assertTrue(lastNameResult.containsAction(Var.JSTYPE_INT));
        assertTrue(lastNameResult.isValid(Var.JSTYPE_INT));
    }
}
