package org.apache.commons.validator;

import java.io.IOException;
import org.xml.sax.SAXException;

public class MultipleTest extends AbstractCommonTest {
    protected static String ACTION = "required";
    protected static String FORM_KEY = "nameForm";

    public MultipleTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws IOException, SAXException {
        loadResources("MultipleTests-config.xml");
    }

    /* access modifiers changed from: protected */
    public void tearDown() {
    }

    public void testBothBlank() throws ValidatorException {
        NameBean name = new NameBean();
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have failed.", !firstNameResult.isValid(ACTION));
        assertNotNull("Last Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have failed.", !lastNameResult.isValid(ACTION));
        assertTrue("Last Name ValidatorResults should not contain the 'int' action.", lastNameResult.containsAction(Var.JSTYPE_INT) ^ true);
    }

    public void testRequiredFirstNameBlankLastNameShort() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("");
        name.setLastName("Test");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have failed.", !firstNameResult.isValid(ACTION));
        assertNotNull("Last Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the 'int' action.", lastNameResult.containsAction(Var.JSTYPE_INT));
        assertTrue("Last Name ValidatorResult for the 'int' action should have failed.", lastNameResult.isValid(Var.JSTYPE_INT) ^ true);
    }

    public void testRequiredLastNameShort() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("Test");
        name.setLastName("Test");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have passed.", firstNameResult.isValid(ACTION));
        assertNotNull("Last Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the 'int' action.", lastNameResult.containsAction(Var.JSTYPE_INT));
        assertTrue("Last Name ValidatorResult for the 'int' action should have failed.", lastNameResult.isValid(Var.JSTYPE_INT) ^ true);
    }

    public void testRequiredLastNameLong() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("Joe");
        name.setLastName("12345678");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have passed.", firstNameResult.isValid(ACTION));
        assertNotNull("Last Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the 'int' action.", lastNameResult.containsAction(Var.JSTYPE_INT));
        assertTrue("Last Name ValidatorResult for the 'int' action should have passed.", lastNameResult.isValid(Var.JSTYPE_INT));
    }

    public void testFailingFirstDependentValidator() throws ValidatorException {
        NameBean name = new NameBean();
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult middleNameResult = results.getValidatorResult("middleName");
        assertNotNull("Middle Name ValidatorResult should not be null.", middleNameResult);
        assertTrue("Middle Name ValidatorResult should contain the 'required' action.", middleNameResult.containsAction("required"));
        assertTrue("Middle Name ValidatorResult for the 'required' action should have failed", !middleNameResult.isValid("required"));
        assertTrue("Middle Name ValidatorResult should not contain the 'int' action.", !middleNameResult.containsAction(Var.JSTYPE_INT));
        assertTrue("Middle Name ValidatorResult should not contain the 'positive' action.", !middleNameResult.containsAction("positive"));
    }

    public void testFailingNextDependentValidator() throws ValidatorException {
        NameBean name = new NameBean();
        name.setMiddleName("TEST");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult middleNameResult = results.getValidatorResult("middleName");
        assertNotNull("Middle Name ValidatorResult should not be null.", middleNameResult);
        assertTrue("Middle Name ValidatorResult should contain the 'required' action.", middleNameResult.containsAction("required"));
        assertTrue("Middle Name ValidatorResult for the 'required' action should have passed", middleNameResult.isValid("required"));
        assertTrue("Middle Name ValidatorResult should contain the 'int' action.", middleNameResult.containsAction(Var.JSTYPE_INT));
        assertTrue("Middle Name ValidatorResult for the 'int' action should have failed", !middleNameResult.isValid(Var.JSTYPE_INT));
        assertTrue("Middle Name ValidatorResult should not contain the 'positive' action.", !middleNameResult.containsAction("positive"));
    }

    public void testPassingDependentsFailingMain() throws ValidatorException {
        NameBean name = new NameBean();
        name.setMiddleName("-2534");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult middleNameResult = results.getValidatorResult("middleName");
        assertNotNull("Middle Name ValidatorResult should not be null.", middleNameResult);
        assertTrue("Middle Name ValidatorResult should contain the 'required' action.", middleNameResult.containsAction("required"));
        assertTrue("Middle Name ValidatorResult for the 'required' action should have passed", middleNameResult.isValid("required"));
        assertTrue("Middle Name ValidatorResult should contain the 'int' action.", middleNameResult.containsAction(Var.JSTYPE_INT));
        assertTrue("Middle Name ValidatorResult for the 'int' action should have passed", middleNameResult.isValid(Var.JSTYPE_INT));
        assertTrue("Middle Name ValidatorResult should contain the 'positive' action.", middleNameResult.containsAction("positive"));
        assertTrue("Middle Name ValidatorResult for the 'positive' action should have failed", !middleNameResult.isValid("positive"));
    }

    public void testPassingDependentsPassingMain() throws ValidatorException {
        NameBean name = new NameBean();
        name.setMiddleName("2534");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult middleNameResult = results.getValidatorResult("middleName");
        assertNotNull("Middle Name ValidatorResult should not be null.", middleNameResult);
        assertTrue("Middle Name ValidatorResult should contain the 'required' action.", middleNameResult.containsAction("required"));
        assertTrue("Middle Name ValidatorResult for the 'required' action should have passed", middleNameResult.isValid("required"));
        assertTrue("Middle Name ValidatorResult should contain the 'int' action.", middleNameResult.containsAction(Var.JSTYPE_INT));
        assertTrue("Middle Name ValidatorResult for the 'int' action should have passed", middleNameResult.isValid(Var.JSTYPE_INT));
        assertTrue("Middle Name ValidatorResult should contain the 'positive' action.", middleNameResult.containsAction("positive"));
        assertTrue("Middle Name ValidatorResult for the 'positive' action should have passed", middleNameResult.isValid("positive"));
    }
}
