package org.apache.commons.validator;

import java.io.IOException;
import java.util.Locale;
import org.xml.sax.SAXException;

public class ParameterTest extends AbstractCommonTest {
    private static final String FORM_KEY = "nameForm";
    private String firstName;
    private String lastName;
    private String middleName;

    public ParameterTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws IOException, SAXException {
        loadResources("ParameterTest-config.xml");
        this.firstName = "foo";
        this.middleName = "123";
        this.lastName = "456";
    }

    /* access modifiers changed from: protected */
    public void tearDown() {
    }

    public void testAllValid() {
        NameBean bean = createNameBean();
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, bean);
        validator.setParameter(Validator.LOCALE_PARAM, Locale.getDefault());
        try {
            validator.validate();
        } catch (Exception e) {
            fail("Validator.validate() threw " + e);
        }
        assertParameterValue(validator, Validator.BEAN_PARAM, Object.class);
        assertParameterValue(validator, Validator.FIELD_PARAM, Field.class);
        assertParameterValue(validator, Validator.FORM_PARAM, Form.class);
        assertParameterValue(validator, Validator.LOCALE_PARAM, Locale.class);
        assertParameterValue(validator, Validator.VALIDATOR_ACTION_PARAM, ValidatorAction.class);
        assertParameterValue(validator, Validator.VALIDATOR_PARAM, Validator.class);
        assertParameterValue(validator, Validator.VALIDATOR_RESULTS_PARAM, ValidatorResults.class);
    }

    private void assertParameterValue(Validator validator, String name, Class<?> type) {
        Object value = validator.getParameterValue(name);
        assertNotNull("Expected '" + type.getName() + "' but was null", value);
        assertTrue("Expected '" + type.getName() + "' but was '" + value.getClass().getName() + "'", type.isInstance(value));
    }

    private NameBean createNameBean() {
        NameBean name = new NameBean();
        name.setFirstName(this.firstName);
        name.setMiddleName(this.middleName);
        name.setLastName(this.lastName);
        return name;
    }
}
