package org.apache.commons.validator;

import java.io.IOException;
import org.xml.sax.SAXException;

public class RequiredIfTest extends AbstractCommonTest {
    protected static String ACTION = "requiredif";
    protected static String FORM_KEY = "nameForm";

    public RequiredIfTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws IOException, SAXException {
        loadResources("RequiredIfTest-config.xml");
    }

    /* access modifiers changed from: protected */
    public void tearDown() {
    }

    public void testRequired() throws ValidatorException {
        NameBean name = new NameBean();
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have passed.", firstNameResult.isValid(ACTION));
        assertNotNull("Last Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have passed.", lastNameResult.isValid(ACTION));
    }

    public void testRequiredFirstNameBlank() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("");
        name.setLastName("Test");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have failed.", !firstNameResult.isValid(ACTION));
        assertNotNull("Last Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have passed.", lastNameResult.isValid(ACTION));
    }

    public void testRequiredFirstName() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("Test");
        name.setLastName("Test");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have passed.", firstNameResult.isValid(ACTION));
        assertNotNull("Last Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have passed.", lastNameResult.isValid(ACTION));
    }

    public void testRequiredLastNameBlank() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("Joe");
        name.setLastName("");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have passed.", firstNameResult.isValid(ACTION));
        assertNotNull("Last Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have failed.", !lastNameResult.isValid(ACTION));
    }

    public void testRequiredLastName() throws ValidatorException {
        NameBean name = new NameBean();
        name.setFirstName("Joe");
        name.setLastName("Smith");
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, name);
        ValidatorResults results = validator.validate();
        assertNotNull("Results are null.", results);
        ValidatorResult firstNameResult = results.getValidatorResult("firstName");
        ValidatorResult lastNameResult = results.getValidatorResult("lastName");
        assertNotNull("First Name ValidatorResult should not be null.", firstNameResult);
        assertTrue("First Name ValidatorResult should contain the '" + ACTION + "' action.", firstNameResult.containsAction(ACTION));
        assertTrue("First Name ValidatorResult for the '" + ACTION + "' action should have passed.", firstNameResult.isValid(ACTION));
        assertNotNull("Last Name ValidatorResult should not be null.", lastNameResult);
        assertTrue("Last Name ValidatorResult should contain the '" + ACTION + "' action.", lastNameResult.containsAction(ACTION));
        assertTrue("Last Name ValidatorResult for the '" + ACTION + "' action should have passed.", lastNameResult.isValid(ACTION));
    }
}
