package org.apache.commons.validator;

import java.io.IOException;
import java.io.InputStream;
import java.util.Locale;
import junit.framework.TestCase;
import org.xml.sax.SAXException;

public class RetrieveFormTest extends TestCase {
    private static final Locale CANADA_FRENCH_XXX = new Locale("fr", "CA", "XXX");
    private static final String FORM_PREFIX = "testForm_";
    private ValidatorResources resources = null;

    public RetrieveFormTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws IOException, SAXException {
        InputStream[] streams = {getClass().getResourceAsStream("RetrieveFormTest-config.xml")};
        this.resources = new ValidatorResources(streams);
        for (InputStream inputStream : streams) {
            inputStream.close();
        }
    }

    public void testDefaultForm() {
        checkForm(Locale.US, "testForm_default", "default");
        checkForm(Locale.FRENCH, "testForm_default", "default");
        checkForm(Locale.FRANCE, "testForm_default", "default");
        checkForm(Locale.CANADA, "testForm_default", "default");
        checkForm(Locale.CANADA_FRENCH, "testForm_default", "default");
        checkForm(CANADA_FRENCH_XXX, "testForm_default", "default");
    }

    public void testLanguageForm() {
        checkForm(Locale.US, "testForm_language", "default");
        checkForm(Locale.FRENCH, "testForm_language", "fr");
        checkForm(Locale.FRANCE, "testForm_language", "fr");
        checkForm(Locale.CANADA, "testForm_language", "default");
        checkForm(Locale.CANADA_FRENCH, "testForm_language", "fr");
        checkForm(CANADA_FRENCH_XXX, "testForm_language", "fr");
    }

    public void testLanguageCountryForm() {
        checkForm(Locale.US, "testForm_language_country", "default");
        checkForm(Locale.FRENCH, "testForm_language_country", "fr");
        checkForm(Locale.FRANCE, "testForm_language_country", "fr_FR");
        checkForm(Locale.CANADA, "testForm_language_country", "default");
        checkForm(Locale.CANADA_FRENCH, "testForm_language_country", "fr_CA");
        checkForm(CANADA_FRENCH_XXX, "testForm_language_country", "fr_CA");
    }

    public void testLanguageCountryVariantForm() {
        checkForm(Locale.US, "testForm_language_country_variant", "default");
        checkForm(Locale.FRENCH, "testForm_language_country_variant", "fr");
        checkForm(Locale.FRANCE, "testForm_language_country_variant", "fr_FR");
        checkForm(Locale.CANADA, "testForm_language_country_variant", "default");
        checkForm(Locale.CANADA_FRENCH, "testForm_language_country_variant", "fr_CA");
        checkForm(CANADA_FRENCH_XXX, "testForm_language_country_variant", "fr_CA_XXX");
    }

    public void testFormNotFound() {
        checkFormNotFound(Locale.US, "INVALID_NAME");
        checkFormNotFound(Locale.FRENCH, "INVALID_NAME");
        checkFormNotFound(Locale.FRANCE, "INVALID_NAME");
        checkFormNotFound(Locale.CANADA, "INVALID_NAME");
        checkFormNotFound(Locale.CANADA_FRENCH, "INVALID_NAME");
        checkFormNotFound(CANADA_FRENCH_XXX, "INVALID_NAME");
    }

    private void checkForm(Locale locale, String formKey, String expectedVarValue) {
        Form testForm = this.resources.getForm(locale, formKey);
        assertNotNull("Form '" + formKey + "' null for locale " + locale, testForm);
        Field testField = testForm.getField("testProperty");
        assertEquals("Incorrect Form '" + formKey + "' for locale '" + locale + "'", expectedVarValue, testField.getVarValue("localeVar"));
    }

    private void checkFormNotFound(Locale locale, String formKey) {
        Form testForm = this.resources.getForm(locale, formKey);
        assertNull("Form '" + formKey + "' not null for locale " + locale, testForm);
    }
}
