package org.apache.commons.validator;

import junit.framework.TestCase;

@Deprecated
public class UrlTest extends TestCase {
    private final boolean printIndex = false;
    private final boolean printStatus = false;
    int[] testPartsIndex;
    ResultPair[] testPath = {new ResultPair("/test1", true), new ResultPair("/t123", true), new ResultPair("/$23", true), new ResultPair("/..", false), new ResultPair("/../", false), new ResultPair("/test1/", true), new ResultPair("", true), new ResultPair("/test1/file", true), new ResultPair("/..//file", false), new ResultPair("/test1//file", false)};
    ResultPair[] testScheme;
    ResultPair[] testUrlAuthority = {new ResultPair("www.google.com", true), new ResultPair("go.com", true), new ResultPair("go.au", true), new ResultPair("0.0.0.0", true), new ResultPair("255.255.255.255", true), new ResultPair("256.256.256.256", false), new ResultPair("255.com", true), new ResultPair("1.2.3.4.5", false), new ResultPair("1.2.3.4.", false), new ResultPair("1.2.3", false), new ResultPair(".1.2.3.4", false), new ResultPair("go.a", false), new ResultPair("go.a1a", true), new ResultPair("go.1aa", false), new ResultPair("aaa.", false), new ResultPair(".aaa", false), new ResultPair("aaa", false), new ResultPair("", false)};
    Object[] testUrlParts;
    Object[] testUrlPartsOptions;
    ResultPair[] testUrlPathOptions = {new ResultPair("/test1", true), new ResultPair("/t123", true), new ResultPair("/$23", true), new ResultPair("/..", false), new ResultPair("/../", false), new ResultPair("/test1/", true), new ResultPair("/#", false), new ResultPair("", true), new ResultPair("/test1/file", true), new ResultPair("/t123/file", true), new ResultPair("/$23/file", true), new ResultPair("/../file", false), new ResultPair("/..//file", false), new ResultPair("/test1//file", true), new ResultPair("/#/file", false)};
    ResultPair[] testUrlPort = {new ResultPair(":80", true), new ResultPair(":65535", true), new ResultPair(":0", true), new ResultPair("", true), new ResultPair(":-1", false), new ResultPair(":65636", true), new ResultPair(":65a", false)};
    ResultPair[] testUrlQuery;
    ResultPair[] testUrlScheme = {new ResultPair("http://", true), new ResultPair("ftp://", true), new ResultPair("h3t://", true), new ResultPair("3ht://", false), new ResultPair("http:/", false), new ResultPair("http:", false), new ResultPair("http/", false), new ResultPair("://", false), new ResultPair("", true)};

    public UrlTest(String testName) {
        super(testName);
        ResultPair[] resultPairArr = {new ResultPair("?action=view", true), new ResultPair("?action=edit&mode=up", true), new ResultPair("", true)};
        this.testUrlQuery = resultPairArr;
        ResultPair[] resultPairArr2 = this.testUrlScheme;
        ResultPair[] resultPairArr3 = this.testUrlAuthority;
        ResultPair[] resultPairArr4 = this.testUrlPort;
        this.testUrlParts = new Object[]{resultPairArr2, resultPairArr3, resultPairArr4, this.testPath, resultPairArr};
        this.testUrlPartsOptions = new Object[]{resultPairArr2, resultPairArr3, resultPairArr4, this.testUrlPathOptions, resultPairArr};
        this.testPartsIndex = new int[]{0, 0, 0, 0, 0};
        this.testScheme = new ResultPair[]{new ResultPair("http", true), new ResultPair("ftp", false), new ResultPair("httpd", false), new ResultPair("telnet", false)};
    }

    /* access modifiers changed from: protected */
    public void setUp() {
        int index = 0;
        while (true) {
            int[] iArr = this.testPartsIndex;
            if (index < iArr.length - 1) {
                iArr[index] = 0;
                index++;
            } else {
                return;
            }
        }
    }

    public void testIsValid() {
        testIsValid(this.testUrlParts, 1);
        setUp();
        testIsValid(this.testUrlPartsOptions, 7);
    }

    public void testIsValidScheme() {
        UrlValidator urlVal = new UrlValidator(new String[]{"http", "gopher"}, 0);
        int sIndex = 0;
        while (true) {
            ResultPair[] resultPairArr = this.testScheme;
            if (sIndex < resultPairArr.length) {
                ResultPair testPair = resultPairArr[sIndex];
                assertEquals(testPair.item, testPair.valid, urlVal.isValidScheme(testPair.item));
                sIndex++;
            } else {
                return;
            }
        }
    }

    public void testIsValid(Object[] testObjects, int options) {
        UrlValidator urlVal = new UrlValidator(null, options);
        assertTrue(urlVal.isValid("http://www.google.com"));
        assertTrue(urlVal.isValid("http://www.google.com/"));
        do {
            StringBuilder testBuffer = new StringBuilder();
            boolean expected = true;
            int testPartsIndexIndex = 0;
            while (true) {
                int[] iArr = this.testPartsIndex;
                if (testPartsIndexIndex < iArr.length) {
                    int index = iArr[testPartsIndexIndex];
                    ResultPair[] part = (ResultPair[]) testObjects[testPartsIndexIndex];
                    testBuffer.append(part[index].item);
                    expected &= part[index].valid;
                    testPartsIndexIndex++;
                } else {
                    String url = testBuffer.toString();
                    assertEquals(url, expected, urlVal.isValid(url));
                }
            }
        } while (incrementTestPartsIndex(this.testPartsIndex, testObjects));
    }

    public void testValidator202() {
        new UrlValidator(new String[]{"http", "https"}, 4).isValid("http://www.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.logoworks.comwww.log");
    }

    public void testValidator204() {
        assertTrue(new UrlValidator(new String[]{"http", "https"}).isValid("http://tech.yahoo.com/rc/desktops/102;_ylt=Ao8yevQHlZ4On0O3ZJGXLEQFLZA5"));
    }

    static boolean incrementTestPartsIndex(int[] testPartsIndex2, Object[] testParts) {
        boolean carry = true;
        boolean maxIndex = true;
        for (int testPartsIndexIndex = testPartsIndex2.length - 1; testPartsIndexIndex >= 0; testPartsIndexIndex--) {
            int index = testPartsIndex2[testPartsIndexIndex];
            ResultPair[] part = (ResultPair[]) testParts[testPartsIndexIndex];
            boolean z = false;
            if (carry) {
                if (index < part.length - 1) {
                    index++;
                    testPartsIndex2[testPartsIndexIndex] = index;
                    carry = false;
                } else {
                    testPartsIndex2[testPartsIndexIndex] = 0;
                    carry = true;
                }
            }
            if (index == part.length - 1) {
                z = true;
            }
            maxIndex &= z;
        }
        return !maxIndex;
    }

    private String testPartsIndextoString() {
        StringBuilder carryMsg = new StringBuilder("{");
        int testPartsIndexIndex = 0;
        while (true) {
            int[] iArr = this.testPartsIndex;
            if (testPartsIndexIndex >= iArr.length) {
                return carryMsg.toString();
            }
            carryMsg.append(iArr[testPartsIndexIndex]);
            if (testPartsIndexIndex < this.testPartsIndex.length - 1) {
                carryMsg.append(',');
            } else {
                carryMsg.append('}');
            }
            testPartsIndexIndex++;
        }
    }

    public void testValidateUrl() {
        assertTrue(true);
    }

    public static void main(String[] argv) {
        UrlTest fct = new UrlTest("url test");
        fct.setUp();
        fct.testIsValid();
        fct.testIsValidScheme();
    }
}
