package org.apache.commons.validator;

import java.io.Serializable;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.commons.validator.routines.InetAddressValidator;
import org.apache.commons.validator.util.Flags;

@Deprecated
public class UrlValidator implements Serializable {
    public static final int ALLOW_2_SLASHES = 2;
    public static final int ALLOW_ALL_SCHEMES = 1;
    private static final String ALPHA_CHARS = "a-zA-Z";
    private static final Pattern ALPHA_PATTERN = Pattern.compile("^[a-zA-Z]");
    private static final String ATOM = "[^\\s;/@&=,.?:+$]+";
    private static final Pattern ATOM_PATTERN = Pattern.compile("^([^\\s;/@&=,.?:+$]+).*?$");
    private static final String AUTHORITY_CHARS_REGEX = "\\p{Alnum}\\-\\.";
    private static final Pattern AUTHORITY_PATTERN = Pattern.compile(AUTHORITY_REGEX);
    private static final String AUTHORITY_REGEX = "^([\\p{Alnum}\\-\\.]*)(:\\d*)?(.*)?";
    private static final Pattern DOMAIN_PATTERN = Pattern.compile("^[^\\s;/@&=,.?:+$]+(\\.[^\\s;/@&=,.?:+$]+)*$");
    private static final Pattern LEGAL_ASCII_PATTERN = Pattern.compile("^\\p{ASCII}+$");
    public static final int NO_FRAGMENTS = 4;
    private static final int PARSE_AUTHORITY_EXTRA = 3;
    private static final int PARSE_AUTHORITY_HOST_IP = 1;
    private static final int PARSE_AUTHORITY_PORT = 2;
    private static final int PARSE_URL_AUTHORITY = 4;
    private static final int PARSE_URL_FRAGMENT = 9;
    private static final int PARSE_URL_PATH = 5;
    private static final int PARSE_URL_QUERY = 7;
    private static final int PARSE_URL_SCHEME = 2;
    private static final Pattern PATH_PATTERN = Pattern.compile("^(/[-\\w:@&?=+,.!/~*'%$_;]*)?$");
    private static final Pattern PORT_PATTERN = Pattern.compile("^:(\\d{1,5})$");
    private static final Pattern QUERY_PATTERN = Pattern.compile("^(.*)$");
    private static final Pattern SCHEME_PATTERN = Pattern.compile("^\\p{Alpha}[\\p{Alnum}\\+\\-\\.]*");
    private static final String SPECIAL_CHARS = ";/@&=,.?:+$";
    private static final Pattern URL_PATTERN = Pattern.compile(URL_REGEX);
    private static final String URL_REGEX = "^(([^:/?#]+):)?(//([^/?#]*))?([^?#]*)(\\?([^#]*))?(#(.*))?";
    private static final String VALID_CHARS = "[^\\s;/@&=,.?:+$]";
    private static final long serialVersionUID = 24137157400029593L;
    private final Set<String> allowedSchemes;
    protected String[] defaultSchemes;
    private final Flags options;

    public UrlValidator() {
        this((String[]) null);
    }

    public UrlValidator(String[] schemes) {
        this(schemes, 0);
    }

    public UrlValidator(int options2) {
        this(null, options2);
    }

    public UrlValidator(String[] schemes, int options2) {
        HashSet hashSet = new HashSet();
        this.allowedSchemes = hashSet;
        this.defaultSchemes = new String[]{"http", "https", "ftp"};
        Flags flags = new Flags((long) options2);
        this.options = flags;
        if (!flags.isOn(1)) {
            hashSet.addAll(Arrays.asList(schemes == null ? this.defaultSchemes : schemes));
        }
    }

    public boolean isValid(String value) {
        if (value == null || !LEGAL_ASCII_PATTERN.matcher(value).matches()) {
            return false;
        }
        Matcher urlMatcher = URL_PATTERN.matcher(value);
        if (urlMatcher.matches() && isValidScheme(urlMatcher.group(2)) && isValidAuthority(urlMatcher.group(4)) && isValidPath(urlMatcher.group(5)) && isValidQuery(urlMatcher.group(7)) && isValidFragment(urlMatcher.group(9))) {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public boolean isValidScheme(String scheme) {
        if (scheme == null || !SCHEME_PATTERN.matcher(scheme).matches()) {
            return false;
        }
        if (!this.options.isOff(1) || this.allowedSchemes.contains(scheme)) {
            return true;
        }
        return false;
    }

    /* JADX INFO: Multiple debug info for r11v2 java.lang.String[]: [D('domainSegment' java.lang.String[]), D('i' int)] */
    /* access modifiers changed from: protected */
    public boolean isValidAuthority(String authority) {
        boolean z;
        char[] chars;
        if (authority == null) {
            return false;
        }
        InetAddressValidator inetAddressValidator = InetAddressValidator.getInstance();
        Matcher authorityMatcher = AUTHORITY_PATTERN.matcher(authority);
        if (!authorityMatcher.matches()) {
            return false;
        }
        boolean hostname = false;
        String hostIP = authorityMatcher.group(1);
        boolean ipV4Address = inetAddressValidator.isValid(hostIP);
        if (!ipV4Address) {
            hostname = DOMAIN_PATTERN.matcher(hostIP).matches();
        }
        if (hostname) {
            int size = 1;
            for (char c : hostIP.toCharArray()) {
                if (c == '.') {
                    size++;
                }
            }
            String[] domainSegment = new String[size];
            boolean match = true;
            int segmentCount = 0;
            while (match) {
                Matcher atomMatcher = ATOM_PATTERN.matcher(hostIP);
                match = atomMatcher.matches();
                if (match) {
                    domainSegment[segmentCount] = atomMatcher.group(1);
                    int segmentLength = domainSegment[segmentCount].length() + 1;
                    segmentCount++;
                    hostIP = segmentLength >= hostIP.length() ? "" : hostIP.substring(segmentLength);
                }
            }
            String topLevel = domainSegment[segmentCount - 1];
            if (topLevel.length() < 2 || topLevel.length() > 4) {
                return false;
            }
            z = false;
            if (!ALPHA_PATTERN.matcher(topLevel.substring(0, 1)).matches() || segmentCount < 2) {
                return false;
            }
        } else {
            z = false;
        }
        if (!(hostname || ipV4Address)) {
            return z;
        }
        String port = authorityMatcher.group(2);
        if ((port == null || PORT_PATTERN.matcher(port).matches()) && GenericValidator.isBlankOrNull(authorityMatcher.group(3))) {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public boolean isValidPath(String path) {
        if (path == null || !PATH_PATTERN.matcher(path).matches()) {
            return false;
        }
        int slash2Count = countToken("//", path);
        if (this.options.isOff(2) && slash2Count > 0) {
            return false;
        }
        int slashCount = countToken("/", path);
        int dot2Count = countToken("..", path);
        if (dot2Count <= 0 || (slashCount - slash2Count) - 1 > dot2Count) {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public boolean isValidQuery(String query) {
        if (query == null) {
            return true;
        }
        return QUERY_PATTERN.matcher(query).matches();
    }

    /* access modifiers changed from: protected */
    public boolean isValidFragment(String fragment) {
        if (fragment == null) {
            return true;
        }
        return this.options.isOff(4);
    }

    /* access modifiers changed from: protected */
    public int countToken(String token, String target) {
        int tokenIndex = 0;
        int count = 0;
        while (tokenIndex != -1) {
            tokenIndex = target.indexOf(token, tokenIndex);
            if (tokenIndex > -1) {
                tokenIndex++;
                count++;
            }
        }
        return count;
    }
}
