package org.apache.commons.validator;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

public class Validator implements Serializable {
    public static final String BEAN_PARAM = "java.lang.Object";
    public static final String FIELD_PARAM = "org.apache.commons.validator.Field";
    public static final String FORM_PARAM = "org.apache.commons.validator.Form";
    public static final String LOCALE_PARAM = "java.util.Locale";
    public static final String VALIDATOR_ACTION_PARAM = "org.apache.commons.validator.ValidatorAction";
    public static final String VALIDATOR_PARAM = "org.apache.commons.validator.Validator";
    public static final String VALIDATOR_RESULTS_PARAM = "org.apache.commons.validator.ValidatorResults";
    private static final long serialVersionUID = -7119418755208731611L;
    protected transient ClassLoader classLoader;
    protected String fieldName;
    protected String formName;
    protected boolean onlyReturnErrors;
    protected int page;
    protected Map<String, Object> parameters;
    protected ValidatorResources resources;
    protected boolean useContextClassLoader;

    public Validator(ValidatorResources resources2) {
        this(resources2, null);
    }

    public Validator(ValidatorResources resources2, String formName2) {
        this.resources = null;
        this.formName = null;
        this.fieldName = null;
        this.parameters = new HashMap();
        this.page = 0;
        this.classLoader = null;
        this.useContextClassLoader = false;
        this.onlyReturnErrors = false;
        if (resources2 != null) {
            this.resources = resources2;
            this.formName = formName2;
            return;
        }
        throw new IllegalArgumentException("Resources cannot be null.");
    }

    public Validator(ValidatorResources resources2, String formName2, String fieldName2) {
        this.resources = null;
        this.formName = null;
        this.fieldName = null;
        this.parameters = new HashMap();
        this.page = 0;
        this.classLoader = null;
        this.useContextClassLoader = false;
        this.onlyReturnErrors = false;
        if (resources2 != null) {
            this.resources = resources2;
            this.formName = formName2;
            this.fieldName = fieldName2;
            return;
        }
        throw new IllegalArgumentException("Resources cannot be null.");
    }

    public void setParameter(String parameterClassName, Object parameterValue) {
        this.parameters.put(parameterClassName, parameterValue);
    }

    public Object getParameterValue(String parameterClassName) {
        return this.parameters.get(parameterClassName);
    }

    public String getFormName() {
        return this.formName;
    }

    public void setFormName(String formName2) {
        this.formName = formName2;
    }

    public void setFieldName(String fieldName2) {
        this.fieldName = fieldName2;
    }

    public int getPage() {
        return this.page;
    }

    public void setPage(int page2) {
        this.page = page2;
    }

    public void clear() {
        this.formName = null;
        this.fieldName = null;
        this.parameters = new HashMap();
        this.page = 0;
    }

    public boolean getUseContextClassLoader() {
        return this.useContextClassLoader;
    }

    public void setUseContextClassLoader(boolean use) {
        this.useContextClassLoader = use;
    }

    public ClassLoader getClassLoader() {
        ClassLoader contextLoader;
        ClassLoader classLoader2 = this.classLoader;
        if (classLoader2 != null) {
            return classLoader2;
        }
        if (!this.useContextClassLoader || (contextLoader = Thread.currentThread().getContextClassLoader()) == null) {
            return getClass().getClassLoader();
        }
        return contextLoader;
    }

    public void setClassLoader(ClassLoader classLoader2) {
        this.classLoader = classLoader2;
    }

    public ValidatorResults validate() throws ValidatorException {
        Locale locale = (Locale) getParameterValue(LOCALE_PARAM);
        if (locale == null) {
            locale = Locale.getDefault();
        }
        setParameter(VALIDATOR_PARAM, this);
        Form form = this.resources.getForm(locale, this.formName);
        if (form == null) {
            return new ValidatorResults();
        }
        setParameter(FORM_PARAM, form);
        return form.validate(this.parameters, this.resources.getValidatorActions(), this.page, this.fieldName);
    }

    public boolean getOnlyReturnErrors() {
        return this.onlyReturnErrors;
    }

    public void setOnlyReturnErrors(boolean onlyReturnErrors2) {
        this.onlyReturnErrors = onlyReturnErrors2;
    }
}
