package org.apache.commons.validator;

import java.io.Serializable;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

public class ValidatorResult implements Serializable {
    private static final long serialVersionUID = -3713364681647250531L;
    protected Field field = null;
    protected Map<String, ResultStatus> hAction = new HashMap();

    public ValidatorResult(Field field2) {
        this.field = field2;
    }

    public void add(String validatorName, boolean result) {
        add(validatorName, result, null);
    }

    public void add(String validatorName, boolean result, Object value) {
        this.hAction.put(validatorName, new ResultStatus(result, value));
    }

    public boolean containsAction(String validatorName) {
        return this.hAction.containsKey(validatorName);
    }

    public boolean isValid(String validatorName) {
        ResultStatus status = this.hAction.get(validatorName);
        if (status == null) {
            return false;
        }
        return status.isValid();
    }

    public Object getResult(String validatorName) {
        ResultStatus status = this.hAction.get(validatorName);
        if (status == null) {
            return null;
        }
        return status.getResult();
    }

    public Iterator<String> getActions() {
        return Collections.unmodifiableMap(this.hAction).keySet().iterator();
    }

    @Deprecated
    public Map<String, ResultStatus> getActionMap() {
        return Collections.unmodifiableMap(this.hAction);
    }

    public Field getField() {
        return this.field;
    }

    /* access modifiers changed from: protected */
    public static class ResultStatus implements Serializable {
        private static final long serialVersionUID = 4076665918535320007L;
        private Object result;
        private boolean valid;

        public ResultStatus(boolean valid2, Object result2) {
            this.valid = false;
            this.result = null;
            this.valid = valid2;
            this.result = result2;
        }

        @Deprecated
        public ResultStatus(ValidatorResult ignored, boolean valid2, Object result2) {
            this(valid2, result2);
        }

        public boolean isValid() {
            return this.valid;
        }

        public void setValid(boolean valid2) {
            this.valid = valid2;
        }

        public Object getResult() {
            return this.result;
        }

        public void setResult(Object result2) {
            this.result = result2;
        }
    }
}
