package org.apache.commons.validator;

import java.io.IOException;
import org.xml.sax.SAXException;

public class ValidatorResultsTest extends AbstractCommonTest {
    private static final String FORM_KEY = "nameForm";
    private static final String firstNameField = "firstName";
    private static final String lastNameField = "lastName";
    private static final String middleNameField = "middleName";
    private String firstName;
    private String lastName;
    private String middleName;

    public ValidatorResultsTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws IOException, SAXException {
        loadResources("ValidatorResultsTest-config.xml");
        this.firstName = "foo";
        this.middleName = "123";
        this.lastName = "456";
    }

    /* access modifiers changed from: protected */
    public void tearDown() {
    }

    public void testAllValid() throws ValidatorException {
        ValidatorResults results = validate(createNameBean());
        checkValidatorResult(results, firstNameField, "required", true);
        checkValidatorResult(results, middleNameField, "required", true);
        checkValidatorResult(results, middleNameField, Var.JSTYPE_INT, true);
        checkValidatorResult(results, middleNameField, "positive", true);
        checkValidatorResult(results, lastNameField, "required", true);
        checkValidatorResult(results, lastNameField, Var.JSTYPE_INT, true);
    }

    public void testErrors() throws ValidatorException {
        this.middleName = "XXX";
        this.lastName = null;
        ValidatorResults results = validate(createNameBean());
        checkValidatorResult(results, firstNameField, "required", true);
        checkValidatorResult(results, middleNameField, "required", true);
        checkValidatorResult(results, middleNameField, Var.JSTYPE_INT, false);
        checkNotRun(results, middleNameField, "positive");
        checkValidatorResult(results, lastNameField, "required", false);
        checkNotRun(results, lastNameField, Var.JSTYPE_INT);
    }

    private void checkNotRun(ValidatorResults results, String field, String action) {
        ValidatorResult result = results.getValidatorResult(field);
        assertNotNull(field + " result", result);
        assertFalse(field + "[" + action + "] run", result.containsAction(action));
    }

    private void checkValidatorResult(ValidatorResults results, String field, String action, boolean expected) {
        ValidatorResult result = results.getValidatorResult(field);
        assertNotNull(field + " result", result);
        assertTrue(field + "[" + action + "] not run", result.containsAction(action));
        assertEquals(field + "[" + action + "] result", expected, result.isValid(action));
    }

    private NameBean createNameBean() {
        NameBean name = new NameBean();
        name.setFirstName(this.firstName);
        name.setMiddleName(this.middleName);
        name.setLastName(this.lastName);
        return name;
    }

    private ValidatorResults validate(Object bean) throws ValidatorException {
        Validator validator = new Validator(this.resources, FORM_KEY);
        validator.setParameter(Validator.BEAN_PARAM, bean);
        return validator.validate();
    }
}
