package org.apache.commons.validator.routines;

import java.math.BigDecimal;
import java.util.Locale;

public class BigDecimalValidatorTest extends AbstractNumberValidatorTest {
    public BigDecimalValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractNumberValidatorTest
    public void setUp() throws Exception {
        super.setUp();
        this.validator = new BigDecimalValidator(false);
        this.strictValidator = new BigDecimalValidator();
        this.testPattern = "#,###.###";
        this.max = null;
        this.maxPlusOne = null;
        this.min = null;
        this.minMinusOne = null;
        this.invalidStrict = new String[]{null, "", "X", "X12", "12X", "1X2", "1.234X"};
        this.invalid = new String[]{null, "", "X", "X12"};
        this.testNumber = new BigDecimal("1234.5");
        Number testNumber2 = new BigDecimal(".1");
        Number testNumber3 = new BigDecimal("12345.67899");
        this.testZero = new BigDecimal("0");
        this.validStrict = new String[]{"0", "1234.5", "1,234.5", ".1", "12345.678990"};
        this.validStrictCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, testNumber2, testNumber3};
        this.valid = new String[]{"0", "1234.5", "1,234.5", "1,234.5", "1234.5X"};
        this.validCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, this.testNumber, this.testNumber};
        this.testStringUS = "1,234.5";
        this.testStringDE = "1.234,5";
        this.localeValue = this.testStringDE;
        this.localePattern = "#.###,#";
        this.testLocale = Locale.GERMANY;
        this.localeExpected = this.testNumber;
    }

    public void testBigDecimalValidatorMethods() {
        Locale locale = Locale.GERMAN;
        BigDecimal expected = new BigDecimal(12345);
        assertEquals("validate(A) default", expected, BigDecimalValidator.getInstance().validate("12,345"));
        assertEquals("validate(A) locale ", expected, BigDecimalValidator.getInstance().validate("12.345", locale));
        assertEquals("validate(A) pattern", expected, BigDecimalValidator.getInstance().validate("1,23,45", "0,00,00"));
        assertEquals("validate(A) both", expected, BigDecimalValidator.getInstance().validate("1.23.45", "0,00,00", Locale.GERMAN));
        assertTrue("isValid(A) default", BigDecimalValidator.getInstance().isValid("12,345"));
        assertTrue("isValid(A) locale ", BigDecimalValidator.getInstance().isValid("12.345", locale));
        assertTrue("isValid(A) pattern", BigDecimalValidator.getInstance().isValid("1,23,45", "0,00,00"));
        assertTrue("isValid(A) both", BigDecimalValidator.getInstance().isValid("1.23.45", "0,00,00", Locale.GERMAN));
        assertNull("validate(B) default", BigDecimalValidator.getInstance().validate("XXXX"));
        assertNull("validate(B) locale ", BigDecimalValidator.getInstance().validate("XXXX", locale));
        assertNull("validate(B) pattern", BigDecimalValidator.getInstance().validate("XXXX", "0,00,00"));
        assertNull("validate(B) both", BigDecimalValidator.getInstance().validate("1,23,45", "0,00,00", Locale.GERMAN));
        assertFalse("isValid(B) default", BigDecimalValidator.getInstance().isValid("XXXX"));
        assertFalse("isValid(B) locale ", BigDecimalValidator.getInstance().isValid("XXXX", locale));
        assertFalse("isValid(B) pattern", BigDecimalValidator.getInstance().isValid("XXXX", "0,00,00"));
        assertFalse("isValid(B) both", BigDecimalValidator.getInstance().isValid("1,23,45", "0,00,00", Locale.GERMAN));
    }

    public void testBigDecimalRangeMinMax() {
        BigDecimalValidator validator = new BigDecimalValidator(true, 0, true);
        BigDecimal number9 = new BigDecimal("9");
        BigDecimal number10 = new BigDecimal("10");
        BigDecimal number11 = new BigDecimal("11");
        BigDecimal number19 = new BigDecimal("19");
        BigDecimal number20 = new BigDecimal("20");
        BigDecimal number21 = new BigDecimal("21");
        assertFalse("isInRange(A) < min", validator.isInRange(number9, (double) 10.0f, (double) 20.0f));
        assertTrue("isInRange(A) = min", validator.isInRange(number10, (double) 10.0f, (double) 20.0f));
        assertTrue("isInRange(A) in range", validator.isInRange(number11, (double) 10.0f, (double) 20.0f));
        assertTrue("isInRange(A) = max", validator.isInRange(number20, (double) 10.0f, (double) 20.0f));
        assertFalse("isInRange(A) > max", validator.isInRange(number21, (double) 10.0f, (double) 20.0f));
        assertFalse("minValue(A) < min", validator.minValue(number9, (double) 10.0f));
        assertTrue("minValue(A) = min", validator.minValue(number10, (double) 10.0f));
        assertTrue("minValue(A) > min", validator.minValue(number11, (double) 10.0f));
        assertTrue("maxValue(A) < max", validator.maxValue(number19, (double) 20.0f));
        assertTrue("maxValue(A) = max", validator.maxValue(number20, (double) 20.0f));
        assertFalse("maxValue(A) > max", validator.maxValue(number21, (double) 20.0f));
    }
}
