package org.apache.commons.validator.routines;

import java.math.BigInteger;
import java.text.Format;
import java.util.Locale;

public class BigIntegerValidator extends AbstractNumberValidator {
    private static final BigIntegerValidator VALIDATOR = new BigIntegerValidator();
    private static final long serialVersionUID = 6713144356347139988L;

    public static BigIntegerValidator getInstance() {
        return VALIDATOR;
    }

    public BigIntegerValidator() {
        this(true, 0);
    }

    public BigIntegerValidator(boolean strict, int formatType) {
        super(strict, formatType, false);
    }

    public BigInteger validate(String value) {
        return (BigInteger) parse(value, null, null);
    }

    public BigInteger validate(String value, String pattern) {
        return (BigInteger) parse(value, pattern, null);
    }

    public BigInteger validate(String value, Locale locale) {
        return (BigInteger) parse(value, null, locale);
    }

    public BigInteger validate(String value, String pattern, Locale locale) {
        return (BigInteger) parse(value, pattern, locale);
    }

    public boolean isInRange(BigInteger value, long min, long max) {
        return value.longValue() >= min && value.longValue() <= max;
    }

    public boolean minValue(BigInteger value, long min) {
        return value.longValue() >= min;
    }

    public boolean maxValue(BigInteger value, long max) {
        return value.longValue() <= max;
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractNumberValidator, org.apache.commons.validator.routines.AbstractFormatValidator
    public Object processParsedValue(Object value, Format formatter) {
        return BigInteger.valueOf(((Number) value).longValue());
    }
}
