package org.apache.commons.validator.routines;

import java.math.BigInteger;
import java.util.Locale;

public class BigIntegerValidatorTest extends AbstractNumberValidatorTest {
    public BigIntegerValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractNumberValidatorTest
    public void setUp() throws Exception {
        super.setUp();
        this.validator = new BigIntegerValidator(false, 0);
        this.strictValidator = new BigIntegerValidator();
        this.testPattern = "#,###";
        this.max = null;
        this.maxPlusOne = null;
        this.min = null;
        this.minMinusOne = null;
        this.invalidStrict = new String[]{null, "", "X", "X12", "12X", "1X2", "1.2"};
        this.invalid = new String[]{null, "", "X", "X12"};
        this.testNumber = new BigInteger("1234");
        this.testZero = new BigInteger("0");
        this.validStrict = new String[]{"0", "1234", "1,234"};
        this.validStrictCompare = new Number[]{this.testZero, this.testNumber, this.testNumber};
        this.valid = new String[]{"0", "1234", "1,234", "1,234.5", "1234X"};
        this.validCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, this.testNumber, this.testNumber};
        this.testStringUS = "1,234";
        this.testStringDE = "1.234";
        this.localeValue = this.testStringDE;
        this.localePattern = "#.###";
        this.testLocale = Locale.GERMANY;
        this.localeExpected = this.testNumber;
    }

    public void testBigIntegerValidatorMethods() {
        Locale locale = Locale.GERMAN;
        BigInteger expected = new BigInteger("12345");
        assertEquals("validate(A) default", expected, BigIntegerValidator.getInstance().validate("12,345"));
        assertEquals("validate(A) locale ", expected, BigIntegerValidator.getInstance().validate("12.345", locale));
        assertEquals("validate(A) pattern", expected, BigIntegerValidator.getInstance().validate("1,23,45", "0,00,00"));
        assertEquals("validate(A) both", expected, BigIntegerValidator.getInstance().validate("1.23.45", "0,00,00", Locale.GERMAN));
        assertTrue("isValid(A) default", BigIntegerValidator.getInstance().isValid("12,345"));
        assertTrue("isValid(A) locale ", BigIntegerValidator.getInstance().isValid("12.345", locale));
        assertTrue("isValid(A) pattern", BigIntegerValidator.getInstance().isValid("1,23,45", "0,00,00"));
        assertTrue("isValid(A) both", BigIntegerValidator.getInstance().isValid("1.23.45", "0,00,00", Locale.GERMAN));
        assertNull("validate(B) default", BigIntegerValidator.getInstance().validate("XXXX"));
        assertNull("validate(B) locale ", BigIntegerValidator.getInstance().validate("XXXX", locale));
        assertNull("validate(B) pattern", BigIntegerValidator.getInstance().validate("XXXX", "0,00,00"));
        assertNull("validate(B) both", BigIntegerValidator.getInstance().validate("1,23,45", "0,00,00", Locale.GERMAN));
        assertFalse("isValid(B) default", BigIntegerValidator.getInstance().isValid("XXXX"));
        assertFalse("isValid(B) locale ", BigIntegerValidator.getInstance().isValid("XXXX", locale));
        assertFalse("isValid(B) pattern", BigIntegerValidator.getInstance().isValid("XXXX", "0,00,00"));
        assertFalse("isValid(B) both", BigIntegerValidator.getInstance().isValid("1,23,45", "0,00,00", Locale.GERMAN));
    }

    public void testBigIntegerRangeMinMax() {
        BigIntegerValidator validator = (BigIntegerValidator) this.strictValidator;
        BigInteger number9 = validator.validate("9", "#");
        BigInteger number10 = validator.validate("10", "#");
        BigInteger number11 = validator.validate("11", "#");
        BigInteger number19 = validator.validate("19", "#");
        BigInteger number20 = validator.validate("20", "#");
        BigInteger number21 = validator.validate("21", "#");
        assertFalse("isInRange() < min", validator.isInRange(number9, 10, 20));
        assertTrue("isInRange() = min", validator.isInRange(number10, 10, 20));
        assertTrue("isInRange() in range", validator.isInRange(number11, 10, 20));
        assertTrue("isInRange() = max", validator.isInRange(number20, 10, 20));
        assertFalse("isInRange() > max", validator.isInRange(number21, 10, 20));
        assertFalse("minValue() < min", validator.minValue(number9, 10));
        assertTrue("minValue() = min", validator.minValue(number10, 10));
        assertTrue("minValue() > min", validator.minValue(number11, 10));
        assertTrue("maxValue() < max", validator.maxValue(number19, 20));
        assertTrue("maxValue() = max", validator.maxValue(number20, 20));
        assertFalse("maxValue() > max", validator.maxValue(number21, 20));
    }
}
