package org.apache.commons.validator.routines;

import java.util.Locale;

public class ByteValidatorTest extends AbstractNumberValidatorTest {
    private static final String BYTE_MAX = "127";
    private static final String BYTE_MAX_0 = "127.99999999999999999999999";
    private static final String BYTE_MAX_1 = "128";
    private static final Byte BYTE_MAX_VAL = Byte.MAX_VALUE;
    private static final String BYTE_MIN = "-128";
    private static final String BYTE_MIN_0 = "-128.99999999999999999999999";
    private static final String BYTE_MIN_1 = "-129";
    private static final Byte BYTE_MIN_VAL = Byte.MIN_VALUE;

    public ByteValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractNumberValidatorTest
    public void setUp() throws Exception {
        super.setUp();
        this.validator = new ByteValidator(false, 0);
        this.strictValidator = new ByteValidator();
        this.testPattern = "#,###";
        this.max = Byte.MAX_VALUE;
        this.maxPlusOne = Long.valueOf(this.max.longValue() + 1);
        this.min = Byte.MIN_VALUE;
        this.minMinusOne = Long.valueOf(this.min.longValue() - 1);
        this.invalidStrict = new String[]{null, "", "X", "X12", "12X", "1X2", "1.2", BYTE_MAX_1, BYTE_MIN_1, BYTE_MAX_0, BYTE_MIN_0};
        this.invalid = new String[]{null, "", "X", "X12", BYTE_MAX_1, BYTE_MIN_1};
        this.testNumber = (byte) 123;
        this.testZero = (byte) 0;
        this.validStrict = new String[]{"0", "123", ",123", BYTE_MAX, BYTE_MIN};
        Byte b = BYTE_MAX_VAL;
        Byte b2 = BYTE_MIN_VAL;
        this.validStrictCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, b, b2};
        this.valid = new String[]{"0", "123", ",123", ",123.5", "123X", BYTE_MAX, BYTE_MIN, BYTE_MAX_0, BYTE_MIN_0};
        this.validCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, this.testNumber, this.testNumber, b, b2, b, b2};
        this.testStringUS = ",123";
        this.testStringDE = ".123";
        this.localeValue = this.testStringDE;
        this.localePattern = "#.###";
        this.testLocale = Locale.GERMANY;
        this.localeExpected = this.testNumber;
    }

    public void testByteValidatorMethods() {
        Locale locale = Locale.GERMAN;
        assertEquals("validate(A) default", (byte) 123, ByteValidator.getInstance().validate(",123"));
        assertEquals("validate(A) locale ", (byte) 123, ByteValidator.getInstance().validate(".123", locale));
        assertEquals("validate(A) pattern", (byte) 123, ByteValidator.getInstance().validate("1,23", "0,00"));
        assertEquals("validate(A) both", (byte) 123, ByteValidator.getInstance().validate("1.23", "0,00", Locale.GERMAN));
        assertTrue("isValid(A) default", ByteValidator.getInstance().isValid(",123"));
        assertTrue("isValid(A) locale ", ByteValidator.getInstance().isValid(".123", locale));
        assertTrue("isValid(A) pattern", ByteValidator.getInstance().isValid("1,23", "0,00"));
        assertTrue("isValid(A) both", ByteValidator.getInstance().isValid("1.23", "0,00", Locale.GERMAN));
        assertNull("validate(B) default", ByteValidator.getInstance().validate("XXXX"));
        assertNull("validate(B) locale ", ByteValidator.getInstance().validate("XXXX", locale));
        assertNull("validate(B) pattern", ByteValidator.getInstance().validate("XXXX", "0,00"));
        assertNull("validate(B) both", ByteValidator.getInstance().validate("1,23", "0,00", Locale.GERMAN));
        assertFalse("isValid(B) default", ByteValidator.getInstance().isValid("XXXX"));
        assertFalse("isValid(B) locale ", ByteValidator.getInstance().isValid("XXXX", locale));
        assertFalse("isValid(B) pattern", ByteValidator.getInstance().isValid("XXXX", "0,00"));
        assertFalse("isValid(B) both", ByteValidator.getInstance().isValid("1,23", "0,00", Locale.GERMAN));
    }

    public void testByteRangeMinMax() {
        ByteValidator validator = (ByteValidator) this.strictValidator;
        Byte number9 = validator.validate("9", "#");
        Byte number10 = validator.validate("10", "#");
        Byte number11 = validator.validate("11", "#");
        Byte number19 = validator.validate("19", "#");
        Byte number20 = validator.validate("20", "#");
        Byte number21 = validator.validate("21", "#");
        assertFalse("isInRange() < min", validator.isInRange(number9, (byte) 10, (byte) 20));
        assertTrue("isInRange() = min", validator.isInRange(number10, (byte) 10, (byte) 20));
        assertTrue("isInRange() in range", validator.isInRange(number11, (byte) 10, (byte) 20));
        assertTrue("isInRange() = max", validator.isInRange(number20, (byte) 10, (byte) 20));
        assertFalse("isInRange() > max", validator.isInRange(number21, (byte) 10, (byte) 20));
        assertFalse("minValue() < min", validator.minValue(number9, (byte) 10));
        assertTrue("minValue() = min", validator.minValue(number10, (byte) 10));
        assertTrue("minValue() > min", validator.minValue(number11, (byte) 10));
        assertTrue("maxValue() < max", validator.maxValue(number19, (byte) 20));
        assertTrue("maxValue() = max", validator.maxValue(number20, (byte) 20));
        assertFalse("maxValue() > max", validator.maxValue(number21, (byte) 20));
    }
}
