package org.apache.commons.validator.routines;

import java.text.Format;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

public class CalendarValidatorTest extends AbstractCalendarValidatorTest {
    private static final int DATE_2005_11_23 = 20051123;
    private static final int TIME_12_03_45 = 120345;
    private CalendarValidator calValidator;

    public CalendarValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractCalendarValidatorTest
    public void setUp() throws Exception {
        super.setUp();
        CalendarValidator calendarValidator = new CalendarValidator();
        this.calValidator = calendarValidator;
        this.validator = calendarValidator;
    }

    public void testCalendarValidatorMethods() {
        Locale.setDefault(Locale.US);
        Locale locale = Locale.GERMAN;
        boolean z = false;
        Date expected = createCalendar(null, 20051231, 0).getTime();
        assertEquals("validate(A) default", expected, CalendarValidator.getInstance().validate("12/31/05").getTime());
        assertEquals("validate(A) locale ", expected, CalendarValidator.getInstance().validate("31.12.2005", locale).getTime());
        assertEquals("validate(A) pattern", expected, CalendarValidator.getInstance().validate("2005-12-31", "yyyy-MM-dd").getTime());
        assertEquals("validate(A) both", expected, CalendarValidator.getInstance().validate("31 Dez 2005", "dd MMM yyyy", Locale.GERMAN).getTime());
        assertTrue("isValid(A) default", CalendarValidator.getInstance().isValid("12/31/05"));
        assertTrue("isValid(A) locale ", CalendarValidator.getInstance().isValid("31.12.2005", locale));
        assertTrue("isValid(A) pattern", CalendarValidator.getInstance().isValid("2005-12-31", "yyyy-MM-dd"));
        assertTrue("isValid(A) both", CalendarValidator.getInstance().isValid("31 Dez 2005", "dd MMM yyyy", Locale.GERMAN));
        assertNull("validate(B) default", CalendarValidator.getInstance().validate("XXXX"));
        assertNull("validate(B) locale ", CalendarValidator.getInstance().validate("XXXX", locale));
        assertNull("validate(B) pattern", CalendarValidator.getInstance().validate("XXXX", "yyyy-MM-dd"));
        assertNull("validate(B) both", CalendarValidator.getInstance().validate("31 Dec 2005", "dd MMM yyyy", Locale.GERMAN));
        assertFalse("isValid(B) default", CalendarValidator.getInstance().isValid("XXXX"));
        assertFalse("isValid(B) locale ", CalendarValidator.getInstance().isValid("XXXX", locale));
        assertFalse("isValid(B) pattern", CalendarValidator.getInstance().isValid("XXXX", "yyyy-MM-dd"));
        assertFalse("isValid(B) both", CalendarValidator.getInstance().isValid("31 Dec 2005", "dd MMM yyyy", Locale.GERMAN));
        TimeZone zone = TimeZone.getDefault().getRawOffset() == EET.getRawOffset() ? EST : EET;
        Date expectedZone = createCalendar(zone, 20051231, 0).getTime();
        if (expected.getTime() == expectedZone.getTime()) {
            z = true;
        }
        assertFalse("default/EET same ", z);
        assertEquals("validate(C) default", expectedZone, CalendarValidator.getInstance().validate("12/31/05", zone).getTime());
        assertEquals("validate(C) locale ", expectedZone, CalendarValidator.getInstance().validate("31.12.2005", locale, zone).getTime());
        assertEquals("validate(C) pattern", expectedZone, CalendarValidator.getInstance().validate("2005-12-31", "yyyy-MM-dd", zone).getTime());
        assertEquals("validate(C) both", expectedZone, CalendarValidator.getInstance().validate("31 Dez 2005", "dd MMM yyyy", Locale.GERMAN, zone).getTime());
    }

    public void testCompare() {
        Calendar diffHour = createCalendar(GMT, 20050823, 115922);
        Calendar diffMin = createCalendar(GMT, 20050823, 124422);
        Calendar diffSec = createCalendar(GMT, 20050823, 124521);
        Calendar value = createCalendar(GMT, 20050823, 124522);
        Calendar cal20050824 = createCalendar(GMT, 20050824, 124522);
        Calendar cal20050822 = createCalendar(GMT, 20050822, 124522);
        Calendar cal20050830 = createCalendar(GMT, 20050830, 124522);
        Calendar cal20050816 = createCalendar(GMT, 20050816, 124522);
        Calendar cal20050901 = createCalendar(GMT, 20050901, 124522);
        Calendar cal20050801 = createCalendar(GMT, 20050801, 124522);
        Calendar cal20050731 = createCalendar(GMT, 20050731, 124522);
        Calendar cal20051101 = createCalendar(GMT, 20051101, 124522);
        Calendar cal20051001 = createCalendar(GMT, 20051001, 124522);
        Calendar cal20050701 = createCalendar(GMT, 20050701, 124522);
        Calendar cal20050630 = createCalendar(GMT, 20050630, 124522);
        Calendar cal20060101 = createCalendar(GMT, 20060101, 124522);
        Calendar cal20050101 = createCalendar(GMT, 20050101, 124522);
        Calendar cal20041231 = createCalendar(GMT, 20041231, 124522);
        assertEquals("hour GT", 1, this.calValidator.compare(value, diffHour, 11));
        assertEquals("hour EQ", 0, this.calValidator.compare(value, diffMin, 11));
        assertEquals("mins GT", 1, this.calValidator.compare(value, diffMin, 12));
        assertEquals("mins EQ", 0, this.calValidator.compare(value, diffSec, 12));
        assertEquals("secs GT", 1, this.calValidator.compare(value, diffSec, 13));
        assertEquals("date LT", -1, this.calValidator.compareDates(value, cal20050824));
        assertEquals("date EQ", 0, this.calValidator.compareDates(value, diffHour));
        assertEquals("date(B)", 0, this.calValidator.compare(value, diffHour, 6));
        assertEquals("date GT", 1, this.calValidator.compareDates(value, cal20050822));
        assertEquals("week LT", -1, this.calValidator.compareWeeks(value, cal20050830));
        assertEquals("week =1", 0, this.calValidator.compareWeeks(value, cal20050824));
        assertEquals("week =2", 0, this.calValidator.compareWeeks(value, cal20050822));
        assertEquals("week =3", 0, this.calValidator.compare(value, cal20050822, 4));
        assertEquals("week =4", 0, this.calValidator.compareWeeks(value, cal20050822));
        assertEquals("week GT", 1, this.calValidator.compareWeeks(value, cal20050816));
        assertEquals("mnth LT", -1, this.calValidator.compareMonths(value, cal20050901));
        assertEquals("mnth =1", 0, this.calValidator.compareMonths(value, cal20050830));
        assertEquals("mnth =2", 0, this.calValidator.compareMonths(value, cal20050801));
        assertEquals("mnth =3", 0, this.calValidator.compareMonths(value, cal20050816));
        assertEquals("mnth GT", 1, this.calValidator.compareMonths(value, cal20050731));
        assertEquals("qtrA <1", -1, this.calValidator.compareQuarters(value, cal20051101));
        assertEquals("qtrA <2", -1, this.calValidator.compareQuarters(value, cal20051001));
        assertEquals("qtrA =1", 0, this.calValidator.compareQuarters(value, cal20050901));
        assertEquals("qtrA =2", 0, this.calValidator.compareQuarters(value, cal20050701));
        assertEquals("qtrA =3", 0, this.calValidator.compareQuarters(value, cal20050731));
        assertEquals("qtrA GT", 1, this.calValidator.compareQuarters(value, cal20050630));
        assertEquals("qtrB LT", -1, this.calValidator.compareQuarters(value, cal20051101, 2));
        assertEquals("qtrB =1", 0, this.calValidator.compareQuarters(value, cal20051001, 2));
        assertEquals("qtrB =2", 0, this.calValidator.compareQuarters(value, cal20050901, 2));
        assertEquals("qtrB =3", 1, this.calValidator.compareQuarters(value, cal20050701, 2));
        assertEquals("qtrB =4", 1, this.calValidator.compareQuarters(value, cal20050731, 2));
        assertEquals("qtrB GT", 1, this.calValidator.compareQuarters(value, cal20050630, 2));
        assertEquals("year LT", -1, this.calValidator.compareYears(value, cal20060101));
        assertEquals("year EQ", 0, this.calValidator.compareYears(value, cal20050101));
        assertEquals("year GT", 1, this.calValidator.compareYears(value, cal20041231));
        try {
            this.calValidator.compare(value, value, -1);
            fail("Invalid Compare field - expected IllegalArgumentException to be thrown");
        } catch (IllegalArgumentException e) {
            assertEquals("check message", "Invalid field: -1", e.getMessage());
        }
    }

    public void testDateTimeStyle() {
        Locale origDefault = Locale.getDefault();
        Locale.setDefault(Locale.UK);
        AbstractCalendarValidator dateTimeValidator = new AbstractCalendarValidator(true, 3, 3) {
            /* class org.apache.commons.validator.routines.CalendarValidatorTest.AnonymousClass1 */
            private static final long serialVersionUID = 1;

            /* access modifiers changed from: protected */
            @Override // org.apache.commons.validator.routines.AbstractCalendarValidator, org.apache.commons.validator.routines.AbstractFormatValidator
            public Object processParsedValue(Object value, Format formatter) {
                return value;
            }
        };
        assertTrue("validate(A) default", dateTimeValidator.isValid("31/12/05 14:23"));
        assertTrue("validate(A) locale ", dateTimeValidator.isValid("12/31/05 2:23 PM", Locale.US));
        Locale.setDefault(origDefault);
    }

    @Override // org.apache.commons.validator.routines.AbstractCalendarValidatorTest
    public void testFormat() {
        Locale origDefault = Locale.getDefault();
        Locale.setDefault(Locale.UK);
        Calendar cal20050101 = createCalendar(GMT, 20051231, 11500);
        assertNull("null", this.calValidator.format(null));
        assertEquals("default", "31/12/05", this.calValidator.format(cal20050101));
        assertEquals("locale", "12/31/05", this.calValidator.format(cal20050101, Locale.US));
        assertEquals("patternA", "2005-12-31 01:15", this.calValidator.format(cal20050101, "yyyy-MM-dd HH:mm"));
        assertEquals("patternB", "2005-12-31 GMT", this.calValidator.format(cal20050101, "yyyy-MM-dd z"));
        assertEquals("both", "31 Dez 2005", this.calValidator.format(cal20050101, "dd MMM yyyy", Locale.GERMAN));
        assertEquals("EST default", "30/12/05", this.calValidator.format(cal20050101, EST));
        assertEquals("EST locale", "12/30/05", this.calValidator.format(cal20050101, Locale.US, EST));
        assertEquals("EST patternA", "2005-12-30 20:15", this.calValidator.format(cal20050101, "yyyy-MM-dd HH:mm", EST));
        assertEquals("EST patternB", "2005-12-30 EST", this.calValidator.format(cal20050101, "yyyy-MM-dd z", EST));
        assertEquals("EST both", "30 Dez 2005", this.calValidator.format(cal20050101, "dd MMM yyyy", Locale.GERMAN, EST));
        Locale.setDefault(origDefault);
    }

    public void testAdjustToTimeZone() {
        Calendar calEST = createCalendar(EST, DATE_2005_11_23, TIME_12_03_45);
        Date dateEST = calEST.getTime();
        Calendar calGMT = createCalendar(GMT, DATE_2005_11_23, TIME_12_03_45);
        Date dateGMT = calGMT.getTime();
        Calendar calCET = createCalendar(EET, DATE_2005_11_23, TIME_12_03_45);
        Date dateCET = calCET.getTime();
        boolean z = true;
        assertFalse("Check GMT != CET", dateGMT.getTime() == dateCET.getTime());
        assertFalse("Check GMT != EST", dateGMT.getTime() == dateEST.getTime());
        assertFalse("Check CET != EST", dateCET.getTime() == dateEST.getTime());
        CalendarValidator.adjustToTimeZone(calEST, GMT);
        assertEquals("EST to GMT", dateGMT, calEST.getTime());
        assertFalse("Check EST = GMT", dateEST == calEST.getTime());
        CalendarValidator.adjustToTimeZone(calEST, EST);
        assertEquals("back to EST", dateEST, calEST.getTime());
        assertFalse("Check EST != GMT", dateGMT == calEST.getTime());
        CalendarValidator.adjustToTimeZone(calCET, GMT);
        assertEquals("CET to GMT", dateGMT, calCET.getTime());
        assertFalse("Check CET = GMT", dateCET == calCET.getTime());
        CalendarValidator.adjustToTimeZone(calCET, EET);
        assertEquals("back to CET", dateCET, calCET.getTime());
        if (dateGMT != calCET.getTime()) {
            z = false;
        }
        assertFalse("Check CET != GMT", z);
        Calendar calUTC = createCalendar(UTC, DATE_2005_11_23, TIME_12_03_45);
        assertTrue("SAME: UTC = GMT", UTC.hasSameRules(GMT));
        assertEquals("SAME: Check time (A)", calUTC.getTime(), calGMT.getTime());
        assertFalse("SAME: Check GMT(A)", GMT.equals(calUTC.getTimeZone()));
        assertTrue("SAME: Check UTC(A)", UTC.equals(calUTC.getTimeZone()));
        CalendarValidator.adjustToTimeZone(calUTC, GMT);
        assertEquals("SAME: Check time (B)", calUTC.getTime(), calGMT.getTime());
        assertTrue("SAME: Check GMT(B)", GMT.equals(calUTC.getTimeZone()));
        assertFalse("SAME: Check UTC(B)", UTC.equals(calUTC.getTimeZone()));
    }
}
