package org.apache.commons.validator.routines;

import junit.framework.TestCase;
import org.apache.commons.validator.routines.checkdigit.CheckDigit;
import org.apache.commons.validator.routines.checkdigit.EAN13CheckDigit;

public class CodeValidatorTest extends TestCase {
    public CodeValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws Exception {
        CodeValidatorTest.super.setUp();
    }

    /* access modifiers changed from: protected */
    public void tearDown() throws Exception {
        CodeValidatorTest.super.tearDown();
    }

    public void testCheckDigit() {
        String str = null;
        CodeValidator validator = new CodeValidator(str, -1, -1, (CheckDigit) null);
        assertNull("No CheckDigit", validator.getCheckDigit());
        assertEquals("No CheckDigit invalid", "9781930110992", validator.validate("9781930110992"));
        assertEquals("No CheckDigit valid", "9781930110991", validator.validate("9781930110991"));
        assertEquals("No CheckDigit (is) invalid", true, validator.isValid("9781930110992"));
        assertEquals("No CheckDigit (is) valid", true, validator.isValid("9781930110991"));
        CodeValidator validator2 = new CodeValidator(str, -1, EAN13CheckDigit.EAN13_CHECK_DIGIT);
        assertNotNull("EAN CheckDigit", validator2.getCheckDigit());
        assertEquals("EAN CheckDigit invalid", null, validator2.validate("9781930110992"));
        assertEquals("EAN CheckDigit valid", "9781930110991", validator2.validate("9781930110991"));
        assertEquals("EAN CheckDigit (is) invalid", false, validator2.isValid("9781930110992"));
        assertEquals("EAN CheckDigit (is) valid", true, validator2.isValid("9781930110991"));
        assertEquals("EAN CheckDigit ex", null, validator2.validate("978193011099X"));
    }

    public void testLength() {
        String str = null;
        CheckDigit checkDigit = null;
        CodeValidator validator = new CodeValidator(str, -1, -1, checkDigit);
        assertEquals("No min", -1, validator.getMinLength());
        assertEquals("No max", -1, validator.getMaxLength());
        assertEquals("No Length 10", "1234567890", validator.validate("1234567890"));
        assertEquals("No Length 11", "12345678901", validator.validate("12345678901"));
        assertEquals("No Length 12", "123456789012", validator.validate("123456789012"));
        assertEquals("No Length 20", "12345678901234567890", validator.validate("12345678901234567890"));
        assertEquals("No Length 21", "123456789012345678901", validator.validate("123456789012345678901"));
        assertEquals("No Length 22", "1234567890123456789012", validator.validate("1234567890123456789012"));
        CodeValidator validator2 = new CodeValidator(str, 11, -1, checkDigit);
        assertEquals("Min 11 - min", 11, validator2.getMinLength());
        assertEquals("Min 11 - max", -1, validator2.getMaxLength());
        assertEquals("Min 11 - 10", null, validator2.validate("1234567890"));
        assertEquals("Min 11 - 11", "12345678901", validator2.validate("12345678901"));
        assertEquals("Min 11 - 12", "123456789012", validator2.validate("123456789012"));
        assertEquals("Min 11 - 20", "12345678901234567890", validator2.validate("12345678901234567890"));
        assertEquals("Min 11 - 21", "123456789012345678901", validator2.validate("123456789012345678901"));
        assertEquals("Min 11 - 22", "1234567890123456789012", validator2.validate("1234567890123456789012"));
        CodeValidator validator3 = new CodeValidator(str, -1, 21, checkDigit);
        assertEquals("Max 21 - min", -1, validator3.getMinLength());
        assertEquals("Max 21 - max", 21, validator3.getMaxLength());
        assertEquals("Max 21 - 10", "1234567890", validator3.validate("1234567890"));
        assertEquals("Max 21 - 11", "12345678901", validator3.validate("12345678901"));
        assertEquals("Max 21 - 12", "123456789012", validator3.validate("123456789012"));
        assertEquals("Max 21 - 20", "12345678901234567890", validator3.validate("12345678901234567890"));
        assertEquals("Max 21 - 21", "123456789012345678901", validator3.validate("123456789012345678901"));
        assertEquals("Max 21 - 22", null, validator3.validate("1234567890123456789012"));
        CodeValidator validator4 = new CodeValidator(str, 11, 21, checkDigit);
        assertEquals("Min 11 / Max 21 - min", 11, validator4.getMinLength());
        assertEquals("Min 11 / Max 21 - max", 21, validator4.getMaxLength());
        assertEquals("Min 11 / Max 21 - 10", null, validator4.validate("1234567890"));
        assertEquals("Min 11 / Max 21 - 11", "12345678901", validator4.validate("12345678901"));
        assertEquals("Min 11 / Max 21 - 12", "123456789012", validator4.validate("123456789012"));
        assertEquals("Min 11 / Max 21 - 20", "12345678901234567890", validator4.validate("12345678901234567890"));
        assertEquals("Min 11 / Max 21 - 21", "123456789012345678901", validator4.validate("123456789012345678901"));
        assertEquals("Min 11 / Max 21 - 22", null, validator4.validate("1234567890123456789012"));
        CodeValidator validator5 = new CodeValidator(str, 11, 11, checkDigit);
        assertEquals("Exact 11 - min", 11, validator5.getMinLength());
        assertEquals("Exact 11 - max", 11, validator5.getMaxLength());
        assertEquals("Exact 11 - 10", null, validator5.validate("1234567890"));
        assertEquals("Exact 11 - 11", "12345678901", validator5.validate("12345678901"));
        assertEquals("Exact 11 - 12", null, validator5.validate("123456789012"));
    }

    public void testRegex() {
        CheckDigit checkDigit = null;
        CodeValidator validator = new CodeValidator((String) null, -1, -1, checkDigit);
        assertNull("No Regex", validator.getRegexValidator());
        assertEquals("No Regex 2", "12", validator.validate("12"));
        assertEquals("No Regex 3", "123", validator.validate("123"));
        assertEquals("No Regex 4", "1234", validator.validate("1234"));
        assertEquals("No Regex 5", "12345", validator.validate("12345"));
        assertEquals("No Regex invalid", "12a4", validator.validate("12a4"));
        CodeValidator validator2 = new CodeValidator("^([0-9]{3,4})$", -1, -1, checkDigit);
        assertNotNull("No Regex", validator2.getRegexValidator());
        assertEquals("Regex 2", null, validator2.validate("12"));
        assertEquals("Regex 3", "123", validator2.validate("123"));
        assertEquals("Regex 4", "1234", validator2.validate("1234"));
        assertEquals("Regex 5", null, validator2.validate("12345"));
        assertEquals("Regex invalid", null, validator2.validate("12a4"));
        CodeValidator validator3 = new CodeValidator(new RegexValidator("^([0-9]{3})(?:[-\\s])([0-9]{3})$"), 6, checkDigit);
        assertEquals("Reformat 123-456", "123456", validator3.validate("123-456"));
        assertEquals("Reformat 123 456", "123456", validator3.validate("123 456"));
        assertEquals("Reformat 123456", null, validator3.validate("123456"));
        assertEquals("Reformat 123.456", null, validator3.validate("123.456"));
        CodeValidator validator4 = new CodeValidator(new RegexValidator("^(?:([0-9]{3})(?:[-\\s])([0-9]{3}))|([0-9]{6})$"), 6, checkDigit);
        assertEquals("Reformat 2 Regex", "RegexValidator{" + "^(?:([0-9]{3})(?:[-\\s])([0-9]{3}))|([0-9]{6})$" + "}", validator4.getRegexValidator().toString());
        assertEquals("Reformat 2 123-456", "123456", validator4.validate("123-456"));
        assertEquals("Reformat 2 123 456", "123456", validator4.validate("123 456"));
        assertEquals("Reformat 2 123456", "123456", validator4.validate("123456"));
    }

    public void testNoInput() {
        CodeValidator validator = new CodeValidator((String) null, -1, -1, (CheckDigit) null);
        assertEquals("Null", null, validator.validate(null));
        assertEquals("Zero Length", null, validator.validate(""));
        assertEquals("Spaces", null, validator.validate("   "));
        assertEquals("Trimmed", "A", validator.validate(" A  "));
    }

    public void testValidator294_1() {
        String str = null;
        CheckDigit checkDigit = null;
        assertEquals("Null", null, new CodeValidator(str, 0, -1, checkDigit).validate(null));
        assertEquals("Null", null, new CodeValidator(str, -1, 0, checkDigit).validate(null));
    }

    public void testValidator294_2() {
        assertEquals("Null", null, new CodeValidator((String) null, -1, 0, (CheckDigit) null).validate(null));
    }

    public void testConstructors() {
        RegexValidator regex = new RegexValidator("^[0-9]*$");
        CodeValidator validator = new CodeValidator(regex, EAN13CheckDigit.EAN13_CHECK_DIGIT);
        assertEquals("Constructor 1 - regex", regex, validator.getRegexValidator());
        assertEquals("Constructor 1 - min length", -1, validator.getMinLength());
        assertEquals("Constructor 1 - max length", -1, validator.getMaxLength());
        assertEquals("Constructor 1 - check digit", EAN13CheckDigit.EAN13_CHECK_DIGIT, validator.getCheckDigit());
        CodeValidator validator2 = new CodeValidator(regex, 13, EAN13CheckDigit.EAN13_CHECK_DIGIT);
        assertEquals("Constructor 2 - regex", regex, validator2.getRegexValidator());
        assertEquals("Constructor 2 - min length", 13, validator2.getMinLength());
        assertEquals("Constructor 2 - max length", 13, validator2.getMaxLength());
        assertEquals("Constructor 2 - check digit", EAN13CheckDigit.EAN13_CHECK_DIGIT, validator2.getCheckDigit());
        CodeValidator validator3 = new CodeValidator(regex, 10, 20, EAN13CheckDigit.EAN13_CHECK_DIGIT);
        assertEquals("Constructor 3 - regex", regex, validator3.getRegexValidator());
        assertEquals("Constructor 3 - min length", 10, validator3.getMinLength());
        assertEquals("Constructor 3 - max length", 20, validator3.getMaxLength());
        assertEquals("Constructor 3 - check digit", EAN13CheckDigit.EAN13_CHECK_DIGIT, validator3.getCheckDigit());
        CodeValidator validator4 = new CodeValidator("^[0-9]*$", EAN13CheckDigit.EAN13_CHECK_DIGIT);
        assertEquals("Constructor 4 - regex", "RegexValidator{^[0-9]*$}", validator4.getRegexValidator().toString());
        assertEquals("Constructor 4 - min length", -1, validator4.getMinLength());
        assertEquals("Constructor 4 - max length", -1, validator4.getMaxLength());
        assertEquals("Constructor 4 - check digit", EAN13CheckDigit.EAN13_CHECK_DIGIT, validator4.getCheckDigit());
        CodeValidator validator5 = new CodeValidator("^[0-9]*$", 13, EAN13CheckDigit.EAN13_CHECK_DIGIT);
        assertEquals("Constructor 5 - regex", "RegexValidator{^[0-9]*$}", validator5.getRegexValidator().toString());
        assertEquals("Constructor 5 - min length", 13, validator5.getMinLength());
        assertEquals("Constructor 5 - max length", 13, validator5.getMaxLength());
        assertEquals("Constructor 5 - check digit", EAN13CheckDigit.EAN13_CHECK_DIGIT, validator5.getCheckDigit());
        CodeValidator validator6 = new CodeValidator("^[0-9]*$", 10, 20, EAN13CheckDigit.EAN13_CHECK_DIGIT);
        assertEquals("Constructor 6 - regex", "RegexValidator{^[0-9]*$}", validator6.getRegexValidator().toString());
        assertEquals("Constructor 6 - min length", 10, validator6.getMinLength());
        assertEquals("Constructor 6 - max length", 20, validator6.getMaxLength());
        assertEquals("Constructor 6 - check digit", EAN13CheckDigit.EAN13_CHECK_DIGIT, validator6.getCheckDigit());
    }
}
