package org.apache.commons.validator.routines;

import java.text.DecimalFormat;
import java.text.Format;

public class CurrencyValidator extends BigDecimalValidator {
    private static final char CURRENCY_SYMBOL = 164;
    private static final CurrencyValidator VALIDATOR = new CurrencyValidator();
    private static final long serialVersionUID = -4201640771171486514L;

    public static BigDecimalValidator getInstance() {
        return VALIDATOR;
    }

    public CurrencyValidator() {
        this(true, true);
    }

    public CurrencyValidator(boolean strict, boolean allowFractions) {
        super(strict, 1, allowFractions);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractFormatValidator
    public Object parse(String value, Format formatter) {
        Object parsedValue = super.parse(value, formatter);
        if (parsedValue != null || !(formatter instanceof DecimalFormat)) {
            return parsedValue;
        }
        DecimalFormat decimalFormat = (DecimalFormat) formatter;
        String pattern = decimalFormat.toPattern();
        if (pattern.indexOf(164) < 0) {
            return parsedValue;
        }
        StringBuilder buffer = new StringBuilder(pattern.length());
        for (int i = 0; i < pattern.length(); i++) {
            if (pattern.charAt(i) != 164) {
                buffer.append(pattern.charAt(i));
            }
        }
        decimalFormat.applyPattern(buffer.toString());
        return super.parse(value, decimalFormat);
    }
}
