package org.apache.commons.validator.routines;

import java.text.Format;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

public class DateValidator extends AbstractCalendarValidator {
    private static final DateValidator VALIDATOR = new DateValidator();
    private static final long serialVersionUID = -3966328400469953190L;

    public static DateValidator getInstance() {
        return VALIDATOR;
    }

    public DateValidator() {
        this(true, 3);
    }

    public DateValidator(boolean strict, int dateStyle) {
        super(strict, dateStyle, -1);
    }

    public Date validate(String value) {
        return (Date) parse(value, null, null, null);
    }

    public Date validate(String value, TimeZone timeZone) {
        return (Date) parse(value, null, null, timeZone);
    }

    public Date validate(String value, String pattern) {
        return (Date) parse(value, pattern, null, null);
    }

    public Date validate(String value, String pattern, TimeZone timeZone) {
        return (Date) parse(value, pattern, null, timeZone);
    }

    public Date validate(String value, Locale locale) {
        return (Date) parse(value, null, locale, null);
    }

    public Date validate(String value, Locale locale, TimeZone timeZone) {
        return (Date) parse(value, null, locale, timeZone);
    }

    public Date validate(String value, String pattern, Locale locale) {
        return (Date) parse(value, pattern, locale, null);
    }

    public Date validate(String value, String pattern, Locale locale, TimeZone timeZone) {
        return (Date) parse(value, pattern, locale, timeZone);
    }

    public int compareDates(Date value, Date compare, TimeZone timeZone) {
        return compare(getCalendar(value, timeZone), getCalendar(compare, timeZone), 5);
    }

    public int compareWeeks(Date value, Date compare, TimeZone timeZone) {
        return compare(getCalendar(value, timeZone), getCalendar(compare, timeZone), 3);
    }

    public int compareMonths(Date value, Date compare, TimeZone timeZone) {
        return compare(getCalendar(value, timeZone), getCalendar(compare, timeZone), 2);
    }

    public int compareQuarters(Date value, Date compare, TimeZone timeZone) {
        return compareQuarters(value, compare, timeZone, 1);
    }

    public int compareQuarters(Date value, Date compare, TimeZone timeZone, int monthOfFirstQuarter) {
        return super.compareQuarters(getCalendar(value, timeZone), getCalendar(compare, timeZone), monthOfFirstQuarter);
    }

    public int compareYears(Date value, Date compare, TimeZone timeZone) {
        return compare(getCalendar(value, timeZone), getCalendar(compare, timeZone), 1);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractCalendarValidator, org.apache.commons.validator.routines.AbstractFormatValidator
    public Object processParsedValue(Object value, Format formatter) {
        return value;
    }

    private Calendar getCalendar(Date value, TimeZone timeZone) {
        Calendar calendar;
        if (timeZone != null) {
            calendar = Calendar.getInstance(timeZone);
        } else {
            calendar = Calendar.getInstance();
        }
        calendar.setTime(value);
        return calendar;
    }
}
