package org.apache.commons.validator.routines;

import java.util.ArrayList;
import java.util.List;
import org.apache.commons.validator.routines.DomainValidator;
import org.bitstrings.test.junit.runner.ClassLoaderPerTestRunner;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;

@RunWith(ClassLoaderPerTestRunner.class)
public class DomainValidatorStartupTest {
    @Test(expected = IllegalArgumentException.class)
    public void testUpdateBaseArrayCC() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.COUNTRY_CODE_RO, new String[]{"com"});
    }

    @Test(expected = IllegalArgumentException.class)
    public void testUpdateBaseArrayGeneric() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_RO, new String[]{"com"});
    }

    @Test(expected = IllegalArgumentException.class)
    public void testUpdateBaseArrayInfra() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.INFRASTRUCTURE_RO, new String[]{"com"});
    }

    @Test(expected = IllegalArgumentException.class)
    public void testUpdateBaseArrayLocal() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.LOCAL_RO, new String[]{"com"});
    }

    @Test
    public void testUpdateCountryCode1a() {
        Assert.assertFalse(DomainValidator.getInstance().isValidCountryCodeTld("com"));
    }

    @Test
    public void testUpdateCountryCode1b() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.COUNTRY_CODE_PLUS, new String[]{"com"});
        Assert.assertTrue(DomainValidator.getInstance().isValidCountryCodeTld("com"));
    }

    @Test
    public void testUpdateCountryCode2() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.COUNTRY_CODE_PLUS, new String[]{"com"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.COUNTRY_CODE_MINUS, new String[]{"com"});
        Assert.assertFalse(DomainValidator.getInstance().isValidCountryCodeTld("com"));
    }

    @Test
    public void testUpdateCountryCode3a() {
        Assert.assertTrue(DomainValidator.getInstance().isValidCountryCodeTld("ch"));
    }

    @Test
    public void testUpdateCountryCode3b() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.COUNTRY_CODE_MINUS, new String[]{"ch"});
        Assert.assertFalse(DomainValidator.getInstance().isValidCountryCodeTld("ch"));
    }

    @Test
    public void testUpdateCountryCode3c() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.COUNTRY_CODE_MINUS, new String[]{"ch"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.COUNTRY_CODE_MINUS, new String[]{"xx"});
        Assert.assertTrue(DomainValidator.getInstance().isValidCountryCodeTld("ch"));
    }

    @Test
    public void testUpdateGeneric1() {
        Assert.assertFalse(DomainValidator.getInstance().isValidGenericTld("ch"));
    }

    @Test
    public void testUpdateGeneric2() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_PLUS, new String[]{"ch"});
        Assert.assertTrue(DomainValidator.getInstance().isValidGenericTld("ch"));
    }

    @Test
    public void testUpdateGeneric3() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_PLUS, new String[]{"ch"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_MINUS, new String[]{"ch"});
        DomainValidator validator = DomainValidator.getInstance();
        Assert.assertFalse(validator.isValidGenericTld("ch"));
        Assert.assertTrue(validator.isValidGenericTld("com"));
    }

    @Test
    public void testUpdateGeneric4() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_PLUS, new String[]{"ch"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_MINUS, new String[]{"ch"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_MINUS, new String[]{"com"});
        Assert.assertFalse(DomainValidator.getInstance().isValidGenericTld("com"));
    }

    @Test
    public void testUpdateGeneric5() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_PLUS, new String[]{"ch"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_MINUS, new String[]{"ch"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_MINUS, new String[]{"com"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_MINUS, new String[]{"xx"});
        Assert.assertTrue(DomainValidator.getInstance().isValidGenericTld("com"));
    }

    @Test
    public void testVALIDATOR_412a() {
        DomainValidator validator = DomainValidator.getInstance();
        Assert.assertFalse(validator.isValidGenericTld("local"));
        Assert.assertFalse(validator.isValid("abc.local"));
        Assert.assertFalse(validator.isValidGenericTld("pvt"));
        Assert.assertFalse(validator.isValid("abc.pvt"));
    }

    @Test
    public void testVALIDATOR_412b() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_PLUS, new String[]{"local", "pvt"});
        DomainValidator validator = DomainValidator.getInstance();
        Assert.assertTrue(validator.isValidGenericTld("local"));
        Assert.assertTrue(validator.isValid("abc.local"));
        Assert.assertTrue(validator.isValidGenericTld("pvt"));
        Assert.assertTrue(validator.isValid("abc.pvt"));
    }

    @Test
    public void testVALIDATOR_412c() {
        DomainValidator validator = DomainValidator.getInstance(true);
        Assert.assertFalse(validator.isValidLocalTld("local"));
        Assert.assertFalse(validator.isValid("abc.local"));
        Assert.assertFalse(validator.isValidLocalTld("pvt"));
        Assert.assertFalse(validator.isValid("abc.pvt"));
    }

    @Test
    public void testVALIDATOR_412d() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.LOCAL_PLUS, new String[]{"local", "pvt"});
        DomainValidator validator = DomainValidator.getInstance(true);
        Assert.assertTrue(validator.isValidLocalTld("local"));
        Assert.assertTrue(validator.isValidLocalTld("pvt"));
        Assert.assertTrue(validator.isValid("abc.local"));
        Assert.assertTrue(validator.isValid("abc.pvt"));
    }

    @Test
    public void testCannotUpdate() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_PLUS, new String[]{"ch"});
        Assert.assertNotNull(DomainValidator.getInstance());
        try {
            DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_PLUS, new String[]{"ch"});
            Assert.fail("Expected IllegalStateException");
        } catch (IllegalStateException e) {
        }
    }

    @Test
    public void testInstanceOverride() {
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_PLUS, new String[]{"gp"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.GENERIC_MINUS, new String[]{"com"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.COUNTRY_CODE_PLUS, new String[]{"cp"});
        DomainValidator.updateTLDOverride(DomainValidator.ArrayType.COUNTRY_CODE_MINUS, new String[]{"ch"});
        DomainValidator validator = DomainValidator.getInstance(false);
        Assert.assertTrue(validator.isValidGenericTld("gp"));
        Assert.assertFalse(validator.isValidGenericTld("com"));
        Assert.assertTrue(validator.isValidCountryCodeTld("cp"));
        Assert.assertFalse(validator.isValidCountryCodeTld("ch"));
        List<DomainValidator.Item> items = new ArrayList<>();
        items.add(new DomainValidator.Item(DomainValidator.ArrayType.GENERIC_MINUS, new String[]{""}));
        items.add(new DomainValidator.Item(DomainValidator.ArrayType.COUNTRY_CODE_MINUS, new String[]{""}));
        DomainValidator validator2 = DomainValidator.getInstance(false, items);
        Assert.assertTrue(validator2.isValidGenericTld("gp"));
        Assert.assertTrue(validator2.isValidGenericTld("com"));
        Assert.assertTrue(validator2.isValidCountryCodeTld("cp"));
        Assert.assertTrue(validator2.isValidCountryCodeTld("ch"));
        DomainValidator validator3 = DomainValidator.getInstance(false);
        Assert.assertTrue(validator3.isValidGenericTld("gp"));
        Assert.assertFalse(validator3.isValidGenericTld("com"));
        Assert.assertTrue(validator3.isValidCountryCodeTld("cp"));
        Assert.assertFalse(validator3.isValidCountryCodeTld("ch"));
    }
}
