package org.apache.commons.validator.routines;

import java.util.Locale;

public class DoubleValidatorTest extends AbstractNumberValidatorTest {
    public DoubleValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractNumberValidatorTest
    public void setUp() throws Exception {
        super.setUp();
        this.validator = new DoubleValidator(false, 0);
        this.strictValidator = new DoubleValidator();
        this.testPattern = "#,###.#";
        this.max = null;
        this.maxPlusOne = null;
        this.min = null;
        this.minMinusOne = null;
        this.invalidStrict = new String[]{null, "", "X", "X12", "12X", "1X2"};
        this.invalid = new String[]{null, "", "X", "X12"};
        this.testNumber = Double.valueOf(1234.5d);
        this.testZero = Double.valueOf(0.0d);
        this.validStrict = new String[]{"0", "1234.5", "1,234.5"};
        this.validStrictCompare = new Number[]{this.testZero, this.testNumber, this.testNumber};
        this.valid = new String[]{"0", "1234.5", "1,234.5", "1,234.5", "1234.5X"};
        this.validCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, this.testNumber, this.testNumber};
        this.testStringUS = "1,234.5";
        this.testStringDE = "1.234,5";
        this.localeValue = this.testStringDE;
        this.localePattern = "#.###,#";
        this.testLocale = Locale.GERMANY;
        this.localeExpected = this.testNumber;
    }

    public void testDoubleValidatorMethods() {
        Locale locale = Locale.GERMAN;
        Double expected = Double.valueOf(12345.0d);
        assertEquals("validate(A) default", expected, DoubleValidator.getInstance().validate("12,345"));
        assertEquals("validate(A) locale ", expected, DoubleValidator.getInstance().validate("12.345", locale));
        assertEquals("validate(A) pattern", expected, DoubleValidator.getInstance().validate("1,23,45", "0,00,00"));
        assertEquals("validate(A) both", expected, DoubleValidator.getInstance().validate("1.23.45", "0,00,00", Locale.GERMAN));
        assertTrue("isValid(A) default", DoubleValidator.getInstance().isValid("12,345"));
        assertTrue("isValid(A) locale ", DoubleValidator.getInstance().isValid("12.345", locale));
        assertTrue("isValid(A) pattern", DoubleValidator.getInstance().isValid("1,23,45", "0,00,00"));
        assertTrue("isValid(A) both", DoubleValidator.getInstance().isValid("1.23.45", "0,00,00", Locale.GERMAN));
        assertNull("validate(B) default", DoubleValidator.getInstance().validate("XXXX"));
        assertNull("validate(B) locale ", DoubleValidator.getInstance().validate("XXXX", locale));
        assertNull("validate(B) pattern", DoubleValidator.getInstance().validate("XXXX", "0,00,00"));
        assertNull("validate(B) both", DoubleValidator.getInstance().validate("1,23,45", "0,00,00", Locale.GERMAN));
        assertFalse("isValid(B) default", DoubleValidator.getInstance().isValid("XXXX"));
        assertFalse("isValid(B) locale ", DoubleValidator.getInstance().isValid("XXXX", locale));
        assertFalse("isValid(B) pattern", DoubleValidator.getInstance().isValid("XXXX", "0,00,00"));
        assertFalse("isValid(B) both", DoubleValidator.getInstance().isValid("1,23,45", "0,00,00", Locale.GERMAN));
    }

    public void testDoubleRangeMinMax() {
        DoubleValidator validator = (DoubleValidator) this.strictValidator;
        Double number9 = validator.validate("9", "#");
        Double number10 = validator.validate("10", "#");
        Double number11 = validator.validate("11", "#");
        Double number19 = validator.validate("19", "#");
        Double number20 = validator.validate("20", "#");
        Double number21 = validator.validate("21", "#");
        assertFalse("isInRange() < min", validator.isInRange(number9, 10.0d, 20.0d));
        assertTrue("isInRange() = min", validator.isInRange(number10, 10.0d, 20.0d));
        assertTrue("isInRange() in range", validator.isInRange(number11, 10.0d, 20.0d));
        assertTrue("isInRange() = max", validator.isInRange(number20, 10.0d, 20.0d));
        assertFalse("isInRange() > max", validator.isInRange(number21, 10.0d, 20.0d));
        assertFalse("minValue() < min", validator.minValue(number9, 10.0d));
        assertTrue("minValue() = min", validator.minValue(number10, 10.0d));
        assertTrue("minValue() > min", validator.minValue(number11, 10.0d));
        assertTrue("maxValue() < max", validator.maxValue(number19, 20.0d));
        assertTrue("maxValue() = max", validator.maxValue(number20, 20.0d));
        assertFalse("maxValue() > max", validator.maxValue(number21, 20.0d));
    }
}
