package org.apache.commons.validator.routines;

import java.io.Serializable;
import java.util.Arrays;
import java.util.Locale;
import org.apache.commons.validator.routines.checkdigit.ISINCheckDigit;

public class ISINValidator implements Serializable {
    private static final String[] CCODES;
    private static final String ISIN_REGEX = "([A-Z]{2}[A-Z0-9]{9}[0-9])";
    private static final ISINValidator ISIN_VALIDATOR_FALSE = new ISINValidator(false);
    private static final ISINValidator ISIN_VALIDATOR_TRUE = new ISINValidator(true);
    private static final String[] SPECIALS;
    private static final CodeValidator VALIDATOR = new CodeValidator(ISIN_REGEX, 12, ISINCheckDigit.ISIN_CHECK_DIGIT);
    private static final long serialVersionUID = -5964391439144260936L;
    private final boolean checkCountryCode;

    static {
        String[] iSOCountries = Locale.getISOCountries();
        CCODES = iSOCountries;
        String[] strArr = {"EZ", "XS"};
        SPECIALS = strArr;
        Arrays.sort(iSOCountries);
        Arrays.sort(strArr);
    }

    public static ISINValidator getInstance(boolean checkCountryCode2) {
        return checkCountryCode2 ? ISIN_VALIDATOR_TRUE : ISIN_VALIDATOR_FALSE;
    }

    private ISINValidator(boolean checkCountryCode2) {
        this.checkCountryCode = checkCountryCode2;
    }

    public boolean isValid(String code) {
        boolean valid = VALIDATOR.isValid(code);
        if (!valid || !this.checkCountryCode) {
            return valid;
        }
        return checkCode(code.substring(0, 2));
    }

    public Object validate(String code) {
        Object validate = VALIDATOR.validate(code);
        if (validate == null || !this.checkCountryCode) {
            return validate;
        }
        if (checkCode(code.substring(0, 2))) {
            return validate;
        }
        return null;
    }

    private boolean checkCode(String code) {
        return Arrays.binarySearch(CCODES, code) >= 0 || Arrays.binarySearch(SPECIALS, code) >= 0;
    }
}
