package org.apache.commons.validator.routines;

import java.util.Locale;

public class LongValidatorTest extends AbstractNumberValidatorTest {
    private static final String LONG_MAX = "9223372036854775807";
    private static final String LONG_MAX_0 = "9223372036854775807.99999999999999999999999";
    private static final String LONG_MAX_1 = "9223372036854775808";
    private static final Long LONG_MAX_VAL = Long.MAX_VALUE;
    private static final String LONG_MIN = "-9223372036854775808";
    private static final String LONG_MIN_0 = "-9223372036854775808.99999999999999999999999";
    private static final String LONG_MIN_1 = "-9223372036854775809";
    private static final Long LONG_MIN_VAL = Long.MIN_VALUE;
    private static final String NINES = "9999999999999999999999999999999999999";

    public LongValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractNumberValidatorTest
    public void setUp() throws Exception {
        super.setUp();
        this.validator = new LongValidator(false, 0);
        this.strictValidator = new LongValidator();
        this.testPattern = "#,###";
        this.max = null;
        this.maxPlusOne = null;
        this.min = null;
        this.minMinusOne = null;
        this.invalidStrict = new String[]{null, "", "X", "X12", "12X", "1X2", "1.2", LONG_MAX_1, LONG_MIN_1, NINES};
        this.invalid = new String[]{null, "", "X", "X12", "", LONG_MAX_1, LONG_MIN_1, NINES};
        this.testNumber = 1234L;
        this.testZero = 0L;
        this.validStrict = new String[]{"0", "1234", "1,234", LONG_MAX, LONG_MIN};
        Long l = LONG_MAX_VAL;
        Long l2 = LONG_MIN_VAL;
        this.validStrictCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, l, l2};
        this.valid = new String[]{"0", "1234", "1,234", "1,234.5", "1234X", LONG_MAX, LONG_MIN, LONG_MAX_0, LONG_MIN_0};
        this.validCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, this.testNumber, this.testNumber, l, l2, l, l2};
        this.testStringUS = "1,234";
        this.testStringDE = "1.234";
        this.localeValue = this.testStringDE;
        this.localePattern = "#.###";
        this.testLocale = Locale.GERMANY;
        this.localeExpected = this.testNumber;
    }

    public void testLongValidatorMethods() {
        Locale locale = Locale.GERMAN;
        assertEquals("validate(A) default", 12345L, LongValidator.getInstance().validate("12,345"));
        assertEquals("validate(A) locale ", 12345L, LongValidator.getInstance().validate("12.345", locale));
        assertEquals("validate(A) pattern", 12345L, LongValidator.getInstance().validate("1,23,45", "0,00,00"));
        assertEquals("validate(A) both", 12345L, LongValidator.getInstance().validate("1.23.45", "0,00,00", Locale.GERMAN));
        assertTrue("isValid(A) default", LongValidator.getInstance().isValid("12,345"));
        assertTrue("isValid(A) locale ", LongValidator.getInstance().isValid("12.345", locale));
        assertTrue("isValid(A) pattern", LongValidator.getInstance().isValid("1,23,45", "0,00,00"));
        assertTrue("isValid(A) both", LongValidator.getInstance().isValid("1.23.45", "0,00,00", Locale.GERMAN));
        assertNull("validate(B) default", LongValidator.getInstance().validate("XXXX"));
        assertNull("validate(B) locale ", LongValidator.getInstance().validate("XXXX", locale));
        assertNull("validate(B) pattern", LongValidator.getInstance().validate("XXXX", "0,00,00"));
        assertNull("validate(B) both", LongValidator.getInstance().validate("1,23,45", "0,00,00", Locale.GERMAN));
        assertFalse("isValid(B) default", LongValidator.getInstance().isValid("XXXX"));
        assertFalse("isValid(B) locale ", LongValidator.getInstance().isValid("XXXX", locale));
        assertFalse("isValid(B) pattern", LongValidator.getInstance().isValid("XXXX", "0,00,00"));
        assertFalse("isValid(B) both", LongValidator.getInstance().isValid("1,23,45", "0,00,00", Locale.GERMAN));
    }

    public void testLongRangeMinMax() {
        LongValidator validator = (LongValidator) this.strictValidator;
        Long number9 = validator.validate("9", "#");
        Long number10 = validator.validate("10", "#");
        Long number11 = validator.validate("11", "#");
        Long number19 = validator.validate("19", "#");
        Long number20 = validator.validate("20", "#");
        Long number21 = validator.validate("21", "#");
        assertFalse("isInRange() < min", validator.isInRange(number9, 10, 20));
        assertTrue("isInRange() = min", validator.isInRange(number10, 10, 20));
        assertTrue("isInRange() in range", validator.isInRange(number11, 10, 20));
        assertTrue("isInRange() = max", validator.isInRange(number20, 10, 20));
        assertFalse("isInRange() > max", validator.isInRange(number21, 10, 20));
        assertFalse("minValue() < min", validator.minValue(number9, 10));
        assertTrue("minValue() = min", validator.minValue(number10, 10));
        assertTrue("minValue() > min", validator.minValue(number11, 10));
        assertTrue("maxValue() < max", validator.maxValue(number19, 20));
        assertTrue("maxValue() = max", validator.maxValue(number20, 20));
        assertFalse("maxValue() > max", validator.maxValue(number21, 20));
    }
}
