package org.apache.commons.validator.routines;

import java.math.BigDecimal;
import java.util.Locale;
import junit.framework.TestCase;

public class PercentValidatorTest extends TestCase {
    protected PercentValidator validator;

    public PercentValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    public void setUp() throws Exception {
        PercentValidatorTest.super.setUp();
        this.validator = new PercentValidator();
    }

    /* access modifiers changed from: protected */
    public void tearDown() throws Exception {
        PercentValidatorTest.super.tearDown();
        this.validator = null;
    }

    public void testFormatType() {
        assertEquals("Format Type A", 2, PercentValidator.getInstance().getFormatType());
        assertEquals("Format Type B", 2, PercentValidator.getInstance().getFormatType());
    }

    public void testValid() {
        Locale origDefault = Locale.getDefault();
        Locale.setDefault(Locale.UK);
        BigDecimalValidator validator2 = PercentValidator.getInstance();
        BigDecimal expected = new BigDecimal("0.12");
        BigDecimal negative = new BigDecimal("-0.12");
        BigDecimal hundred = new BigDecimal("1.00");
        assertEquals("Default locale", expected, validator2.validate("12%"));
        assertEquals("Default negtve", negative, validator2.validate("-12%"));
        assertEquals("UK locale", expected, validator2.validate("12%", Locale.UK));
        assertEquals("UK negative", negative, validator2.validate("-12%", Locale.UK));
        assertEquals("UK No symbol", expected, validator2.validate("12", Locale.UK));
        assertEquals("US locale", expected, validator2.validate("12%", Locale.US));
        assertEquals("US negative", negative, validator2.validate("-12%", Locale.US));
        assertEquals("US No symbol", expected, validator2.validate("12", Locale.US));
        assertEquals("100%", hundred, validator2.validate("100%"));
        Locale.setDefault(origDefault);
    }

    public void testInvalid() {
        BigDecimalValidator validator2 = PercentValidator.getInstance();
        assertFalse("isValid() Null Value", validator2.isValid(null));
        assertFalse("isValid() Empty Value", validator2.isValid(""));
        assertNull("validate() Null Value", validator2.validate(null));
        assertNull("validate() Empty Value", validator2.validate(""));
        assertFalse("UK wrong symbol", validator2.isValid("12@", Locale.UK));
        assertFalse("UK wrong negative", validator2.isValid("(12%)", Locale.UK));
        assertFalse("US wrong symbol", validator2.isValid("12@", Locale.US));
        assertFalse("US wrong negative", validator2.isValid("(12%)", Locale.US));
    }
}
