package org.apache.commons.validator.routines;

import java.util.Locale;

public class ShortValidatorTest extends AbstractNumberValidatorTest {
    public ShortValidatorTest(String name) {
        super(name);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.AbstractNumberValidatorTest
    public void setUp() throws Exception {
        super.setUp();
        this.validator = new ShortValidator(false, 0);
        this.strictValidator = new ShortValidator();
        this.testPattern = "#,###";
        this.max = Short.MAX_VALUE;
        this.maxPlusOne = Long.valueOf(this.max.longValue() + 1);
        this.min = Short.MIN_VALUE;
        this.minMinusOne = Long.valueOf(this.min.longValue() - 1);
        this.invalidStrict = new String[]{null, "", "X", "X12", "12X", "1X2", "1.2"};
        this.invalid = new String[]{null, "", "X", "X12"};
        this.testNumber = (short) 1234;
        this.testZero = (short) 0;
        this.validStrict = new String[]{"0", "1234", "1,234"};
        this.validStrictCompare = new Number[]{this.testZero, this.testNumber, this.testNumber};
        this.valid = new String[]{"0", "1234", "1,234", "1,234.5", "1234X"};
        this.validCompare = new Number[]{this.testZero, this.testNumber, this.testNumber, this.testNumber, this.testNumber};
        this.testStringUS = "1,234";
        this.testStringDE = "1.234";
        this.localeValue = this.testStringDE;
        this.localePattern = "#.###";
        this.testLocale = Locale.GERMANY;
        this.localeExpected = this.testNumber;
    }

    public void testShortValidatorMethods() {
        Locale locale = Locale.GERMAN;
        assertEquals("validate(A) default", (short) 12345, ShortValidator.getInstance().validate("12,345"));
        assertEquals("validate(A) locale ", (short) 12345, ShortValidator.getInstance().validate("12.345", locale));
        assertEquals("validate(A) pattern", (short) 12345, ShortValidator.getInstance().validate("1,23,45", "0,00,00"));
        assertEquals("validate(A) both", (short) 12345, ShortValidator.getInstance().validate("1.23.45", "0,00,00", Locale.GERMAN));
        assertTrue("isValid(A) default", ShortValidator.getInstance().isValid("12,345"));
        assertTrue("isValid(A) locale ", ShortValidator.getInstance().isValid("12.345", locale));
        assertTrue("isValid(A) pattern", ShortValidator.getInstance().isValid("1,23,45", "0,00,00"));
        assertTrue("isValid(A) both", ShortValidator.getInstance().isValid("1.23.45", "0,00,00", Locale.GERMAN));
        assertNull("validate(B) default", ShortValidator.getInstance().validate("XXXX"));
        assertNull("validate(B) locale ", ShortValidator.getInstance().validate("XXXX", locale));
        assertNull("validate(B) pattern", ShortValidator.getInstance().validate("XXXX", "0,00,00"));
        assertNull("validate(B) both", ShortValidator.getInstance().validate("1,23,45", "0,00,00", Locale.GERMAN));
        assertFalse("isValid(B) default", ShortValidator.getInstance().isValid("XXXX"));
        assertFalse("isValid(B) locale ", ShortValidator.getInstance().isValid("XXXX", locale));
        assertFalse("isValid(B) pattern", ShortValidator.getInstance().isValid("XXXX", "0,00,00"));
        assertFalse("isValid(B) both", ShortValidator.getInstance().isValid("1,23,45", "0,00,00", Locale.GERMAN));
    }

    public void testShortRangeMinMax() {
        ShortValidator validator = (ShortValidator) this.strictValidator;
        Short number9 = validator.validate("9", "#");
        Short number10 = validator.validate("10", "#");
        Short number11 = validator.validate("11", "#");
        Short number19 = validator.validate("19", "#");
        Short number20 = validator.validate("20", "#");
        Short number21 = validator.validate("21", "#");
        assertFalse("isInRange() < min", validator.isInRange(number9, (short) 10, (short) 20));
        assertTrue("isInRange() = min", validator.isInRange(number10, (short) 10, (short) 20));
        assertTrue("isInRange() in range", validator.isInRange(number11, (short) 10, (short) 20));
        assertTrue("isInRange() = max", validator.isInRange(number20, (short) 10, (short) 20));
        assertFalse("isInRange() > max", validator.isInRange(number21, (short) 10, (short) 20));
        assertFalse("minValue() < min", validator.minValue(number9, (short) 10));
        assertTrue("minValue() = min", validator.minValue(number10, (short) 10));
        assertTrue("minValue() > min", validator.minValue(number11, (short) 10));
        assertTrue("maxValue() < max", validator.maxValue(number19, (short) 20));
        assertTrue("maxValue() = max", validator.maxValue(number20, (short) 20));
        assertFalse("maxValue() > max", validator.maxValue(number21, (short) 20));
    }
}
