package org.apache.commons.validator.routines.checkdigit;

public final class CUSIPCheckDigit extends ModulusCheckDigit {
    public static final CheckDigit CUSIP_CHECK_DIGIT = new CUSIPCheckDigit();
    private static final int[] POSITION_WEIGHT = {2, 1};
    private static final long serialVersionUID = 666941918490152456L;

    public CUSIPCheckDigit() {
        super(10);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.checkdigit.ModulusCheckDigit
    public int toInt(char character, int leftPos, int rightPos) throws CheckDigitException {
        int charValue = Character.getNumericValue(character);
        int charMax = rightPos == 1 ? 9 : 35;
        if (charValue >= 0 && charValue <= charMax) {
            return charValue;
        }
        throw new CheckDigitException("Invalid Character[" + leftPos + "," + rightPos + "] = '" + charValue + "' out of range 0 to " + charMax);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.checkdigit.ModulusCheckDigit
    public int weightedValue(int charValue, int leftPos, int rightPos) {
        return ModulusCheckDigit.sumDigits(charValue * POSITION_WEIGHT[rightPos % 2]);
    }
}
