package org.apache.commons.validator.routines.checkdigit;

import java.io.Serializable;

public final class IBANCheckDigit implements CheckDigit, Serializable {
    public static final CheckDigit IBAN_CHECK_DIGIT = new IBANCheckDigit();
    private static final long MAX = 999999999;
    private static final int MAX_ALPHANUMERIC_VALUE = 35;
    private static final int MIN_CODE_LEN = 5;
    private static final long MODULUS = 97;
    private static final long serialVersionUID = -3600191725934382801L;

    @Override // org.apache.commons.validator.routines.checkdigit.CheckDigit
    public boolean isValid(String code) {
        if (code == null || code.length() < 5) {
            return false;
        }
        String check = code.substring(2, 4);
        if ("00".equals(check) || "01".equals(check) || "99".equals(check)) {
            return false;
        }
        try {
            if (calculateModulus(code) == 1) {
                return true;
            }
            return false;
        } catch (CheckDigitException e) {
            return false;
        }
    }

    @Override // org.apache.commons.validator.routines.checkdigit.CheckDigit
    public String calculate(String code) throws CheckDigitException {
        int i = 0;
        if (code == null || code.length() < 5) {
            StringBuilder sb = new StringBuilder();
            sb.append("Invalid Code length=");
            if (code != null) {
                i = code.length();
            }
            sb.append(i);
            throw new CheckDigitException(sb.toString());
        }
        int charValue = 98 - calculateModulus(code.substring(0, 2) + "00" + code.substring(4));
        String checkDigit = Integer.toString(charValue);
        if (charValue > 9) {
            return checkDigit;
        }
        return "0" + checkDigit;
    }

    private int calculateModulus(String code) throws CheckDigitException {
        String reformattedCode = code.substring(4) + code.substring(0, 4);
        long total = 0;
        for (int i = 0; i < reformattedCode.length(); i++) {
            int charValue = Character.getNumericValue(reformattedCode.charAt(i));
            if (charValue < 0 || charValue > 35) {
                throw new CheckDigitException("Invalid Character[" + i + "] = '" + charValue + "'");
            }
            long total2 = ((charValue > 9 ? 100 : 10) * total) + ((long) charValue);
            if (total2 > MAX) {
                total2 %= MODULUS;
            }
            total = total2;
        }
        return (int) (total % MODULUS);
    }
}
