package org.apache.commons.validator.routines.checkdigit;

public final class ISINCheckDigit extends ModulusCheckDigit {
    public static final CheckDigit ISIN_CHECK_DIGIT = new ISINCheckDigit();
    private static final int MAX_ALPHANUMERIC_VALUE = 35;
    private static final int[] POSITION_WEIGHT = {2, 1};
    private static final long serialVersionUID = -1239211208101323599L;

    public ISINCheckDigit() {
        super(10);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.checkdigit.ModulusCheckDigit
    public int calculateModulus(String code, boolean includesCheckDigit) throws CheckDigitException {
        StringBuilder transformed = new StringBuilder(code.length() * 2);
        if (includesCheckDigit) {
            char checkDigit = code.charAt(code.length() - 1);
            if (!Character.isDigit(checkDigit)) {
                throw new CheckDigitException("Invalid checkdigit[" + checkDigit + "] in " + code);
            }
        }
        for (int i = 0; i < code.length(); i++) {
            int charValue = Character.getNumericValue(code.charAt(i));
            if (charValue < 0 || charValue > 35) {
                throw new CheckDigitException("Invalid Character[" + (i + 1) + "] = '" + charValue + "'");
            }
            transformed.append(charValue);
        }
        return super.calculateModulus(transformed.toString(), includesCheckDigit);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.checkdigit.ModulusCheckDigit
    public int weightedValue(int charValue, int leftPos, int rightPos) {
        return ModulusCheckDigit.sumDigits(charValue * POSITION_WEIGHT[rightPos % 2]);
    }
}
