package org.apache.commons.validator.routines.checkdigit;

import java.util.Arrays;

public final class ModulusTenCheckDigit extends ModulusCheckDigit {
    private static final long serialVersionUID = -3752929983453368497L;
    private final int[] postitionWeight;
    private final boolean sumWeightedDigits;
    private final boolean useRightPos;

    public ModulusTenCheckDigit(int[] postitionWeight2) {
        this(postitionWeight2, false, false);
    }

    public ModulusTenCheckDigit(int[] postitionWeight2, boolean useRightPos2) {
        this(postitionWeight2, useRightPos2, false);
    }

    public ModulusTenCheckDigit(int[] postitionWeight2, boolean useRightPos2, boolean sumWeightedDigits2) {
        super(10);
        this.postitionWeight = Arrays.copyOf(postitionWeight2, postitionWeight2.length);
        this.useRightPos = useRightPos2;
        this.sumWeightedDigits = sumWeightedDigits2;
    }

    @Override // org.apache.commons.validator.routines.checkdigit.CheckDigit, org.apache.commons.validator.routines.checkdigit.ModulusCheckDigit
    public boolean isValid(String code) {
        if (code == null || code.length() == 0 || !Character.isDigit(code.charAt(code.length() - 1))) {
            return false;
        }
        return super.isValid(code);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.checkdigit.ModulusCheckDigit
    public int toInt(char character, int leftPos, int rightPos) throws CheckDigitException {
        int num = Character.getNumericValue(character);
        if (num >= 0) {
            return num;
        }
        throw new CheckDigitException("Invalid Character[" + leftPos + "] = '" + character + "'");
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.checkdigit.ModulusCheckDigit
    public int weightedValue(int charValue, int leftPos, int rightPos) {
        int pos = this.useRightPos ? rightPos : leftPos;
        int[] iArr = this.postitionWeight;
        int weightedValue = charValue * iArr[(pos - 1) % iArr.length];
        if (this.sumWeightedDigits) {
            return ModulusCheckDigit.sumDigits(weightedValue);
        }
        return weightedValue;
    }

    public String toString() {
        return getClass().getSimpleName() + "[postitionWeight=" + Arrays.toString(this.postitionWeight) + ", useRightPos=" + this.useRightPos + ", sumWeightedDigits=" + this.sumWeightedDigits + "]";
    }
}
