package org.apache.commons.validator.routines.checkdigit;

public final class SedolCheckDigit extends ModulusCheckDigit {
    private static final int MAX_ALPHANUMERIC_VALUE = 35;
    private static final int[] POSITION_WEIGHT = {1, 3, 1, 7, 3, 9, 1};
    public static final CheckDigit SEDOL_CHECK_DIGIT = new SedolCheckDigit();
    private static final long serialVersionUID = -8976881621148878443L;

    public SedolCheckDigit() {
        super(10);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.checkdigit.ModulusCheckDigit
    public int calculateModulus(String code, boolean includesCheckDigit) throws CheckDigitException {
        if (code.length() <= POSITION_WEIGHT.length) {
            return super.calculateModulus(code, includesCheckDigit);
        }
        throw new CheckDigitException("Invalid Code Length = " + code.length());
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.checkdigit.ModulusCheckDigit
    public int weightedValue(int charValue, int leftPos, int rightPos) {
        return POSITION_WEIGHT[leftPos - 1] * charValue;
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.commons.validator.routines.checkdigit.ModulusCheckDigit
    public int toInt(char character, int leftPos, int rightPos) throws CheckDigitException {
        int charValue = Character.getNumericValue(character);
        int charMax = rightPos == 1 ? 9 : 35;
        if (charValue >= 0 && charValue <= charMax) {
            return charValue;
        }
        throw new CheckDigitException("Invalid Character[" + leftPos + "," + rightPos + "] = '" + charValue + "' out of range 0 to " + charMax);
    }
}
