package org.apache.commons.validator.util;

import junit.framework.TestCase;

public class FlagsTest extends TestCase {
    private static final int INT_FLAG = 4;
    private static final long LONG_FLAG = 1;
    private static final long LONG_FLAG_2 = 2;

    public FlagsTest(String name) {
        super(name);
    }

    public void testHashCode() {
        assertEquals(new Flags(45).hashCode(), 45);
    }

    public void testGetFlags() {
        assertEquals(new Flags(45).getFlags(), 45);
    }

    public void testIsOnOff() {
        Flags f = new Flags();
        f.turnOn(1);
        f.turnOn(4);
        assertTrue(f.isOn(1));
        assertTrue(!f.isOff(1));
        assertTrue(f.isOn(4));
        assertTrue(!f.isOff(4));
        assertTrue(f.isOff(2));
    }

    public void testTurnOnOff() {
    }

    public void testTurnOff() {
    }

    public void testTurnOffAll() {
        Flags f = new Flags(98432);
        f.turnOffAll();
        assertEquals(0, f.getFlags());
    }

    public void testClear() {
        Flags f = new Flags(98432);
        f.clear();
        assertEquals(0, f.getFlags());
    }

    public void testTurnOnAll() {
        Flags f = new Flags();
        f.turnOnAll();
        assertEquals(-1, f.getFlags());
    }

    public void testIsOn_isFalseWhenNotAllFlagsInArgumentAreOn() {
        assertFalse(new Flags(1).isOn(3));
    }

    public void testIsOn_isTrueWhenHighOrderBitIsSetAndQueried() {
        assertTrue(new Flags(-1).isOn(Long.MIN_VALUE));
    }

    public void testClone() {
    }

    public void testEqualsObject() {
    }

    public void testToString() {
        Flags f = new Flags();
        assertEquals(64, f.toString().length());
        f.turnOn(4);
        String s = f.toString();
        assertEquals(64, s.length());
        assertEquals("0000000000000000000000000000000000000000000000000000000000000100", s);
    }
}
