package org.apache.commons.validator.util;

import java.lang.reflect.InvocationTargetException;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.collections.FastHashMap;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.commons.validator.Arg;
import org.apache.commons.validator.Msg;
import org.apache.commons.validator.Var;

public class ValidatorUtils {
    private static final Log LOG = LogFactory.getLog(ValidatorUtils.class);

    public static String replace(String value, String key, String replaceValue) {
        int pos;
        if (value == null || key == null || replaceValue == null || (pos = value.indexOf(key)) < 0) {
            return value;
        }
        int length = value.length();
        int end = key.length() + pos;
        if (length == key.length()) {
            return replaceValue;
        }
        if (end == length) {
            return value.substring(0, pos) + replaceValue;
        }
        return value.substring(0, pos) + replaceValue + replace(value.substring(end), key, replaceValue);
    }

    public static String getValueAsString(Object bean, String property) {
        Object value = null;
        try {
            value = PropertyUtils.getProperty(bean, property);
        } catch (IllegalAccessException e) {
            LOG.error(e.getMessage(), e);
        } catch (InvocationTargetException e2) {
            LOG.error(e2.getMessage(), e2);
        } catch (NoSuchMethodException e3) {
            LOG.error(e3.getMessage(), e3);
        }
        if (value == null) {
            return null;
        }
        if (value instanceof String[]) {
            if (((String[]) value).length > 0) {
                return value.toString();
            }
            return "";
        } else if (!(value instanceof Collection)) {
            return value.toString();
        } else {
            if (((Collection) value).isEmpty()) {
                return "";
            }
            return value.toString();
        }
    }

    @Deprecated
    public static FastHashMap copyFastHashMap(FastHashMap map) {
        FastHashMap results = new FastHashMap();
        for (Map.Entry<String, ?> entry : map.entrySet()) {
            String key = entry.getKey();
            Object value = entry.getValue();
            if (value instanceof Msg) {
                results.put(key, ((Msg) value).clone());
            } else if (value instanceof Arg) {
                results.put(key, ((Arg) value).clone());
            } else if (value instanceof Var) {
                results.put(key, ((Var) value).clone());
            } else {
                results.put(key, value);
            }
        }
        results.setFast(true);
        return results;
    }

    public static Map<String, Object> copyMap(Map<String, Object> map) {
        Map<String, Object> results = new HashMap<>();
        for (Map.Entry<String, Object> entry : map.entrySet()) {
            String key = entry.getKey();
            Object value = entry.getValue();
            if (value instanceof Msg) {
                results.put(key, ((Msg) value).clone());
            } else if (value instanceof Arg) {
                results.put(key, ((Arg) value).clone());
            } else if (value instanceof Var) {
                results.put(key, ((Var) value).clone());
            } else {
                results.put(key, value);
            }
        }
        return results;
    }
}
